@@ -1,25 +1,15 @@
-# -*- coding: utf-8 -*-
 """
 Provide authentication using simple LDAP binds
 
 :depends:   - ldap Python module
 """
-
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import itertools
 import logging
 
 import salt.utils.data
 import salt.utils.stringutils
-
-# Import third party libs
 from jinja2 import Environment
-
-# Import salt libs
 from salt.exceptions import CommandExecutionError, SaltInvocationError
-from salt.ext import six
 
 log = logging.getLogger(__name__)
 
@@ -62,15 +52,15 @@ def _config(key, mandatory=True, opts=None):
     """
     try:
         if opts:
-            value = opts["auth.ldap.{0}".format(key)]
+            value = opts["auth.ldap.{}".format(key)]
         else:
-            value = __opts__["auth.ldap.{0}".format(key)]
+            value = __opts__["auth.ldap.{}".format(key)]
     except KeyError:
         try:
-            value = __defopts__["auth.ldap.{0}".format(key)]
+            value = __defopts__["auth.ldap.{}".format(key)]
         except KeyError:
             if mandatory:
-                msg = "missing auth.ldap.{0} in master config".format(key)
+                msg = "missing auth.ldap.{} in master config".format(key)
                 raise SaltInvocationError(msg)
             return False
     return value
@@ -86,7 +76,7 @@ def _render_template(param, username):
     return template.render(variables)
 
 
-class _LDAPConnection(object):
+class _LDAPConnection:
     """
     Setup an LDAP connection.
     """
@@ -128,13 +118,13 @@ class _LDAPConnection(object):
 
         schema = "ldaps" if tls else "ldap"
         if self.uri == "":
-            self.uri = "{0}://{1}:{2}".format(schema, self.server, self.port)
+            self.uri = "{}://{}:{}".format(schema, self.server, self.port)
 
         try:
             if no_verify:
                 ldap.set_option(ldap.OPT_X_TLS_REQUIRE_CERT, ldap.OPT_X_TLS_NEVER)
 
-            self.ldap = ldap.initialize("{0}".format(self.uri))
+            self.ldap = ldap.initialize("{}".format(self.uri))
             self.ldap.protocol_version = 3  # ldap.VERSION3
             self.ldap.set_option(ldap.OPT_REFERRALS, 0)  # Needed for AD
 
@@ -148,7 +138,7 @@ class _LDAPConnection(object):
                 self.ldap.simple_bind_s(self.binddn, self.bindpw)
         except Exception as ldap_error:  # pylint: disable=broad-except
             raise CommandExecutionError(
-                "Failed to bind to LDAP server {0} as {1}: {2}".format(
+                "Failed to bind to LDAP server {} as {}: {}".format(
                     self.uri, self.binddn, ldap_error
                 )
             )
@@ -412,14 +402,14 @@ def groups(username, **kwargs):
 
         if _config("activedirectory"):
             try:
-                get_user_dn_search = "(&({0}={1})(objectClass={2}))".format(
+                get_user_dn_search = "(&({}={})(objectClass={}))".format(
                     _config("accountattributename"), username, _config("persontype")
                 )
                 user_dn_results = bind.search_s(
                     _config("basedn"),
                     ldap.SCOPE_SUBTREE,
                     get_user_dn_search,
-                    [str("distinguishedName")],
+                    ["distinguishedName"],
                 )  # future lint: disable=blacklisted-function
             except Exception as e:  # pylint: disable=broad-except
                 log.error("Exception thrown while looking up user DN in AD: %s", e)
@@ -429,7 +419,7 @@ def groups(username, **kwargs):
                 return group_list
             # LDAP results are always tuples.  First entry in the tuple is the DN
             dn = ldap.filter.escape_filter_chars(user_dn_results[0][0])
-            ldap_search_string = "(&(member={0})(objectClass={1}))".format(
+            ldap_search_string = "(&(member={})(objectClass={}))".format(
                 dn, _config("groupclass")
             )
             log.debug("Running LDAP group membership search: %s", ldap_search_string)
@@ -440,7 +430,7 @@ def groups(username, **kwargs):
                     ldap_search_string,
                     [
                         salt.utils.stringutils.to_str(_config("accountattributename")),
-                        str("cn"),
+                        "cn",
                     ],
                 )  # future lint: disable=blacklisted-function
             except Exception as e:  # pylint: disable=broad-except
@@ -464,7 +454,7 @@ def groups(username, **kwargs):
                 [
                     salt.utils.stringutils.to_str(_config("accountattributename")),
                     salt.utils.stringutils.to_str(_config("groupattribute")),
-                    str("cn"),
+                    "cn",
                 ],
             )  # future lint: disable=blacklisted-function
 
@@ -488,10 +478,10 @@ def groups(username, **kwargs):
                 return []
         else:
             if _config("groupou"):
-                search_base = "ou={0},{1}".format(_config("groupou"), _config("basedn"))
+                search_base = "ou={},{}".format(_config("groupou"), _config("basedn"))
             else:
-                search_base = "{0}".format(_config("basedn"))
-            search_string = "(&({0}={1})(objectClass={2}))".format(
+                search_base = "{}".format(_config("basedn"))
+            search_string = "(&({}={})(objectClass={}))".format(
                 _config("accountattributename"), username, _config("groupclass")
             )
             search_results = bind.search_s(
@@ -500,7 +490,7 @@ def groups(username, **kwargs):
                 search_string,
                 [
                     salt.utils.stringutils.to_str(_config("accountattributename")),
-                    str("cn"),  # future lint: disable=blacklisted-function
+                    "cn",  # future lint: disable=blacklisted-function
                     salt.utils.stringutils.to_str(_config("groupattribute")),
                 ],
             )
@@ -569,7 +559,7 @@ def __expand_ldap_entries(entries, opts=None):
         if not isinstance(user_or_group_dict, dict):
             acl_tree.append(user_or_group_dict)
             continue
-        for minion_or_ou, matchers in six.iteritems(user_or_group_dict):
+        for minion_or_ou, matchers in user_or_group_dict.items():
             permissions = matchers
             retrieved_minion_ids = []
             if minion_or_ou.startswith("ldap("):
@@ -578,7 +568,7 @@ def __expand_ldap_entries(entries, opts=None):
                 search_string = "(objectClass=computer)"
                 try:
                     search_results = bind.search_s(
-                        search_base, ldap.SCOPE_SUBTREE, search_string, [str("cn")]
+                        search_base, ldap.SCOPE_SUBTREE, search_string, ["cn"]
                     )  # future lint: disable=blacklisted-function
                     for ldap_match in search_results:
                         try:
@@ -622,7 +612,7 @@ def process_acl(auth_list, opts=None):
     """
     ou_names = []
     for item in auth_list:
-        if isinstance(item, six.string_types):
+        if isinstance(item, str):
             continue
         ou_names.extend(
             [
