@@ -1,21 +1,12 @@
-# -*- coding: utf-8 -*-
 """
 An execution module which can manipulate an f5 bigip via iControl REST
     :maturity:      develop
     :platform:      f5_bigip_11.6
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import salt libs
 import salt.exceptions
 import salt.utils.json
 
-# Import 3rd-party libs
-from salt.ext import six
-
-# Import third party libs
 try:
     import requests
     import requests.exceptions
@@ -109,7 +100,7 @@ def _loop_payload(params):
     payload = {}
 
     # set the payload
-    for param, value in six.iteritems(params):
+    for param, value in params.items():
         if value is not None:
             payload[param] = value
 
@@ -153,7 +144,7 @@ def _determine_toggles(payload, toggles):
     Figure out what it likes to hear without confusing the user.
     """
 
-    for toggle, definition in six.iteritems(toggles):
+    for toggle, definition in toggles.items():
         # did the user specify anything?
         if definition["value"] is not None:
             # test for yes_no toggle
@@ -253,7 +244,9 @@ def start_transaction(hostname, username, password, label):
         The name / alias for this transaction.  The actual transaction
         id will be stored within a grain called ``bigip_f5_trans:<label>``
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.start_transaction bigip admin admin my_transaction
 
@@ -303,7 +296,9 @@ def list_transaction(hostname, username, password, label):
         the label of this transaction stored within the grain:
         ``bigip_f5_trans:<label>``
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.list_transaction bigip admin admin my_transaction
 
@@ -347,7 +342,9 @@ def commit_transaction(hostname, username, password, label):
         the label of this transaction stored within the grain:
         ``bigip_f5_trans:<label>``
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.commit_transaction bigip admin admin my_transaction
     """
@@ -394,7 +391,9 @@ def delete_transaction(hostname, username, password, label):
         The label of this transaction stored within the grain:
         ``bigip_f5_trans:<label>``
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.delete_transaction bigip admin admin my_transaction
     """
@@ -441,7 +440,9 @@ def list_node(hostname, username, password, name=None, trans_label=None):
         The label of the transaction stored within the grain:
         ``bigip_f5_trans:<label>``
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.list_node bigip admin admin my-node
     """
@@ -484,7 +485,9 @@ def create_node(hostname, username, password, name, address, trans_label=None):
         The label of the transaction stored within the grain:
         ``bigip_f5_trans:<label>``
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.create_node bigip admin admin 10.1.1.2
     """
@@ -558,7 +561,9 @@ def modify_node(
         The label of the transaction stored within the grain:
         ``bigip_f5_trans:<label>``
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.modify_node bigip admin admin 10.1.1.2 ratio=2 logging=enabled
     """
@@ -611,7 +616,9 @@ def delete_node(hostname, username, password, name, trans_label=None):
         The label of the transaction stored within the grain:
         ``bigip_f5_trans:<label>``
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.delete_node bigip admin admin my-node
     """
@@ -647,7 +654,9 @@ def list_pool(hostname, username, password, name=None):
         The name of the pool to list. If no name is specified then all pools
         will be listed.
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.list_pool bigip admin admin my-pool
     """
@@ -771,7 +780,9 @@ def create_pool(
     slow_ramp_time
         [integer]
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.create_pool bigip admin admin my-pool 10.1.1.1:80,10.1.1.2:80,10.1.1.3:80 monitor=http
     """
@@ -927,7 +938,9 @@ def modify_pool(
     slow_ramp_time
         [integer]
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.modify_pool bigip admin admin my-pool 10.1.1.1:80,10.1.1.2:80,10.1.1.3:80 min_active_members=1
     """
@@ -998,7 +1011,9 @@ def delete_pool(hostname, username, password, name):
     name
         The name of the pool which will be deleted
 
-    CLI Example::
+    CLI Example
+
+    .. code-block:: bash
 
         salt '*' bigip.delete_node bigip admin admin my-pool
     """
@@ -1036,7 +1051,9 @@ def replace_pool_members(hostname, username, password, name, members):
         List of comma delimited pool members to replace existing members with.
         i.e. 10.1.1.1:80,10.1.1.2:80,10.1.1.3:80
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.replace_pool_members bigip admin admin my-pool 10.2.2.1:80,10.2.2.2:80,10.2.2.3:80
     """
@@ -1046,7 +1063,7 @@ def replace_pool_members(hostname, username, password, name, members):
     # specify members if provided
     if members is not None:
 
-        if isinstance(members, six.string_types):
+        if isinstance(members, str):
             members = members.split(",")
 
         pool_members = []
@@ -1202,7 +1219,9 @@ def modify_pool_member(
     state
         [ user-up | user-down ]
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.modify_pool_member bigip admin admin my-pool 10.2.2.1:80 state=use-down session=user-disabled
     """
@@ -1256,7 +1275,9 @@ def delete_pool_member(hostname, username, password, name, member):
     member
         The name of the pool member to delete
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.delete_pool_member bigip admin admin my-pool 10.2.2.2:80
     """
@@ -1293,7 +1314,9 @@ def list_virtual(hostname, username, password, name=None):
         The name of the virtual to list. If no name is specified than all
         virtuals will be listed.
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.list_virtual bigip admin admin my-virtual
     """
@@ -1458,7 +1481,9 @@ def create_virtual(
     vlans
         [none | default | [enabled|disabled]:vlan1,vlan2,vlan3 ... ]
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.create_virtual bigip admin admin my-virtual-3 26.2.2.5:80 \
             pool=my-http-pool-http profiles=http,tcp
@@ -1583,7 +1608,7 @@ def create_virtual(
             payload["vlans"] = "none"
         elif vlans == "default":
             payload["vlans"] = "default"
-        elif isinstance(vlans, six.string_types) and (
+        elif isinstance(vlans, str) and (
             vlans.startswith("enabled") or vlans.startswith("disabled")
         ):
             try:
@@ -1759,7 +1784,9 @@ def modify_virtual(
     vlans
         [none | default | [enabled|disabled]:vlan1,vlan2,vlan3 ... ]
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.modify_virtual bigip admin admin my-virtual source_address_translation=none
         salt '*' bigip.modify_virtual bigip admin admin my-virtual rules=my-rule,my-other-rule
@@ -1914,7 +1941,9 @@ def delete_virtual(hostname, username, password, name):
     name
         The name of the virtual to delete
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.delete_virtual bigip admin admin my-virtual
     """
@@ -1955,7 +1984,9 @@ def list_monitor(
     name
         The name of the monitor to list
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.list_monitor bigip admin admin http my-http-monitor
 
@@ -2002,7 +2033,9 @@ def create_monitor(hostname, username, password, monitor_type, name, **kwargs):
         Consult F5 BIGIP user guide for specific options for each monitor type.
         Typically, tmsh arg names are used.
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.create_monitor bigip admin admin http my-http-monitor timeout=10 interval=5
     """
@@ -2016,7 +2049,7 @@ def create_monitor(hostname, username, password, monitor_type, name, **kwargs):
 
     # there's a ton of different monitors and a ton of options for each type of monitor.
     # this logic relies that the end user knows which options are meant for which monitor types
-    for key, value in six.iteritems(kwargs):
+    for key, value in kwargs.items():
         if not key.startswith("__"):
             if key not in ["hostname", "username", "password", "type"]:
                 key = key.replace("_", "-")
@@ -2053,7 +2086,9 @@ def modify_monitor(hostname, username, password, monitor_type, name, **kwargs):
         Consult F5 BIGIP user guide for specific options for each monitor type.
         Typically, tmsh arg names are used.
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.modify_monitor bigip admin admin http my-http-monitor  timout=16 interval=6
 
@@ -2067,7 +2102,7 @@ def modify_monitor(hostname, username, password, monitor_type, name, **kwargs):
 
     # there's a ton of different monitors and a ton of options for each type of monitor.
     # this logic relies that the end user knows which options are meant for which monitor types
-    for key, value in six.iteritems(kwargs):
+    for key, value in kwargs.items():
         if not key.startswith("__"):
             if key not in ["hostname", "username", "password", "type", "name"]:
                 key = key.replace("_", "-")
@@ -2101,7 +2136,9 @@ def delete_monitor(hostname, username, password, monitor_type, name):
     name
         The name of the monitor to delete
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.delete_monitor bigip admin admin http my-http-monitor
 
@@ -2143,7 +2180,9 @@ def list_profile(
     name
         The name of the profile to list
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.list_profile bigip admin admin http my-http-profile
 
@@ -2214,7 +2253,9 @@ def create_profile(hostname, username, password, profile_type, name, **kwargs):
             Use ``\,`` or ``\:`` or ``\|`` to escape characters which shouldn't
             be treated as delimiters i.e. ``ciphers='DEFAULT\:!SSLv3'``
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.create_profile bigip admin admin http my-http-profile defaultsFrom='/Common/http'
         salt '*' bigip.create_profile bigip admin admin http my-http-profile defaultsFrom='/Common/http' \
@@ -2231,7 +2272,7 @@ def create_profile(hostname, username, password, profile_type, name, **kwargs):
 
     # there's a ton of different profiles and a ton of options for each type of profile.
     # this logic relies that the end user knows which options are meant for which profile types
-    for key, value in six.iteritems(kwargs):
+    for key, value in kwargs.items():
         if not key.startswith("__"):
             if key not in ["hostname", "username", "password", "profile_type"]:
                 key = key.replace("_", "-")
@@ -2301,7 +2342,9 @@ def modify_profile(hostname, username, password, profile_type, name, **kwargs):
             Use ``\,`` or ``\:`` or ``\|`` to escape characters which shouldn't
             be treated as delimiters i.e. ``ciphers='DEFAULT\:!SSLv3'``
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.modify_profile bigip admin admin http my-http-profile defaultsFrom='/Common/http'
 
@@ -2322,7 +2365,7 @@ def modify_profile(hostname, username, password, profile_type, name, **kwargs):
 
     # there's a ton of different profiles and a ton of options for each type of profile.
     # this logic relies that the end user knows which options are meant for which profile types
-    for key, value in six.iteritems(kwargs):
+    for key, value in kwargs.items():
         if not key.startswith("__"):
             if key not in ["hostname", "username", "password", "profile_type"]:
                 key = key.replace("_", "-")
@@ -2362,7 +2405,9 @@ def delete_profile(hostname, username, password, profile_type, name):
     name
         The name of the profile to delete
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' bigip.delete_profile bigip admin admin http my-http-profile
 
