@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 daemontools service module. This module will create daemontools type
 service watcher.
 
@@ -11,25 +11,30 @@ so it can be used to maintain services using the ``provider`` argument:
     myservice:
       service.running:
         - provider: daemontools
-'''
-from __future__ import absolute_import
+"""
+from __future__ import absolute_import, print_function, unicode_literals
 
 # Import python libs
+import logging
 import os
+import os.path
 import re
 
 # Import salt libs
+import salt.utils.path
 from salt.exceptions import CommandExecutionError
 
 # Function alias to not shadow built-ins.
-__func_alias__ = {
-    'reload_': 'reload'
-}
+__func_alias__ = {"reload_": "reload"}
+
+log = logging.getLogger(__name__)
+
+__virtualname__ = "daemontools"
 
 VALID_SERVICE_DIRS = [
-    '/service',
-    '/var/service',
-    '/etc/service',
+    "/service",
+    "/var/service",
+    "/etc/service",
 ]
 SERVICE_DIR = None
 for service_dir in VALID_SERVICE_DIRS:
@@ -38,18 +43,26 @@ for service_dir in VALID_SERVICE_DIRS:
         break
 
 
+def __virtual__():
+    # Ensure that daemontools is installed properly.
+    BINS = frozenset(("svc", "supervise", "svok"))
+    if all(salt.utils.path.which(b) for b in BINS) and SERVICE_DIR:
+        return __virtualname__
+    return (False, "Missing dependency: {0}".format(BINS))
+
+
 def _service_path(name):
-    '''
+    """
     build service path
-    '''
+    """
     if not SERVICE_DIR:
         raise CommandExecutionError("Could not find service directory.")
-    return '{0}/{1}'.format(SERVICE_DIR, name)
+    return "{0}/{1}".format(SERVICE_DIR, name)
 
 
-#-- states.service  compatible args
+# -- states.service  compatible args
 def start(name):
-    '''
+    """
     Starts service via daemontools
 
     CLI Example:
@@ -57,15 +70,15 @@ def start(name):
     .. code-block:: bash
 
         salt '*' daemontools.start <service name>
-    '''
-    __salt__['file.remove']('{0}/down'.format(_service_path(name)))
-    cmd = 'svc -u {0}'.format(_service_path(name))
-    return not __salt__['cmd.retcode'](cmd, python_shell=False)
+    """
+    __salt__["file.remove"]("{0}/down".format(_service_path(name)))
+    cmd = "svc -u {0}".format(_service_path(name))
+    return not __salt__["cmd.retcode"](cmd, python_shell=False)
 
 
-#-- states.service compatible args
+# -- states.service compatible args
 def stop(name):
-    '''
+    """
     Stops service via daemontools
 
     CLI Example:
@@ -73,14 +86,14 @@ def stop(name):
     .. code-block:: bash
 
         salt '*' daemontools.stop <service name>
-    '''
-    __salt__['file.touch']('{0}/down'.format(_service_path(name)))
-    cmd = 'svc -d {0}'.format(_service_path(name))
-    return not __salt__['cmd.retcode'](cmd, python_shell=False)
+    """
+    __salt__["file.touch"]("{0}/down".format(_service_path(name)))
+    cmd = "svc -d {0}".format(_service_path(name))
+    return not __salt__["cmd.retcode"](cmd, python_shell=False)
 
 
 def term(name):
-    '''
+    """
     Send a TERM to service via daemontools
 
     CLI Example:
@@ -88,14 +101,14 @@ def term(name):
     .. code-block:: bash
 
         salt '*' daemontools.term <service name>
-    '''
-    cmd = 'svc -t {0}'.format(_service_path(name))
-    return not __salt__['cmd.retcode'](cmd, python_shell=False)
+    """
+    cmd = "svc -t {0}".format(_service_path(name))
+    return not __salt__["cmd.retcode"](cmd, python_shell=False)
 
 
-#-- states.service compatible
+# -- states.service compatible
 def reload_(name):
-    '''
+    """
     Wrapper for term()
 
     CLI Example:
@@ -103,13 +116,13 @@ def reload_(name):
     .. code-block:: bash
 
         salt '*' daemontools.reload <service name>
-    '''
+    """
     term(name)
 
 
-#-- states.service compatible
+# -- states.service compatible
 def restart(name):
-    '''
+    """
     Restart service via daemontools. This will stop/start service
 
     CLI Example:
@@ -117,16 +130,16 @@ def restart(name):
     .. code-block:: bash
 
         salt '*' daemontools.restart <service name>
-    '''
-    ret = 'restart False'
+    """
+    ret = "restart False"
     if stop(name) and start(name):
-        ret = 'restart True'
+        ret = "restart True"
     return ret
 
 
-#-- states.service compatible
+# -- states.service compatible
 def full_restart(name):
-    '''
+    """
     Calls daemontools.restart() function
 
     CLI Example:
@@ -134,13 +147,13 @@ def full_restart(name):
     .. code-block:: bash
 
         salt '*' daemontools.full_restart <service name>
-    '''
+    """
     restart(name)
 
 
-#-- states.service compatible
+# -- states.service compatible
 def status(name, sig=None):
-    '''
+    """
     Return the status for a service via daemontools, return pid if running
 
     CLI Example:
@@ -148,18 +161,18 @@ def status(name, sig=None):
     .. code-block:: bash
 
         salt '*' daemontools.status <service name>
-    '''
-    cmd = 'svstat {0}'.format(_service_path(name))
-    out = __salt__['cmd.run_stdout'](cmd, python_shell=False)
+    """
+    cmd = "svstat {0}".format(_service_path(name))
+    out = __salt__["cmd.run_stdout"](cmd, python_shell=False)
     try:
-        pid = re.search(r'\(pid (\d+)\)', out).group(1)
+        pid = re.search(r"\(pid (\d+)\)", out).group(1)
     except AttributeError:
-        pid = ''
+        pid = ""
     return pid
 
 
 def available(name):
-    '''
+    """
     Returns ``True`` if the specified service is available, otherwise returns
     ``False``.
 
@@ -168,12 +181,12 @@ def available(name):
     .. code-block:: bash
 
         salt '*' daemontools.available foo
-    '''
+    """
     return name in get_all()
 
 
 def missing(name):
-    '''
+    """
     The inverse of daemontools.available.
     Returns ``True`` if the specified service is not available, otherwise returns
     ``False``.
@@ -183,12 +196,12 @@ def missing(name):
     .. code-block:: bash
 
         salt '*' daemontools.missing foo
-    '''
+    """
     return name not in get_all()
 
 
 def get_all():
-    '''
+    """
     Return a list of all available services
 
     CLI Example:
@@ -196,8 +209,55 @@ def get_all():
     .. code-block:: bash
 
         salt '*' daemontools.get_all
-    '''
+    """
     if not SERVICE_DIR:
         raise CommandExecutionError("Could not find service directory.")
-    #- List all daemontools services in
+    # - List all daemontools services in
     return sorted(os.listdir(SERVICE_DIR))
+
+
+def enabled(name, **kwargs):
+    """
+    Return True if the named service is enabled, false otherwise
+    A service is considered enabled if in your service directory:
+    - an executable ./run file exist
+    - a file named "down" does not exist
+
+    .. versionadded:: 2015.5.7
+
+    name
+        Service name
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' daemontools.enabled <service name>
+    """
+    if not available(name):
+        log.error("Service %s not found", name)
+        return False
+
+    run_file = os.path.join(SERVICE_DIR, name, "run")
+    down_file = os.path.join(SERVICE_DIR, name, "down")
+
+    return (
+        os.path.isfile(run_file)
+        and os.access(run_file, os.X_OK)
+        and not os.path.isfile(down_file)
+    )
+
+
+def disabled(name):
+    """
+    Return True if the named service is enabled, false otherwise
+
+    .. versionadded:: 2015.5.6
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' daemontools.disabled <service name>
+    """
+    return not enabled(name)
