@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Remote package support using ``pkg_add(1)``
 
 .. important::
@@ -71,45 +70,51 @@ variables, if set, but these values can also be overridden in several ways:
             zsh:
               pkg.installed:
                 - fromrepo: ftp://ftp2.freebsd.org/
-'''
-from __future__ import absolute_import
+"""
 
-# Import python libs
 import copy
 import logging
 import re
 
-# Import salt libs
-import salt.utils
+import salt.utils.data
+import salt.utils.functools
+import salt.utils.pkg
 from salt.exceptions import CommandExecutionError, MinionError
-import salt.ext.six as six
 
 log = logging.getLogger(__name__)
 
 # Define the module's virtual name
-__virtualname__ = 'pkg'
+__virtualname__ = "pkg"
 
 
 def __virtual__():
-    '''
+    """
     Load as 'pkg' on FreeBSD versions less than 10.
     Don't load on FreeBSD 9 when the config option
     ``providers:pkg`` is set to 'pkgng'.
-    '''
-    if __grains__['os'] == 'FreeBSD' and float(__grains__['osrelease']) < 10:
+    """
+    if __grains__["os"] == "FreeBSD" and float(__grains__["osrelease"]) < 10:
         providers = {}
-        if 'providers' in __opts__:
-            providers = __opts__['providers']
-        if providers and 'pkg' in providers and providers['pkg'] == 'pkgng':
-            log.debug('Configuration option \'providers:pkg\' is set to '
-                    '\'pkgng\', won\'t load old provider \'freebsdpkg\'.')
-            return (False, 'The freebsdpkg execution module cannot be loaded: the configuration option \'providers:pkg\' is set to \'pkgng\'')
+        if "providers" in __opts__:
+            providers = __opts__["providers"]
+        if providers and "pkg" in providers and providers["pkg"] == "pkgng":
+            log.debug(
+                "Configuration option 'providers:pkg' is set to "
+                "'pkgng', won't load old provider 'freebsdpkg'."
+            )
+            return (
+                False,
+                "The freebsdpkg execution module cannot be loaded: the configuration option 'providers:pkg' is set to 'pkgng'",
+            )
         return __virtualname__
-    return (False, 'The freebsdpkg execution module cannot be loaded: either the os is not FreeBSD or the version of FreeBSD is >= 10.')
+    return (
+        False,
+        "The freebsdpkg execution module cannot be loaded: either the os is not FreeBSD or the version of FreeBSD is >= 10.",
+    )
 
 
 def _get_repo_options(fromrepo=None, packagesite=None):
-    '''
+    """
     Return a list of tuples to seed the "env" list, which is used to set
     environment variables for any pkg_add commands that are spawned.
 
@@ -120,34 +125,40 @@ def _get_repo_options(fromrepo=None, packagesite=None):
     freebsdpkg.PACKAGEROOT nor freebsdpkg.PACKAGESITE are specified, then an
     empty list is returned, and it is assumed that the system defaults (or
     environment variables) will be used.
-    '''
-    root = fromrepo if fromrepo is not None \
-        else __salt__['config.get']('freebsdpkg.PACKAGEROOT', None)
-    site = packagesite if packagesite is not None \
-        else __salt__['config.get']('freebsdpkg.PACKAGESITE', None)
+    """
+    root = (
+        fromrepo
+        if fromrepo is not None
+        else __salt__["config.get"]("freebsdpkg.PACKAGEROOT", None)
+    )
+    site = (
+        packagesite
+        if packagesite is not None
+        else __salt__["config.get"]("freebsdpkg.PACKAGESITE", None)
+    )
     ret = {}
     if root is not None:
-        ret['PACKAGEROOT'] = root
+        ret["PACKAGEROOT"] = root
     if site is not None:
-        ret['PACKAGESITE'] = site
+        ret["PACKAGESITE"] = site
     return ret
 
 
 def _match(names):
-    '''
+    """
     Since pkg_delete requires the full "pkgname-version" string, this function
     will attempt to match the package name with its version. Returns a list of
     partial matches and package names that match the "pkgname-version" string
     required by pkg_delete, and a list of errors encountered.
-    '''
+    """
     pkgs = list_pkgs(versions_as_list=True)
     errors = []
 
     # Look for full matches
     full_pkg_strings = []
-    out = __salt__['cmd.run_stdout'](['pkg_info'],
-                                     output_loglevel='trace',
-                                     python_shell=False)
+    out = __salt__["cmd.run_stdout"](
+        ["pkg_info"], output_loglevel="trace", python_shell=False
+    )
     for line in out.splitlines():
         try:
             full_pkg_strings.append(line.split()[0])
@@ -162,28 +173,26 @@ def _match(names):
         cver = pkgs.get(name)
         if cver is not None:
             if len(cver) == 1:
-                matches.append('{0}-{1}'.format(name, cver[0]))
+                matches.append("{}-{}".format(name, cver[0]))
             else:
                 ambiguous.append(name)
                 errors.append(
-                    'Ambiguous package \'{0}\'. Full name/version required. '
-                    'Possible matches: {1}'.format(
-                        name,
-                        ', '.join(['{0}-{1}'.format(name, x) for x in cver])
+                    "Ambiguous package '{}'. Full name/version required. "
+                    "Possible matches: {}".format(
+                        name, ", ".join(["{}-{}".format(name, x) for x in cver])
                     )
                 )
 
     # Find packages that did not match anything
-    not_matched = \
-        set(names) - set(matches) - set(full_matches) - set(ambiguous)
+    not_matched = set(names) - set(matches) - set(full_matches) - set(ambiguous)
     for name in not_matched:
-        errors.append('Package \'{0}\' not found'.format(name))
+        errors.append("Package '{}' not found".format(name))
 
     return matches + full_matches, errors
 
 
 def latest_version(*names, **kwargs):
-    '''
+    """
     ``pkg_add(1)`` is not capable of querying for remote packages, so this
     function will always return results as if there is no package available for
     install or upgrade.
@@ -194,15 +203,18 @@ def latest_version(*names, **kwargs):
 
         salt '*' pkg.latest_version <package name>
         salt '*' pkg.latest_version <package1> <package2> <package3> ...
-    '''
-    return '' if len(names) == 1 else dict((x, '') for x in names)
+    """
+    return "" if len(names) == 1 else {x: "" for x in names}
+
 
 # available_version is being deprecated
-available_version = salt.utils.alias_function(latest_version, 'available_version')
+available_version = salt.utils.functools.alias_function(
+    latest_version, "available_version"
+)
 
 
 def version(*names, **kwargs):
-    '''
+    """
     Returns a string representing the package version or an empty string if not
     installed. If more than one package name is specified, a dict of
     name/version pairs is returned.
@@ -213,30 +225,26 @@ def version(*names, **kwargs):
 
         .. versionadded:: 2014.1.0
 
-
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' pkg.version <package name>
         salt '*' pkg.version <package1> <package2> <package3> ...
-    '''
-    with_origin = kwargs.pop('with_origin', False)
-    ret = __salt__['pkg_resource.version'](*names, **kwargs)
-    if not salt.utils.is_true(with_origin):
+    """
+    with_origin = kwargs.pop("with_origin", False)
+    ret = __salt__["pkg_resource.version"](*names, **kwargs)
+    if not salt.utils.data.is_true(with_origin):
         return ret
     # Put the return value back into a dict since we're adding a subdict
     if len(names) == 1:
         ret = {names[0]: ret}
-    origins = __context__.get('pkg.origin', {})
-    return dict([
-        (x, {'origin': origins.get(x, ''), 'version': y})
-        for x, y in six.iteritems(ret)
-    ])
+    origins = __context__.get("pkg.origin", {})
+    return {x: {"origin": origins.get(x, ""), "version": y} for x, y in ret.items()}
 
 
-def refresh_db():
-    '''
+def refresh_db(**kwargs):
+    """
     ``pkg_add(1)`` does not use a local database of available packages, so this
     function simply returns ``True``. it exists merely for API compatibility.
 
@@ -245,12 +253,27 @@ def refresh_db():
     .. code-block:: bash
 
         salt '*' pkg.refresh_db
-    '''
+    """
+    # Remove rtag file to keep multiple refreshes from happening in pkg states
+    salt.utils.pkg.clear_rtag(__opts__)
     return True
 
 
+def _list_pkgs_from_context(versions_as_list, with_origin):
+    """
+    Use pkg list from __context__
+    """
+    ret = copy.deepcopy(__context__["pkg.list_pkgs"])
+    if not versions_as_list:
+        __salt__["pkg_resource.stringify"](ret)
+    if salt.utils.data.is_true(with_origin):
+        origins = __context__.get("pkg.origin", {})
+        return {x: {"origin": origins.get(x, ""), "version": y} for x, y in ret.items()}
+    return ret
+
+
 def list_pkgs(versions_as_list=False, with_origin=False, **kwargs):
-    '''
+    """
     List the packages currently installed as a dict::
 
         {'<package_name>': '<version>'}
@@ -266,61 +289,45 @@ def list_pkgs(versions_as_list=False, with_origin=False, **kwargs):
     .. code-block:: bash
 
         salt '*' pkg.list_pkgs
-    '''
-    versions_as_list = salt.utils.is_true(versions_as_list)
+    """
+    versions_as_list = salt.utils.data.is_true(versions_as_list)
     # not yet implemented or not applicable
-    if any([salt.utils.is_true(kwargs.get(x))
-            for x in ('removed', 'purge_desired')]):
+    if any(
+        [salt.utils.data.is_true(kwargs.get(x)) for x in ("removed", "purge_desired")]
+    ):
         return {}
 
-    if 'pkg.list_pkgs' in __context__:
-        ret = copy.deepcopy(__context__['pkg.list_pkgs'])
-        if not versions_as_list:
-            __salt__['pkg_resource.stringify'](ret)
-        if salt.utils.is_true(with_origin):
-            origins = __context__.get('pkg.origin', {})
-            return dict([
-                (x, {'origin': origins.get(x, ''), 'version': y})
-                for x, y in six.iteritems(ret)
-            ])
-        return ret
+    if "pkg.list_pkgs" in __context__ and kwargs.get("use_context", True):
+        return _list_pkgs_from_context(versions_as_list, with_origin)
 
     ret = {}
     origins = {}
-    out = __salt__['cmd.run_stdout'](['pkg_info', '-ao'],
-                                     output_loglevel='trace',
-                                     python_shell=False)
-    pkgs_re = re.compile(r'Information for ([^:]+):\s*Origin:\n([^\n]+)')
+    out = __salt__["cmd.run_stdout"](
+        ["pkg_info", "-ao"], output_loglevel="trace", python_shell=False
+    )
+    pkgs_re = re.compile(r"Information for ([^:]+):\s*Origin:\n([^\n]+)")
     for pkg, origin in pkgs_re.findall(out):
         if not pkg:
             continue
         try:
-            pkgname, pkgver = pkg.rsplit('-', 1)
+            pkgname, pkgver = pkg.rsplit("-", 1)
         except ValueError:
             continue
-        __salt__['pkg_resource.add_pkg'](ret, pkgname, pkgver)
+        __salt__["pkg_resource.add_pkg"](ret, pkgname, pkgver)
         origins[pkgname] = origin
 
-    __salt__['pkg_resource.sort_pkglist'](ret)
-    __context__['pkg.list_pkgs'] = copy.deepcopy(ret)
-    __context__['pkg.origin'] = origins
+    __salt__["pkg_resource.sort_pkglist"](ret)
+    __context__["pkg.list_pkgs"] = copy.deepcopy(ret)
+    __context__["pkg.origin"] = origins
     if not versions_as_list:
-        __salt__['pkg_resource.stringify'](ret)
-    if salt.utils.is_true(with_origin):
-        return dict([
-            (x, {'origin': origins.get(x, ''), 'version': y})
-            for x, y in six.iteritems(ret)
-        ])
+        __salt__["pkg_resource.stringify"](ret)
+    if salt.utils.data.is_true(with_origin):
+        return {x: {"origin": origins.get(x, ""), "version": y} for x, y in ret.items()}
     return ret
 
 
-def install(name=None,
-            refresh=False,
-            fromrepo=None,
-            pkgs=None,
-            sources=None,
-            **kwargs):
-    '''
+def install(name=None, refresh=False, fromrepo=None, pkgs=None, sources=None, **kwargs):
+    """
     Install package(s) using ``pkg_add(1)``
 
     name
@@ -371,9 +378,9 @@ def install(name=None,
     .. code-block:: bash
 
         salt '*' pkg.install <package name>
-    '''
+    """
     try:
-        pkg_params, pkg_type = __salt__['pkg_resource.parse_targets'](
+        pkg_params, pkg_type = __salt__["pkg_resource.parse_targets"](
             name, pkgs, sources, **kwargs
         )
     except MinionError as exc:
@@ -382,60 +389,43 @@ def install(name=None,
     if not pkg_params:
         return {}
 
-    packageroot = kwargs.get('packageroot')
+    packageroot = kwargs.get("packageroot")
     if not fromrepo and packageroot:
         fromrepo = packageroot
 
-    env = _get_repo_options(fromrepo, kwargs.get('packagesite'))
+    env = _get_repo_options(fromrepo, kwargs.get("packagesite"))
     args = []
 
-    if pkg_type == 'repository':
-        args.append('-r')  # use remote repo
+    if pkg_type == "repository":
+        args.append("-r")  # use remote repo
 
     args.extend(pkg_params)
 
     old = list_pkgs()
-    out = __salt__['cmd.run_all'](
-        ['pkg_add'] + args,
-        env=env,
-        output_loglevel='trace',
-        python_shell=False
+    out = __salt__["cmd.run_all"](
+        ["pkg_add"] + args, env=env, output_loglevel="trace", python_shell=False
     )
-    if out['retcode'] != 0 and out['stderr']:
-        errors = [out['stderr']]
+    if out["retcode"] != 0 and out["stderr"]:
+        errors = [out["stderr"]]
     else:
         errors = []
 
-    __context__.pop('pkg.list_pkgs', None)
+    __context__.pop("pkg.list_pkgs", None)
     new = list_pkgs()
     _rehash()
-    ret = salt.utils.compare_dicts(old, new)
+    ret = salt.utils.data.compare_dicts(old, new)
 
     if errors:
         raise CommandExecutionError(
-            'Problem encountered installing package(s)',
-            info={'errors': errors, 'changes': ret}
+            "Problem encountered installing package(s)",
+            info={"errors": errors, "changes": ret},
         )
 
     return ret
 
 
-def upgrade():
-    '''
-    Upgrades are not supported with ``pkg_add(1)``. This function is included
-    for API compatibility only and always returns an empty dict.
-
-    CLI Example:
-
-    .. code-block:: bash
-
-        salt '*' pkg.upgrade
-    '''
-    return {}
-
-
 def remove(name=None, pkgs=None, **kwargs):
-    '''
+    """
     Remove packages using ``pkg_delete(1)``
 
     name
@@ -460,9 +450,9 @@ def remove(name=None, pkgs=None, **kwargs):
         salt '*' pkg.remove <package name>
         salt '*' pkg.remove <package1>,<package2>,<package3>
         salt '*' pkg.remove pkgs='["foo", "bar"]'
-    '''
+    """
     try:
-        pkg_params = __salt__['pkg_resource.parse_targets'](name, pkgs)[0]
+        pkg_params = __salt__["pkg_resource.parse_targets"](name, pkgs)[0]
     except MinionError as exc:
         raise CommandExecutionError(exc)
 
@@ -473,46 +463,45 @@ def remove(name=None, pkgs=None, **kwargs):
     if not targets:
         return {}
 
-    out = __salt__['cmd.run_all'](
-        ['pkg_delete'] + targets,
-        output_loglevel='trace',
-        python_shell=False
+    out = __salt__["cmd.run_all"](
+        ["pkg_delete"] + targets, output_loglevel="trace", python_shell=False
     )
-    if out['retcode'] != 0 and out['stderr']:
-        errors = [out['stderr']]
+    if out["retcode"] != 0 and out["stderr"]:
+        errors = [out["stderr"]]
     else:
         errors = []
 
-    __context__.pop('pkg.list_pkgs', None)
+    __context__.pop("pkg.list_pkgs", None)
     new = list_pkgs()
-    ret = salt.utils.compare_dicts(old, new)
+    ret = salt.utils.data.compare_dicts(old, new)
 
     if errors:
         raise CommandExecutionError(
-            'Problem encountered removing package(s)',
-            info={'errors': errors, 'changes': ret}
+            "Problem encountered removing package(s)",
+            info={"errors": errors, "changes": ret},
         )
 
     return ret
 
+
 # Support pkg.delete to remove packages to more closely match pkg_delete
-delete = salt.utils.alias_function(remove, 'delete')
+delete = salt.utils.functools.alias_function(remove, "delete")
 # No equivalent to purge packages, use remove instead
-purge = salt.utils.alias_function(remove, 'purge')
+purge = salt.utils.functools.alias_function(remove, "purge")
 
 
 def _rehash():
-    '''
+    """
     Recomputes internal hash table for the PATH variable. Use whenever a new
     command is created during the current session.
-    '''
-    shell = __salt__['environ.get']('SHELL')
-    if shell.split('/')[-1] in ('csh', 'tcsh'):
-        __salt__['cmd.shell']('rehash', output_loglevel='trace')
+    """
+    shell = __salt__["environ.get"]("SHELL")
+    if shell.split("/")[-1] in ("csh", "tcsh"):
+        __salt__["cmd.shell"]("rehash", output_loglevel="trace")
 
 
-def file_list(*packages):
-    '''
+def file_list(*packages, **kwargs):
+    """
     List the files that belong to a package. Not specifying any packages will
     return a list of _every_ file on the system's package database (not
     generally recommended).
@@ -524,17 +513,17 @@ def file_list(*packages):
         salt '*' pkg.file_list httpd
         salt '*' pkg.file_list httpd postfix
         salt '*' pkg.file_list
-    '''
+    """
     ret = file_dict(*packages)
     files = []
-    for pkg_files in six.itervalues(ret['files']):
+    for pkg_files in ret["files"].values():
         files.extend(pkg_files)
-    ret['files'] = files
+    ret["files"] = files
     return ret
 
 
-def file_dict(*packages):
-    '''
+def file_dict(*packages, **kwargs):
+    """
     List the files that belong to a package, grouped by package. Not
     specifying any packages will return a list of _every_ file on the
     system's package database (not generally recommended).
@@ -546,32 +535,30 @@ def file_dict(*packages):
         salt '*' pkg.file_list httpd
         salt '*' pkg.file_list httpd postfix
         salt '*' pkg.file_list
-    '''
+    """
     errors = []
     files = {}
 
     if packages:
-        match_pattern = '\'{0}-[0-9]*\''
-        cmd = ['pkg_info', '-QL'] + [match_pattern.format(p) for p in packages]
+        match_pattern = "'{0}-[0-9]*'"
+        cmd = ["pkg_info", "-QL"] + [match_pattern.format(p) for p in packages]
     else:
-        cmd = ['pkg_info', '-QLa']
+        cmd = ["pkg_info", "-QLa"]
 
-    ret = __salt__['cmd.run_all'](cmd,
-                                  output_loglevel='trace',
-                                  python_shell=False)
+    ret = __salt__["cmd.run_all"](cmd, output_loglevel="trace", python_shell=False)
 
-    for line in ret['stderr'].splitlines():
+    for line in ret["stderr"].splitlines():
         errors.append(line)
 
     pkg = None
-    for line in ret['stdout'].splitlines():
-        if pkg is not None and line.startswith('/'):
+    for line in ret["stdout"].splitlines():
+        if pkg is not None and line.startswith("/"):
             files[pkg].append(line)
-        elif ':/' in line:
-            pkg, fn = line.split(':', 1)
-            pkg, ver = pkg.rsplit('-', 1)
+        elif ":/" in line:
+            pkg, fn = line.split(":", 1)
+            pkg, ver = pkg.rsplit("-", 1)
             files[pkg] = [fn]
         else:
             continue  # unexpected string
 
-    return {'errors': errors, 'files': files}
+    return {"errors": errors, "files": files}
