@@ -11,7 +11,6 @@ Sign, encrypt and sign plus encrypt text and files.
 
 """
 
-
 import functools
 import logging
 import os
@@ -24,7 +23,6 @@ import salt.utils.stringutils
 from salt.exceptions import SaltInvocationError
 from salt.utils.versions import LooseVersion as _LooseVersion
 
-# Set up logging
 log = logging.getLogger(__name__)
 
 # Define the module's virtual name
@@ -91,8 +89,7 @@ def __virtual__():
     if not _gpg():
         return (
             False,
-            "The gpg execution module cannot be loaded: "
-            "gpg binary is not in the path.",
+            "The gpg execution module cannot be loaded: gpg binary is not in the path.",
         )
 
     return (
@@ -100,8 +97,7 @@ def __virtual__():
         if HAS_GPG_BINDINGS
         else (
             False,
-            "The gpg execution module cannot be loaded; the "
-            "gnupg python module is not installed.",
+            "The gpg execution module cannot be loaded; the gnupg python module is not installed.",
         )
     )
 
@@ -111,7 +107,7 @@ def _get_user_info(user=None):
     Wrapper for user.info Salt function
     """
     if not user:
-        # Get user Salt runnining as
+        # Get user Salt running as
         user = __salt__["config.option"]("user")
 
     userinfo = __salt__["user.info"](user)
