@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 NAPALM Probes
 =============
@@ -22,12 +21,8 @@ Dependencies
 .. versionadded:: 2016.11.0
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import python lib
 import logging
 
-# import NAPALM utils
 import salt.utils.napalm
 from salt.utils.napalm import proxy_napalm_wrap
 
@@ -114,7 +109,6 @@ def results(**kwargs):  # pylint: disable=unused-argument
 
     :return a dictionary with the results of the probes.
 
-
     CLI Example:
 
     .. code-block:: bash
