@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Module to provide Citrix Netscaler compatibility to Salt (compatible with netscaler 9.2+)
 
@@ -28,13 +27,16 @@ Module to provide Citrix Netscaler compatibility to Salt (compatible with netsca
     This data can also be passed into pillar. Options passed into opts will
     overwrite options passed into pillar.
 
-:CLI Examples:
+CLI Examples:
+
     Calls relying on configuration passed using /etc/salt/minion, grains, or pillars:
+
     .. code-block:: bash
 
         salt-call netscaler.server_exists server_name
 
     Calls passing configuration as opts
+
     .. code-block:: bash
 
         salt-call netscaler.server_exists server_name netscaler_host=1.2.3.4 netscaler_user=username netscaler_pass=password
@@ -43,12 +45,9 @@ Module to provide Citrix Netscaler compatibility to Salt (compatible with netsca
         salt-call netscaler.server_up server_name3 netscaler_host=1.2.3.6 netscaler_useSSL=False
 
 """
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 
-# Import Salt libs
 import salt.utils.platform
 
 try:
@@ -120,7 +119,7 @@ def _connect(**kwargs):
                     name = name[len(prefix) :]
                 except IndexError:
                     return
-            val = __salt__["config.option"]("netscaler.{0}".format(name), None)
+            val = __salt__["config.option"]("netscaler.{}".format(name), None)
             if val is not None:
                 connargs[key] = val
             elif default is not None:
@@ -480,7 +479,6 @@ def service_enable(s_name, **connection_args):
     """
     Enable a service
 
-
     CLI Example:
 
     .. code-block:: bash
