@@ -1,5 +1,5 @@
 # encoding: utf-8
-'''
+"""
 A minimalist REST API for Salt
 ==============================
 
@@ -120,8 +120,9 @@ Usage examples
 :status 200: success
 :status 401: authentication required
 
-'''
+"""
 from __future__ import absolute_import, print_function, unicode_literals
+
 import errno
 import logging
 import os
@@ -133,16 +134,16 @@ import salt.utils.json
 
 # HTTP response codes to response headers map
 H = {
-    200: '200 OK',
-    400: '400 BAD REQUEST',
-    401: '401 UNAUTHORIZED',
-    404: '404 NOT FOUND',
-    405: '405 METHOD NOT ALLOWED',
-    406: '406 NOT ACCEPTABLE',
-    500: '500 INTERNAL SERVER ERROR',
+    200: "200 OK",
+    400: "400 BAD REQUEST",
+    401: "401 UNAUTHORIZED",
+    404: "404 NOT FOUND",
+    405: "405 METHOD NOT ALLOWED",
+    406: "406 NOT ACCEPTABLE",
+    500: "500 INTERNAL SERVER ERROR",
 }
 
-__virtualname__ = 'rest_wsgi'
+__virtualname__ = "rest_wsgi"
 
 logger = logging.getLogger(__virtualname__)
 
@@ -150,26 +151,27 @@ logger = logging.getLogger(__virtualname__)
 def __virtual__():
     mod_opts = __opts__.get(__virtualname__, {})
 
-    if 'port' in mod_opts:
+    if "port" in mod_opts:
         return __virtualname__
 
     return False
 
 
 class HTTPError(Exception):
-    '''
+    """
     A custom exception that can take action based on an HTTP error code
-    '''
+    """
+
     def __init__(self, code, message):
         self.code = code
-        Exception.__init__(self, '{0}: {1}'.format(code, message))
+        Exception.__init__(self, "{0}: {1}".format(code, message))
 
 
 def mkdir_p(path):
-    '''
+    """
     mkdir -p
     http://stackoverflow.com/a/600612/127816
-    '''
+    """
     try:
         os.makedirs(path)
     except OSError as exc:  # Python >2.5
@@ -180,22 +182,22 @@ def mkdir_p(path):
 
 
 def read_body(environ):
-    '''
+    """
     Pull the body from the request and return it
-    '''
-    length = environ.get('CONTENT_LENGTH', '0')
-    length = 0 if length == '' else int(length)
+    """
+    length = environ.get("CONTENT_LENGTH", "0")
+    length = 0 if length == "" else int(length)
 
-    return environ['wsgi.input'].read(length)
+    return environ["wsgi.input"].read(length)
 
 
 def get_json(environ):
-    '''
+    """
     Return the request body as JSON
-    '''
-    content_type = environ.get('CONTENT_TYPE', '')
-    if content_type != 'application/json':
-        raise HTTPError(406, 'JSON required')
+    """
+    content_type = environ.get("CONTENT_TYPE", "")
+    if content_type != "application/json":
+        raise HTTPError(406, "JSON required")
 
     try:
         return salt.utils.json.loads(read_body(environ))
@@ -204,12 +206,12 @@ def get_json(environ):
 
 
 def get_headers(data, extra_headers=None):
-    '''
+    """
     Takes the response data as well as any additional headers and returns a
     tuple of tuples of headers suitable for passing to start_response()
-    '''
+    """
     response_headers = {
-        'Content-Length': str(len(data)),
+        "Content-Length": str(len(data)),
     }
 
     if extra_headers:
@@ -219,51 +221,54 @@ def get_headers(data, extra_headers=None):
 
 
 def run_chunk(environ, lowstate):
-    '''
+    """
     Expects a list of lowstate dictionaries that are executed and returned in
     order
-    '''
-    client = environ['SALT_APIClient']
+    """
+    client = environ["SALT_APIClient"]
 
     for chunk in lowstate:
         yield client.run(chunk)
 
 
 def dispatch(environ):
-    '''
+    """
     Do any path/method dispatching here and return a JSON-serializable data
     structure appropriate for the response
-    '''
-    method = environ['REQUEST_METHOD'].upper()
+    """
+    method = environ["REQUEST_METHOD"].upper()
 
-    if method == 'GET':
-        return ("They found me. I don't know how, but they found me. "
-                "Run for it, Marty!")
-    elif method == 'POST':
+    if method == "GET":
+        return (
+            "They found me. I don't know how, but they found me. " "Run for it, Marty!"
+        )
+    elif method == "POST":
         data = get_json(environ)
         return run_chunk(environ, data)
     else:
-        raise HTTPError(405, 'Method Not Allowed')
+        raise HTTPError(405, "Method Not Allowed")
 
 
 def saltenviron(environ):
-    '''
+    """
     Make Salt's opts dict and the APIClient available in the WSGI environ
-    '''
-    if '__opts__' not in locals():
+    """
+    if "__opts__" not in locals():
         import salt.config
-        __opts__ = salt.config.client_config(
-                os.environ.get('SALT_MASTER_CONFIG', '/etc/salt/master'))
 
-    environ['SALT_OPTS'] = __opts__
-    environ['SALT_APIClient'] = salt.netapi.NetapiClient(__opts__)
+        __opts__ = salt.config.client_config(
+            os.environ.get("SALT_MASTER_CONFIG", "/etc/salt/master")
+        )
+
+    environ["SALT_OPTS"] = __opts__
+    environ["SALT_APIClient"] = salt.netapi.NetapiClient(__opts__)
 
 
 def application(environ, start_response):
-    '''
+    """
     Process the request and return a JSON response. Catch errors and return the
     appropriate HTTP code.
-    '''
+    """
     # Instantiate APIClient once for the whole app
     saltenviron(environ)
 
@@ -277,43 +282,42 @@ def application(environ, start_response):
     except salt.exceptions.EauthAuthenticationError as exc:
         code = 401
         resp = str(exc)
-    except Exception as exc:
+    except Exception as exc:  # pylint: disable=broad-except
         code = 500
         resp = str(exc)
 
     # Convert the response to JSON
     try:
-        ret = salt.utils.json.dumps({'return': resp})
+        ret = salt.utils.json.dumps({"return": resp})
     except TypeError as exc:
         code = 500
         ret = str(exc)  # future lint: disable=blacklisted-function
 
     # Return the response
-    start_response(H[code], get_headers(ret, {
-        'Content-Type': 'application/json',
-    }))
+    start_response(H[code], get_headers(ret, {"Content-Type": "application/json"}))
     return (ret,)
 
 
 def get_opts():
-    '''
+    """
     Return the Salt master config as __opts__
-    '''
+    """
     import salt.config
 
     return salt.config.client_config(
-            os.environ.get('SALT_MASTER_CONFIG', '/etc/salt/master'))
+        os.environ.get("SALT_MASTER_CONFIG", "/etc/salt/master")
+    )
 
 
 def start():
-    '''
+    """
     Start simple_server()
-    '''
+    """
     from wsgiref.simple_server import make_server
 
     # When started outside of salt-api __opts__ will not be injected
-    if '__opts__' not in globals():
-        globals()['__opts__'] = get_opts()
+    if "__opts__" not in globals():
+        globals()["__opts__"] = get_opts()
 
         if __virtual__() is False:
             raise SystemExit(1)
@@ -321,7 +325,7 @@ def start():
     mod_opts = __opts__.get(__virtualname__, {})
 
     # pylint: disable=C0103
-    httpd = make_server('localhost', mod_opts['port'], application)
+    httpd = make_server("localhost", mod_opts["port"], application)
 
     try:
         httpd.serve_forever()
@@ -329,5 +333,5 @@ def start():
         raise SystemExit(0)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     start()
