@@ -1,16 +1,13 @@
-# -*- coding: utf-8 -*-
 """
 In-memory caching used by Salt
 """
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
+import functools
 import logging
 import os
 import re
 import time
 
-# Import salt libs
 import salt.config
 import salt.payload
 import salt.utils.atomicfile
@@ -18,15 +15,12 @@ import salt.utils.data
 import salt.utils.dictupdate
 import salt.utils.files
 import salt.utils.msgpack
-
-# Import third party libs
-from salt.ext.six.moves import range  # pylint: disable=import-error,redefined-builtin
 from salt.utils.zeromq import zmq
 
 log = logging.getLogger(__name__)
 
 
-class CacheFactory(object):
+class CacheFactory:
     """
     Cache which can use a number of backends
     """
@@ -89,7 +83,7 @@ class CacheDisk(CacheDict):
     """
 
     def __init__(self, ttl, path, *args, **kwargs):
-        super(CacheDisk, self).__init__(ttl, *args, **kwargs)
+        super().__init__(ttl, *args, **kwargs)
         self._path = path
         self._dict = {}
         self._read()
@@ -133,6 +127,15 @@ class CacheDisk(CacheDict):
         # Do the same as the parent but also persist
         self._write()
 
+    def clear(self):
+        """
+        Clear the cache
+        """
+        self._key_cache_time.clear()
+        self._dict.clear()
+        # Do the same as the parent but also persist
+        self._write()
+
     def _read(self):
         """
         Read in from disk
@@ -170,7 +173,7 @@ class CacheDisk(CacheDict):
             salt.utils.msgpack.dump(cache, fp_, use_bin_type=True)
 
 
-class CacheCli(object):
+class CacheCli:
     """
     Connection client for the ConCache. Should be used by all
     components that need the list of currently connected minions
@@ -213,7 +216,7 @@ class CacheCli(object):
         return min_list
 
 
-class CacheRegex(object):
+class CacheRegex:
     """
     Create a regular expression object cache for the most frequently
     used patterns to minimize compilation of the same patterns over
@@ -267,20 +270,18 @@ class CacheRegex(object):
             pass
         if len(self.cache) > self.size:
             self.sweep()
-        regex = re.compile("{0}{1}{2}".format(self.prepend, pattern, self.append))
+        regex = re.compile("{}{}{}".format(self.prepend, pattern, self.append))
         self.cache[pattern] = [1, regex, pattern, time.time()]
         return regex
 
 
-class ContextCache(object):
+class ContextCache:
     def __init__(self, opts, name):
         """
         Create a context cache
         """
         self.opts = opts
-        self.cache_path = os.path.join(
-            opts["cachedir"], "context", "{0}.p".format(name)
-        )
+        self.cache_path = os.path.join(opts["cachedir"], "context", "{}.p".format(name))
         self.serial = salt.payload.Serial(self.opts)
 
     def cache_context(self, context):
@@ -309,9 +310,16 @@ def context_cache(func):
     is empty or contains no items, pass a list of keys to evaulate.
     """
 
+    @functools.wraps(func)
     def context_cache_wrap(*args, **kwargs):
-        func_context = func.__globals__["__context__"]
-        func_opts = func.__globals__["__opts__"]
+        try:
+            func_context = func.__globals__["__context__"].value()
+        except AttributeError:
+            func_context = func.__globals__["__context__"]
+        try:
+            func_opts = func.__globals__["__opts__"].value()
+        except AttributeError:
+            func_opts = func.__globals__["__opts__"]
         func_name = func.__globals__["__name__"]
 
         context_cache = ContextCache(func_opts, func_name)
@@ -324,17 +332,3 @@ def context_cache(func):
         return func(*args, **kwargs)
 
     return context_cache_wrap
-
-
-# test code for the CacheCli
-if __name__ == "__main__":
-
-    opts = salt.config.master_config("/etc/salt/master")
-
-    ccli = CacheCli(opts)
-
-    ccli.put_cache(["test1", "test10", "test34"])
-    ccli.put_cache(["test12"])
-    ccli.put_cache(["test18"])
-    ccli.put_cache(["test21"])
-    print("minions: {0}".format(ccli.get_cached()))
