@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Utils for the NAPALM modules and proxy.
 
@@ -15,8 +14,6 @@ Utils for the NAPALM modules and proxy.
 .. versionadded:: 2017.7.0
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import copy
 import importlib
@@ -28,10 +25,6 @@ import salt.output
 import salt.utils.args
 import salt.utils.platform
 
-# Import Salt libs
-from salt.ext import six
-
-# Import third party libs
 try:
     # will try to import NAPALM
     # https://github.com/napalm-automation/napalm
@@ -170,7 +163,7 @@ def call(napalm_device, method, *args, **kwargs):
         # if connected will try to execute desired command
         kwargs_copy = {}
         kwargs_copy.update(kwargs)
-        for karg, warg in six.iteritems(kwargs_copy):
+        for karg, warg in kwargs_copy.items():
             # lets clear None arguments
             # to not be sent to NAPALM methods
             if warg is None:
@@ -427,7 +420,7 @@ def proxy_napalm_wrap(func):
                 except napalm_base.exceptions.ConnectionException as nce:
                     log.error(nce)
                     return "{base_msg}. See log for details.".format(
-                        base_msg=six.text_type(nce.msg)
+                        base_msg=str(nce.msg)
                     )
             else:
                 # in case the `inherit_napalm_device` is set
@@ -496,7 +489,7 @@ def proxy_napalm_wrap(func):
                 except napalm_base.exceptions.ConnectionException as nce:
                     log.error(nce)
                     return "{base_msg}. See log for details.".format(
-                        base_msg=six.text_type(nce.msg)
+                        base_msg=str(nce.msg)
                     )
             else:
                 # in case the `inherit_napalm_device` is set
