@@ -1,22 +1,13 @@
-# -*- coding: utf-8 -*-
 """
 Neutron class
 """
 
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals, with_statement
-
 import logging
 
 import salt.utils.versions
-
-# Import salt libs
 from salt import exceptions
 
-# Import third party libs
-from salt.ext import six
-
 # pylint: disable=import-error
 HAS_NEUTRON = False
 try:
@@ -73,7 +64,7 @@ def sanitize_neutronclient(kwargs):
         "auth",
     )
     ret = {}
-    for var in six.iterkeys(kwargs):
+    for var in kwargs.keys():
         if var in variables:
             ret[var] = kwargs[var]
 
@@ -103,7 +94,7 @@ class SaltNeutron(NeutronShell):
         Set up neutron credentials
         """
         salt.utils.versions.warn_until(
-            "Aluminium",
+            "Sulfur",
             (
                 "The neutron module has been deprecated and will be removed in {version}.  "
                 "Please update to using the neutronng module"
