@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # Import Python libs
-from __future__ import absolute_import, unicode_literals, print_function
+from __future__ import absolute_import, print_function, unicode_literals
 
 # pylint: disable=import-error
 try:
@@ -9,10 +9,7 @@ try:
     from salt.utils.openstack.pyrax.authenticate import Authenticate
     from salt.utils.openstack.pyrax.queues import RackspaceQueues
 
-    __all__ = [
-        'Authenticate',
-        'RackspaceQueues'
-    ]
+    __all__ = ["Authenticate", "RackspaceQueues"]
 
     HAS_PYRAX = True
 except ImportError as err:
