@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # See doc/topics/jobs/index.rst
 """
 Scheduling routines are located here. To activate the scheduler make the
@@ -10,8 +8,6 @@ Detailed tutorial about scheduling jobs can be found :ref:`here
 <scheduling-jobs>`.
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals, with_statement
 
 import copy
 import datetime
@@ -26,7 +22,6 @@ import threading
 import time
 import weakref
 
-# Import Salt libs
 import salt.config
 import salt.defaults.exitcodes
 import salt.exceptions
@@ -47,8 +42,6 @@ import salt.utils.stringutils
 import salt.utils.user
 import salt.utils.yaml
 from salt.exceptions import SaltInvocationError
-
-# Import 3rd-party libs
 from salt.ext import six
 from salt.utils.odict import OrderedDict
 
@@ -73,7 +66,7 @@ except ImportError:
 log = logging.getLogger(__name__)
 
 
-class Schedule(object):
+class Schedule:
     """
     Create a Schedule object, pass in the opts and the functions dict to use
     """
@@ -91,6 +84,7 @@ class Schedule(object):
         standalone=False,
         new_instance=False,
         utils=None,
+        _subprocess_list=None,
     ):
         """
         Only create one instance of Schedule
@@ -110,6 +104,7 @@ class Schedule(object):
                 proxy=proxy,
                 standalone=standalone,
                 utils=utils,
+                _subprocess_list=_subprocess_list,
             )
             if new_instance is True:
                 return instance
@@ -130,6 +125,7 @@ class Schedule(object):
         standalone=False,
         new_instance=False,
         utils=None,
+        _subprocess_list=None,
     ):
         pass
 
@@ -164,7 +160,18 @@ class Schedule(object):
                 self.returners = returners
             else:
                 self.returners = returners.loader.gen_functions()
-        self.time_offset = self.functions.get("timezone.get_offset", lambda: "0000")()
+        try:
+            self.time_offset = self.functions.get(
+                "timezone.get_offset", lambda: "0000"
+            )()
+        except Exception:  # pylint: disable=W0703
+            # get_offset can fail, if that happens, default to 0000
+            log.warning(
+                "Unable to obtain correct timezone offset, defaulting to 0000",
+                exc_info_on_loglevel=logging.DEBUG,
+            )
+            self.time_offset = "0000"
+
         self.schedule_returner = self.option("schedule_returner")
         # Keep track of the lowest loop interval needed in this variable
         self.loop_interval = six.MAXSIZE
@@ -300,7 +307,7 @@ class Schedule(object):
                         salt.utils.yaml.safe_dump({"schedule": schedule_data})
                     )
                 )
-        except (IOError, OSError):
+        except OSError:
             log.error(
                 "Failed to persist the updated schedule",
                 exc_info_on_loglevel=logging.DEBUG,
@@ -387,7 +394,7 @@ class Schedule(object):
             if "enabled" not in data[job]:
                 data[job]["enabled"] = True
 
-        new_job = next(six.iterkeys(data))
+        new_job = next(iter(data.keys()))
 
         if new_job in self._get_schedule(include_opts=False):
             log.warning("Cannot update job %s, it's in the pillar!", new_job)
@@ -651,15 +658,28 @@ class Schedule(object):
                 tag="/salt/minion/minion_schedule_next_fire_time_complete",
             )
 
-    def job_status(self, name):
+    def job_status(self, name, fire_event=False):
         """
         Return the specified schedule item
         """
 
-        schedule = self._get_schedule()
-        return schedule.get(name, {})
+        if fire_event:
+            schedule = self._get_schedule()
+            data = schedule.get(name, {})
 
-    def handle_func(self, multiprocessing_enabled, func, data):
+            # Fire the complete event back along with updated list of schedule
+            with salt.utils.event.get_event(
+                "minion", opts=self.opts, listen=False
+            ) as evt:
+                evt.fire_event(
+                    {"complete": True, "data": data},
+                    tag="/salt/minion/minion_schedule_job_status_complete",
+                )
+        else:
+            schedule = self._get_schedule()
+            return schedule.get(name, {})
+
+    def handle_func(self, multiprocessing_enabled, func, data, jid=None):
         """
         Execute this method in a multiprocess or thread
         """
@@ -670,6 +690,7 @@ class Schedule(object):
             # This also needed for ZeroMQ transport to reset all functions
             # context data that could keep paretns connections. ZeroMQ will
             # hang on polling parents connections from the child process.
+            self.utils = salt.loader.utils(self.opts)
             if self.opts["__role"] == "master":
                 self.functions = salt.loader.runner(self.opts, utils=self.utils)
             else:
@@ -679,12 +700,14 @@ class Schedule(object):
             self.returners = salt.loader.returners(
                 self.opts, self.functions, proxy=self.proxy
             )
+        if jid is None:
+            jid = salt.utils.jid.gen_jid(self.opts)
         ret = {
             "id": self.opts.get("id", "master"),
             "fun": func,
             "fun_args": [],
             "schedule": data["name"],
-            "jid": salt.utils.jid.gen_jid(self.opts),
+            "jid": jid,
         }
 
         if "metadata" in data:
@@ -704,7 +727,7 @@ class Schedule(object):
         if multiprocessing_enabled:
             # We just want to modify the process name if we're on a different process
             salt.utils.process.appendproctitle(
-                "{0} {1}".format(self.__class__.__name__, ret["jid"])
+                "{} {}".format(self.__class__.__name__, ret["jid"])
             )
         data_returner = data.get("returner", None)
 
@@ -739,17 +762,6 @@ class Schedule(object):
 
             ret["pid"] = os.getpid()
 
-            if not self.standalone:
-                if "jid_include" not in data or data["jid_include"]:
-                    log.debug(
-                        "schedule.handle_func: adding this job to the "
-                        "jobcache with data %s",
-                        ret,
-                    )
-                    # write this to /var/cache/salt/minion/proc
-                    with salt.utils.files.fopen(proc_fn, "w+b") as fp_:
-                        fp_.write(salt.payload.Serial(self.opts).dumps(ret))
-
             args = tuple()
             if "args" in data:
                 args = copy.deepcopy(data["args"])
@@ -766,14 +778,25 @@ class Schedule(object):
                     message=self.functions.missing_fun_string(func)
                 )
 
+            if not self.standalone:
+                if "jid_include" not in data or data["jid_include"]:
+                    log.debug(
+                        "schedule.handle_func: adding this job to the "
+                        "jobcache with data %s",
+                        ret,
+                    )
+                    # write this to /var/cache/salt/minion/proc
+                    with salt.utils.files.fopen(proc_fn, "w+b") as fp_:
+                        fp_.write(salt.payload.Serial(self.opts).dumps(ret))
+
             # if the func support **kwargs, lets pack in the pub data we have
             # TODO: pack the *same* pub data as a minion?
             argspec = salt.utils.args.get_function_argspec(self.functions[func])
             if argspec.keywords:
                 # this function accepts **kwargs, pack in the publish data
-                for key, val in six.iteritems(ret):
+                for key, val in ret.items():
                     if key != "kwargs":
-                        kwargs["__pub_{0}".format(key)] = copy.deepcopy(val)
+                        kwargs["__pub_{}".format(key)] = copy.deepcopy(val)
 
             # Only include these when running runner modules
             if self.opts["__role"] == "master":
@@ -805,14 +828,14 @@ class Schedule(object):
                 # namespace only once per module-- not per func
                 completed_funcs = []
 
-                for mod_name in six.iterkeys(self_functions):
+                for mod_name in self_functions.keys():
                     if "." not in mod_name:
                         continue
                     mod, _ = mod_name.split(".", 1)
                     if mod in completed_funcs:
                         continue
                     completed_funcs.append(mod)
-                    for global_key, value in six.iteritems(func_globals):
+                    for global_key, value in func_globals.items():
                         self.functions[mod_name].__globals__[global_key] = value
 
             self.functions.pack["__context__"]["retcode"] = 0
@@ -833,13 +856,13 @@ class Schedule(object):
                         ret["ret_kwargs"] = data["return_kwargs"]
                     rets = []
                     for returner in [data_returner, self.schedule_returner]:
-                        if isinstance(returner, six.string_types):
+                        if isinstance(returner, str):
                             rets.append(returner)
                         elif isinstance(returner, list):
                             rets.extend(returner)
                     # simple de-duplication with order retained
                     for returner in OrderedDict.fromkeys(rets):
-                        ret_str = "{0}.returner".format(returner)
+                        ret_str = "{}.returner".format(returner)
                         if ret_str in self.returners:
                             self.returners[ret_str](ret)
                         else:
@@ -855,7 +878,7 @@ class Schedule(object):
             # is to let the exception bubble up to the top of the thread context,
             # where the thread will die silently, which is worse.
             if "return" not in ret:
-                ret["return"] = "Unhandled exception running {0}".format(ret["fun"])
+                ret["return"] = "Unhandled exception running {}".format(ret["fun"])
             ret["success"] = False
             ret["retcode"] = 254
         finally:
@@ -876,7 +899,7 @@ class Schedule(object):
                             # this job shouldn't be stored
                             mret["jid"] = "nocache"
                     load = {"cmd": "_return", "id": self.opts["id"]}
-                    for key, value in six.iteritems(mret):
+                    for key, value in mret.items():
                         load[key] = value
 
                     if "__role" in self.opts and self.opts["__role"] == "minion":
@@ -929,6 +952,7 @@ class Schedule(object):
 
         log.trace("==== evaluating schedule now %s =====", now)
 
+        jids = []
         loop_interval = self.opts["loop_interval"]
         if not isinstance(loop_interval, datetime.timedelta):
             loop_interval = datetime.timedelta(seconds=loop_interval)
@@ -996,8 +1020,8 @@ class Schedule(object):
                     except (TypeError, ValueError):
                         data["_error"] = (
                             "Date string could not "
-                            "be parsed: {0}, {1}. "
-                            "Ignoring job {2}.".format(
+                            "be parsed: {}, {}. "
+                            "Ignoring job {}.".format(
                                 data["once"], once_fmt, data["name"]
                             )
                         )
@@ -1014,7 +1038,7 @@ class Schedule(object):
             Handle schedule item with when
             """
             if not _WHEN_SUPPORTED:
-                data["_error"] = "Missing python-dateutil. " "Ignoring job {0}.".format(
+                data["_error"] = "Missing python-dateutil. " "Ignoring job {}.".format(
                     data["name"]
                 )
                 log.error(data["_error"])
@@ -1036,7 +1060,7 @@ class Schedule(object):
                         data["_error"] = (
                             'Pillar item "whens" '
                             "must be a dict. "
-                            "Ignoring job {0}.".format(data["name"])
+                            "Ignoring job {}.".format(data["name"])
                         )
                         log.error(data["_error"])
                         return
@@ -1047,7 +1071,7 @@ class Schedule(object):
                     if not isinstance(self.opts["grains"]["whens"], dict):
                         data["_error"] = (
                             'Grain "whens" must be a dict. '
-                            "Ignoring job {0}.".format(data["name"])
+                            "Ignoring job {}.".format(data["name"])
                         )
                         log.error(data["_error"])
                         return
@@ -1060,8 +1084,8 @@ class Schedule(object):
                         when_ = dateutil_parser.parse(when_)
                     except ValueError:
                         data["_error"] = (
-                            "Invalid date string {0}. "
-                            "Ignoring job {1}.".format(i, data["name"])
+                            "Invalid date string {}. "
+                            "Ignoring job {}.".format(i, data["name"])
                         )
                         log.error(data["_error"])
                         return
@@ -1119,7 +1143,7 @@ class Schedule(object):
             Handle schedule item with cron
             """
             if not _CRON_SUPPORTED:
-                data["_error"] = "Missing python-croniter. " "Ignoring job {0}.".format(
+                data["_error"] = "Missing python-croniter. " "Ignoring job {}.".format(
                     data["name"]
                 )
                 log.error(data["_error"])
@@ -1136,7 +1160,7 @@ class Schedule(object):
                         data["cron"], now
                     ).get_next(datetime.datetime)
                 except (ValueError, KeyError):
-                    data["_error"] = "Invalid cron string. " "Ignoring job {0}.".format(
+                    data["_error"] = "Invalid cron string. " "Ignoring job {}.".format(
                         data["name"]
                     )
                     log.error(data["_error"])
@@ -1217,7 +1241,7 @@ class Schedule(object):
             Handle schedule item with skip_explicit
             """
             if not _RANGE_SUPPORTED:
-                data["_error"] = "Missing python-dateutil. " "Ignoring job {0}.".format(
+                data["_error"] = "Missing python-dateutil. " "Ignoring job {}.".format(
                     data["name"]
                 )
                 log.error(data["_error"])
@@ -1227,7 +1251,7 @@ class Schedule(object):
                 data["_error"] = (
                     "schedule.handle_func: Invalid, range "
                     "must be specified as a dictionary. "
-                    "Ignoring job {0}.".format(data["name"])
+                    "Ignoring job {}.".format(data["name"])
                 )
                 log.error(data["_error"])
                 return
@@ -1241,7 +1265,7 @@ class Schedule(object):
                     data["_error"] = (
                         "Invalid date string for start in "
                         "skip_during_range. Ignoring "
-                        "job {0}.".format(data["name"])
+                        "job {}.".format(data["name"])
                     )
                     log.error(data["_error"])
                     return
@@ -1253,7 +1277,7 @@ class Schedule(object):
                     data["_error"] = (
                         "Invalid date string for end in "
                         "skip_during_range. Ignoring "
-                        "job {0}.".format(data["name"])
+                        "job {}.".format(data["name"])
                     )
                     log.error(data["_error"])
                     return
@@ -1287,7 +1311,7 @@ class Schedule(object):
                 data["_error"] = (
                     "schedule.handle_func: Invalid "
                     "range, end must be larger than "
-                    "start. Ignoring job {0}.".format(data["name"])
+                    "start. Ignoring job {}.".format(data["name"])
                 )
                 log.error(data["_error"])
 
@@ -1296,7 +1320,7 @@ class Schedule(object):
             Handle schedule item with skip_explicit
             """
             if not _RANGE_SUPPORTED:
-                data["_error"] = "Missing python-dateutil. " "Ignoring job {0}".format(
+                data["_error"] = "Missing python-dateutil. " "Ignoring job {}".format(
                     data["name"]
                 )
                 log.error(data["_error"])
@@ -1306,7 +1330,7 @@ class Schedule(object):
                 data["_error"] = (
                     "schedule.handle_func: Invalid, range "
                     "must be specified as a dictionary."
-                    "Ignoring job {0}.".format(data["name"])
+                    "Ignoring job {}.".format(data["name"])
                 )
                 log.error(data["_error"])
                 return
@@ -1319,7 +1343,7 @@ class Schedule(object):
                 except ValueError:
                     data["_error"] = (
                         "Invalid date string for start. "
-                        "Ignoring job {0}.".format(data["name"])
+                        "Ignoring job {}.".format(data["name"])
                     )
                     log.error(data["_error"])
                     return
@@ -1330,7 +1354,7 @@ class Schedule(object):
                 except ValueError:
                     data["_error"] = (
                         "Invalid date string for end."
-                        " Ignoring job {0}.".format(data["name"])
+                        " Ignoring job {}.".format(data["name"])
                     )
                     log.error(data["_error"])
                     return
@@ -1356,7 +1380,7 @@ class Schedule(object):
                 data["_error"] = (
                     "schedule.handle_func: Invalid "
                     "range, end must be larger "
-                    "than start. Ignoring job {0}.".format(data["name"])
+                    "than start. Ignoring job {}.".format(data["name"])
                 )
                 log.error(data["_error"])
 
@@ -1365,7 +1389,7 @@ class Schedule(object):
             Handle schedule item with after
             """
             if not _WHEN_SUPPORTED:
-                data["_error"] = "Missing python-dateutil. " "Ignoring job {0}".format(
+                data["_error"] = "Missing python-dateutil. " "Ignoring job {}".format(
                     data["name"]
                 )
                 log.error(data["_error"])
@@ -1389,7 +1413,7 @@ class Schedule(object):
             Handle schedule item with until
             """
             if not _WHEN_SUPPORTED:
-                data["_error"] = "Missing python-dateutil. " "Ignoring job {0}".format(
+                data["_error"] = "Missing python-dateutil. " "Ignoring job {}".format(
                     data["name"]
                 )
                 log.error(data["_error"])
@@ -1427,7 +1451,7 @@ class Schedule(object):
             self.splay = schedule["splay"]
 
         _hidden = ["enabled", "skip_function", "skip_during_range", "splay"]
-        for job, data in six.iteritems(schedule):
+        for job, data in schedule.items():
 
             # Skip anything that is a global setting
             if job in _hidden:
@@ -1458,6 +1482,7 @@ class Schedule(object):
                     type(data),
                 )
                 continue
+
             if "function" in data:
                 func = data["function"]
             elif "func" in data:
@@ -1466,6 +1491,7 @@ class Schedule(object):
                 func = data["fun"]
             else:
                 func = None
+
             if func not in self.functions:
                 log.info("Invalid function: %s in scheduled job %s.", func, job_name)
 
@@ -1684,7 +1710,7 @@ class Schedule(object):
 
             miss_msg = ""
             if seconds < 0:
-                miss_msg = " (runtime missed " "by {0} seconds)".format(abs(seconds))
+                miss_msg = " (runtime missed " "by {} seconds)".format(abs(seconds))
 
             try:
                 if run:
@@ -1718,8 +1744,15 @@ class Schedule(object):
                 # Check run again, just in case _check_max_running
                 # set run to False
                 if run:
-                    log.info("Running scheduled job: %s%s", job_name, miss_msg)
-                    self._run_job(func, data)
+                    jid = salt.utils.jid.gen_jid(self.opts)
+                    jids.append(jid)
+                    log.info(
+                        "Running scheduled job: %s%s with jid %s",
+                        job_name,
+                        miss_msg,
+                        jid,
+                    )
+                    self._run_job(func, data, jid=jid)
 
             finally:
                 # Only set _last_run if the job ran
@@ -1739,8 +1772,9 @@ class Schedule(object):
                         data["_next_fire_time"] = now + datetime.timedelta(
                             seconds=data["_seconds"]
                         )
+        return jids
 
-    def _run_job(self, func, data):
+    def _run_job(self, func, data, jid=None):
         job_dry_run = data.get("dry_run", False)
         if job_dry_run:
             log.debug("Job %s has 'dry_run' set to True. Not running it.", data["name"])
@@ -1753,7 +1787,7 @@ class Schedule(object):
 
         if run_schedule_jobs_in_background is False:
             # Explicitly pass False for multiprocessing_enabled
-            self.handle_func(False, func, data)
+            self.handle_func(False, func, data, jid)
             return
 
         if multiprocessing_enabled and salt.utils.platform.is_windows():
@@ -1777,7 +1811,7 @@ class Schedule(object):
                 with salt.utils.process.default_signals(signal.SIGINT, signal.SIGTERM):
                     proc = thread_cls(
                         target=self.handle_func,
-                        args=(multiprocessing_enabled, func, data),
+                        args=(multiprocessing_enabled, func, data, jid),
                     )
                     # Reset current signals before starting the process in
                     # order not to inherit the current signal handlers
@@ -1786,7 +1820,8 @@ class Schedule(object):
                     self._subprocess_list.add(proc)
             else:
                 proc = thread_cls(
-                    target=self.handle_func, args=(multiprocessing_enabled, func, data)
+                    target=self.handle_func,
+                    args=(multiprocessing_enabled, func, data, jid),
                 )
                 proc.start()
                 proc.name = "{}-Schedule-{}".format(proc.name, data["name"])
