@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 Salt package
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 import importlib
 import sys
 import warnings
@@ -16,14 +13,25 @@ if sys.version_info < (3,):
     sys.stderr.flush()
 
 
-class TornadoImporter(object):
+USE_VENDORED_TORNADO = True
+
+
+class TornadoImporter:
     def find_module(self, module_name, package_path=None):
-        if module_name.startswith("tornado"):
-            return self
+        if USE_VENDORED_TORNADO:
+            if module_name.startswith("tornado"):
+                return self
+        else:
+            if module_name.startswith("salt.ext.tornado"):
+                return self
         return None
 
     def load_module(self, name):
-        mod = importlib.import_module("salt.ext.{}".format(name))
+        if USE_VENDORED_TORNADO:
+            mod = importlib.import_module("salt.ext.{}".format(name))
+        else:
+            # Remove 'salt.ext.' from the module
+            mod = importlib.import_module(name[9:])
         sys.modules[name] = mod
         return mod
 
@@ -38,13 +46,7 @@ warnings.filterwarnings(
     "",  # No deprecation message match
     DeprecationWarning,  # This filter is for DeprecationWarnings
     r"^(salt|salt\.(.*))$",  # Match module(s) 'salt' and 'salt.<whatever>'
-)
-
-# While we are supporting Python2.6, hide nested with-statements warnings
-warnings.filterwarnings(
-    "ignore",
-    "With-statements now directly support multiple context managers",
-    DeprecationWarning,
+    append=True,
 )
 
 # Filter the backports package UserWarning about being re-imported
@@ -52,6 +54,7 @@ warnings.filterwarnings(
     "ignore",
     "^Module backports was already imported from (.*), but (.*) is being added to sys.path$",
     UserWarning,
+    append=True,
 )
 
 
@@ -101,13 +104,7 @@ def __define_global_system_encoding_variable__():
                 # On linux default to ascii as a last resort
                 encoding = "ascii"
 
-    # We can't use six.moves.builtins because these builtins get deleted sooner
-    # than expected. See:
-    #    https://github.com/saltstack/salt/issues/21036
-    if sys.version_info[0] < 3:
-        import __builtin__ as builtins  # pylint: disable=incompatible-py3-code
-    else:
-        import builtins  # pylint: disable=import-error
+    import builtins
 
     # Define the detected encoding as a built-in variable for ease of use
     setattr(builtins, "__salt_system_encoding__", encoding)
@@ -122,3 +119,6 @@ __define_global_system_encoding_variable__()
 
 # This is now garbage collectable
 del __define_global_system_encoding_variable__
+
+# Import Salt's logging machinery
+import salt._logging.impl  # isort:skip  pylint: disable=unused-import
