@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 The client module is used to create a client connection to the publisher
 The data structure needs to be:
@@ -10,17 +9,6 @@ The data structure needs to be:
 """
 
 
-# Import salt libs
-
-# Import third party libs
-
-# pylint: disable=import-error
-
-# Try to import range from https://github.com/ytoolshed/range
-#
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
 # The components here are simple, and they need to be and stay simple, we
@@ -40,9 +28,7 @@ from datetime import datetime
 import salt.cache
 import salt.config
 import salt.defaults.exitcodes
-
-# Import tornado
-import salt.ext.tornado.gen  # pylint: disable=F0401
+import salt.ext.tornado.gen
 import salt.loader
 import salt.payload
 import salt.syspaths as syspaths
@@ -66,7 +52,6 @@ from salt.exceptions import (
     SaltInvocationError,
     SaltReqTimeoutError,
 )
-from salt.ext import six
 
 HAS_RANGE = False
 try:
@@ -75,7 +60,6 @@ try:
     HAS_RANGE = True
 except ImportError:
     pass
-# pylint: enable=import-error
 
 
 log = logging.getLogger(__name__)
@@ -87,6 +71,7 @@ def get_local_client(
     skip_perm_errors=False,
     io_loop=None,
     auto_reconnect=False,
+    listen=False,
 ):
     """
     .. versionadded:: 2014.7.0
@@ -94,11 +79,38 @@ def get_local_client(
     Read in the config and return the correct LocalClient object based on
     the configured transport
 
+    :param str c_path: Path of config file to use for opts.
+
+                       The default value is None.
+
+    :param bool mopts: When provided the local client will use this dictionary of
+                       options insead of loading a config file from the value
+                       of c_path.
+
+                       The default value is None.
+
+    :param str skip_perm_errors: Ignore permissions errors while loading keys.
+
+                                 The default value is False.
+
     :param IOLoop io_loop: io_loop used for events.
                            Pass in an io_loop if you want asynchronous
                            operation for obtaining events. Eg use of
                            set_event_handler() API. Otherwise, operation
                            will be synchronous.
+
+    :param bool keep_loop: Do not destroy the event loop when closing the event
+                           subsriber.
+
+    :param bool auto_reconnect: When True the event subscriber will reconnect
+                                automatically if a disconnect error is raised.
+
+    .. versionadded:: 3004
+    :param bool listen: Listen for events indefinitly. When option is set the
+                        LocalClient object will listen for events until it's
+                        destroy method is called.
+
+                        The default value is False.
     """
     if mopts:
         opts = mopts
@@ -114,10 +126,11 @@ def get_local_client(
         skip_perm_errors=skip_perm_errors,
         io_loop=io_loop,
         auto_reconnect=auto_reconnect,
+        listen=listen,
     )
 
 
-class LocalClient(object):
+class LocalClient:
     """
     The interface used by the :command:`salt` CLI tool on the Salt Master
 
@@ -144,6 +157,7 @@ class LocalClient(object):
 
         local = salt.client.LocalClient()
         local.cmd('*', 'test.fib', [10])
+
     """
 
     def __init__(
@@ -154,13 +168,41 @@ class LocalClient(object):
         io_loop=None,
         keep_loop=False,
         auto_reconnect=False,
+        listen=False,
     ):
         """
+        :param str c_path: Path of config file to use for opts.
+
+                           The default value is None.
+
+        :param bool mopts: When provided the local client will use this dictionary of
+                           options insead of loading a config file from the value
+                           of c_path.
+
+                           The default value is None.
+
+        :param str skip_perm_errors: Ignore permissions errors while loading keys.
+
+                                     The default value is False.
+
         :param IOLoop io_loop: io_loop used for events.
                                Pass in an io_loop if you want asynchronous
                                operation for obtaining events. Eg use of
-                               set_event_handler() API. Otherwise,
-                               operation will be synchronous.
+                               set_event_handler() API. Otherwise, operation
+                               will be synchronous.
+
+        :param bool keep_loop: Do not destroy the event loop when closing the event
+                               subsriber.
+
+        :param bool auto_reconnect: When True the event subscriber will reconnect
+                                    automatically if a disconnect error is raised.
+
+        .. versionadded:: 3004
+        :param bool listen: Listen for events indefinitly. When option is set the
+                            LocalClient object will listen for events until it's
+                            destroy method is called.
+
+                            The default value is False.
         """
         if mopts:
             self.opts = mopts
@@ -178,12 +220,13 @@ class LocalClient(object):
         self.skip_perm_errors = skip_perm_errors
         self.key = self.__read_master_key()
         self.auto_reconnect = auto_reconnect
+        self.listen = listen
         self.event = salt.utils.event.get_event(
             "master",
             self.opts["sock_dir"],
             self.opts["transport"],
             opts=self.opts,
-            listen=False,
+            listen=self.listen,
             io_loop=io_loop,
             keep_loop=keep_loop,
         )
@@ -205,7 +248,7 @@ class LocalClient(object):
             # The username may contain '\' if it is in Windows
             # 'DOMAIN\username' format. Fix this for the keyfile path.
             key_user = key_user.replace("\\", "_")
-        keyfile = os.path.join(self.opts["cachedir"], ".{0}_key".format(key_user))
+        keyfile = os.path.join(self.opts["cachedir"], ".{}_key".format(key_user))
         try:
             # Make sure all key parent directories are accessible
             salt.utils.verify.check_path_traversal(
@@ -213,7 +256,7 @@ class LocalClient(object):
             )
             with salt.utils.files.fopen(keyfile, "r") as key:
                 return salt.utils.stringutils.to_unicode(key.read())
-        except (OSError, IOError, SaltClientError):
+        except (OSError, SaltClientError):
             # Fall back to eauth
             return ""
 
@@ -225,7 +268,7 @@ class LocalClient(object):
         try:
             return range_.expand(tgt)
         except seco.range.RangeException as err:
-            print("Range server exception: {0}".format(err))
+            print("Range server exception: {}".format(err))
             return []
 
     def _get_timeout(self, timeout):
@@ -236,7 +279,7 @@ class LocalClient(object):
             return self.opts["timeout"]
         if isinstance(timeout, int):
             return timeout
-        if isinstance(timeout, six.string_types):
+        if isinstance(timeout, str):
             try:
                 return int(timeout)
             except ValueError:
@@ -307,9 +350,9 @@ class LocalClient(object):
             return pub_data
 
         if self.opts.get("order_masters"):
-            self.event.subscribe("syndic/.*/{0}".format(pub_data["jid"]), "regex")
+            self.event.subscribe("syndic/.*/{}".format(pub_data["jid"]), "regex")
 
-        self.event.subscribe("salt/job/{0}".format(pub_data["jid"]))
+        self.event.subscribe("salt/job/{}".format(pub_data["jid"]))
 
         return pub_data
 
@@ -360,9 +403,9 @@ class LocalClient(object):
                 "The salt master could not be contacted. Is master running?"
             )
         except AuthenticationError as err:
-            six.reraise(*sys.exc_info())
+            raise
         except AuthorizationError as err:
-            six.reraise(*sys.exc_info())
+            raise
         except Exception as general_exception:  # pylint: disable=broad-except
             # Convert to generic client error and pass along message
             raise SaltClientError(general_exception)
@@ -579,7 +622,7 @@ class LocalClient(object):
         if "token" in kwargs:
             eauth["token"] = kwargs.pop("token")
 
-        for key, val in six.iteritems(self.opts):
+        for key, val in self.opts.items():
             if key not in opts:
                 opts[key] = val
         batch = salt.cli.batch.Batch(opts, eauth=eauth, quiet=True)
@@ -732,7 +775,7 @@ class LocalClient(object):
             ):
 
                 if fn_ret:
-                    for mid, data in six.iteritems(fn_ret):
+                    for mid, data in fn_ret.items():
                         ret[mid] = data if full_return else data.get("ret", {})
 
             for failed in list(set(pub_data["minions"]) - set(ret)):
@@ -1011,11 +1054,11 @@ class LocalClient(object):
         :returns: all of the information for the JID
         """
         if verbose:
-            msg = "Executing job with jid {0}".format(jid)
+            msg = "Executing job with jid {}".format(jid)
             print(msg)
             print("-" * len(msg) + "\n")
         elif show_jid:
-            print("jid: {0}".format(jid))
+            print("jid: {}".format(jid))
         if timeout is None:
             timeout = self.opts["timeout"]
         fret = {}
@@ -1034,7 +1077,7 @@ class LocalClient(object):
 
         # if you have all the returns, stop
         if len(found.intersection(minions)) >= len(minions):
-            raise StopIteration()
+            return
 
         # otherwise, get them from the event system
         for event in event_iter:
@@ -1043,7 +1086,7 @@ class LocalClient(object):
                 yield event
             if len(found.intersection(minions)) >= len(minions):
                 self._clean_up_subscriptions(jid)
-                raise StopIteration()
+                return
 
     # TODO: tests!!
     def get_returns_no_block(self, tag, match_type=None):
@@ -1068,6 +1111,9 @@ class LocalClient(object):
             )
             yield raw
 
+    def returns_for_job(self, jid):
+        return self.returners["{}.get_load".format(self.opts["master_job_cache"])](jid)
+
     def get_iter_returns(
         self,
         jid,
@@ -1085,8 +1131,8 @@ class LocalClient(object):
         :returns: all of the information for the JID
         """
         if not isinstance(minions, set):
-            if isinstance(minions, six.string_types):
-                minions = set([minions])
+            if isinstance(minions, str):
+                minions = {minions}
             elif isinstance(minions, (list, tuple)):
                 minions = set(list(minions))
 
@@ -1104,16 +1150,11 @@ class LocalClient(object):
         missing = set()
         # Check to see if the jid is real, if not return the empty dict
         try:
-            if (
-                self.returners["{0}.get_load".format(self.opts["master_job_cache"])](
-                    jid
-                )
-                == {}
-            ):
+            if not self.returns_for_job(jid):
                 log.warning("jid does not exist")
                 yield {}
                 # stop the iteration, since the jid is invalid
-                raise StopIteration()
+                return
         except Exception as exc:  # pylint: disable=broad-except
             log.warning(
                 "Returner unavailable: %s", exc, exc_info_on_loglevel=logging.DEBUG
@@ -1124,10 +1165,10 @@ class LocalClient(object):
         if self.opts["order_masters"]:
             # If we are a MoM, we need to gather expected minions from downstreams masters.
             ret_iter = self.get_returns_no_block(
-                "(salt/job|syndic/.*)/{0}".format(jid), "regex"
+                "(salt/job|syndic/.*)/{}".format(jid), "regex"
             )
         else:
-            ret_iter = self.get_returns_no_block("salt/job/{0}".format(jid))
+            ret_iter = self.get_returns_no_block("salt/job/{}".format(jid))
         # iterator for the info of this job
         jinfo_iter = []
         # open event jids that need to be un-subscribed from later
@@ -1220,7 +1261,7 @@ class LocalClient(object):
                     jinfo_iter = []
                 else:
                     jinfo_iter = self.get_returns_no_block(
-                        "salt/job/{0}".format(jinfo["jid"])
+                        "salt/job/{}".format(jinfo["jid"])
                     )
                 timeout_at = time.time() + gather_job_timeout
                 # if you are a syndic, wait a little longer
@@ -1272,7 +1313,7 @@ class LocalClient(object):
                 # if the minion throws an exception containing the word "return"
                 # the master will try to handle the string as a dict in the next
                 # step. Check if we have a string, log the issue and continue.
-                if isinstance(raw["data"]["return"], six.string_types):
+                if isinstance(raw["data"]["return"], str):
                     log.error("unexpected return from minion: %s", raw)
                     continue
 
@@ -1317,7 +1358,7 @@ class LocalClient(object):
                 self.event.unsubscribe(jid)
 
         if expect_minions:
-            for minion in list((minions - found)):
+            for minion in list(minions - found):
                 yield {minion: {"failed": True}}
 
         # Filter out any minions marked as missing for which we received
@@ -1351,17 +1392,15 @@ class LocalClient(object):
         # Check to see if the jid is real, if not return the empty dict
         try:
             if (
-                self.returners["{0}.get_load".format(self.opts["master_job_cache"])](
-                    jid
-                )
+                self.returners["{}.get_load".format(self.opts["master_job_cache"])](jid)
                 == {}
             ):
                 log.warning("jid does not exist")
                 return ret
         except Exception as exc:  # pylint: disable=broad-except
             raise SaltClientError(
-                "Master job cache returner [{0}] failed to verify jid. "
-                "Exception details: {1}".format(self.opts["master_job_cache"], exc)
+                "Master job cache returner [{}] failed to verify jid. "
+                "Exception details: {}".format(self.opts["master_job_cache"], exc)
             )
 
         # Wait for the hosts to check in
@@ -1403,13 +1442,13 @@ class LocalClient(object):
         event_iter = self.get_event_iter_returns(jid, minions, timeout=timeout)
 
         try:
-            data = self.returners["{0}.get_jid".format(self.opts["master_job_cache"])](
+            data = self.returners["{}.get_jid".format(self.opts["master_job_cache"])](
                 jid
             )
         except Exception as exc:  # pylint: disable=broad-except
             raise SaltClientError(
-                "Returner {0} could not fetch jid data. "
-                "Exception details: {1}".format(self.opts["master_job_cache"], exc)
+                "Returner {} could not fetch jid data. "
+                "Exception details: {}".format(self.opts["master_job_cache"], exc)
             )
         for minion in data:
             m_data = {}
@@ -1434,7 +1473,7 @@ class LocalClient(object):
             if event_ret == {}:
                 time.sleep(0.02)
                 continue
-            for minion, m_data in six.iteritems(event_ret):
+            for minion, m_data in event_ret.items():
                 if minion in ret:
                     ret[minion].update(m_data)
                 else:
@@ -1454,14 +1493,14 @@ class LocalClient(object):
         ret = {}
 
         try:
-            data = self.returners["{0}.get_jid".format(self.opts["master_job_cache"])](
+            data = self.returners["{}.get_jid".format(self.opts["master_job_cache"])](
                 jid
             )
         except Exception as exc:  # pylint: disable=broad-except
             raise SaltClientError(
                 "Could not examine master job cache. "
-                "Error occurred in {0} returner. "
-                "Exception details: {1}".format(self.opts["master_job_cache"], exc)
+                "Error occurred in {} returner. "
+                "Exception details: {}".format(self.opts["master_job_cache"], exc)
             )
         for minion in data:
             m_data = {}
@@ -1495,11 +1534,11 @@ class LocalClient(object):
         log.trace("entered - function get_cli_static_event_returns()")
         minions = set(minions)
         if verbose:
-            msg = "Executing job with jid {0}".format(jid)
+            msg = "Executing job with jid {}".format(jid)
             print(msg)
             print("-" * len(msg) + "\n")
         elif show_jid:
-            print("jid: {0}".format(jid))
+            print("jid: {}".format(jid))
 
         if timeout is None:
             timeout = self.opts["timeout"]
@@ -1511,9 +1550,7 @@ class LocalClient(object):
         # Check to see if the jid is real, if not return the empty dict
         try:
             if (
-                self.returners["{0}.get_load".format(self.opts["master_job_cache"])](
-                    jid
-                )
+                self.returners["{}.get_load".format(self.opts["master_job_cache"])](jid)
                 == {}
             ):
                 log.warning("jid does not exist")
@@ -1521,7 +1558,7 @@ class LocalClient(object):
         except Exception as exc:  # pylint: disable=broad-except
             raise SaltClientError(
                 "Load could not be retrieved from "
-                "returner {0}. Exception details: {1}".format(
+                "returner {}. Exception details: {}".format(
                     self.opts["master_job_cache"], exc
                 )
             )
@@ -1531,7 +1568,7 @@ class LocalClient(object):
             time_left = timeout_at - int(time.time())
             # Wait 0 == forever, use a minimum of 1s
             wait = max(1, time_left)
-            jid_tag = "salt/job/{0}".format(jid)
+            jid_tag = "salt/job/{}".format(jid)
             raw = self.event.get_event(
                 wait, jid_tag, auto_reconnect=self.auto_reconnect
             )
@@ -1591,11 +1628,11 @@ class LocalClient(object):
         log.trace("func get_cli_event_returns()")
 
         if verbose:
-            msg = "Executing job with jid {0}".format(jid)
+            msg = "Executing job with jid {}".format(jid)
             print(msg)
             print("-" * len(msg) + "\n")
         elif show_jid:
-            print("jid: {0}".format(jid))
+            print("jid: {}".format(jid))
 
         # lazy load the connected minions
         connected_minions = None
@@ -1618,14 +1655,14 @@ class LocalClient(object):
             log.debug("return event: %s", ret)
             return_count = return_count + 1
             if progress:
-                for id_, min_ret in six.iteritems(ret):
+                for id_, min_ret in ret.items():
                     if not min_ret.get("failed") is True:
                         yield {
                             "minion_count": len(minions),
                             "return_count": return_count,
                         }
             # replace the return structure for missing minions
-            for id_, min_ret in six.iteritems(ret):
+            for id_, min_ret in ret.items():
                 if min_ret.get("failed") is True:
                     if connected_minions is None:
                         connected_minions = salt.utils.minions.CkMinions(
@@ -1634,7 +1671,7 @@ class LocalClient(object):
                     if (
                         self.opts["minion_data_cache"]
                         and salt.cache.factory(self.opts).contains(
-                            "minions/{0}".format(id_), "data"
+                            "minions/{}".format(id_), "data"
                         )
                         and connected_minions
                         and id_ not in connected_minions
@@ -1660,7 +1697,7 @@ class LocalClient(object):
                                     "remaining minions will return upon completion. To look "
                                     "up the return data for this job later, run the following "
                                     "command:\n\n"
-                                    "salt-run jobs.lookup_jid {0}".format(jid),
+                                    "salt-run jobs.lookup_jid {}".format(jid),
                                     "retcode": salt.defaults.exitcodes.EX_GENERIC,
                                 }
                             }
@@ -1683,13 +1720,13 @@ class LocalClient(object):
         found = set()
         # Check to see if the jid is real, if not return the empty dict
         if (
-            self.returners["{0}.get_load".format(self.opts["master_job_cache"])](jid)
+            self.returners["{}.get_load".format(self.opts["master_job_cache"])](jid)
             == {}
         ):
             log.warning("jid does not exist")
             yield {}
             # stop the iteration, since the jid is invalid
-            raise StopIteration()
+            return
         # Wait for the hosts to check in
         while True:
             raw = self.event.get_event(timeout, auto_reconnect=self.auto_reconnect)
@@ -1720,7 +1757,7 @@ class LocalClient(object):
         if ng not in self.opts["nodegroups"]:
             conf_file = self.opts.get("conf_file", "the master config file")
             raise SaltInvocationError(
-                "Node group {0} unavailable in {1}".format(ng, conf_file)
+                "Node group {} unavailable in {}".format(ng, conf_file)
             )
         return salt.utils.minions.nodegroup_comp(ng, self.opts["nodegroups"])
 
@@ -1737,7 +1774,7 @@ class LocalClient(object):
             new_tgt = list()
             log.debug("compound resolution: original tgt: %s", tgt)
 
-            if isinstance(tgt, six.string_types):
+            if isinstance(tgt, str):
                 tgt = tgt.split()
 
             for word in tgt:
@@ -1759,7 +1796,7 @@ class LocalClient(object):
         # If an external job cache is specified add it to the ret list
         if self.opts.get("ext_job_cache"):
             if ret:
-                ret += ",{0}".format(self.opts["ext_job_cache"])
+                ret += ",{}".format(self.opts["ext_job_cache"])
             else:
                 ret = self.opts["ext_job_cache"]
 
@@ -1843,7 +1880,7 @@ class LocalClient(object):
 
         master_uri = "tcp://{}:{}".format(
             salt.utils.zeromq.ip_bracket(self.opts["interface"]),
-            six.text_type(self.opts["ret_port"]),
+            str(self.opts["ret_port"]),
         )
 
         with salt.transport.client.ReqChannel.factory(
@@ -1947,7 +1984,7 @@ class LocalClient(object):
             "tcp://"
             + salt.utils.zeromq.ip_bracket(self.opts["interface"])
             + ":"
-            + six.text_type(self.opts["ret_port"])
+            + str(self.opts["ret_port"])
         )
 
         with salt.transport.client.AsyncReqChannel.factory(
@@ -2004,16 +2041,25 @@ class LocalClient(object):
         # This IS really necessary!
         # When running tests, if self.events is not destroyed, we leak 2
         # threads per test case which uses self.client
-        if hasattr(self, "event"):
-            # The call below will take care of calling 'self.event.destroy()'
-            del self.event
+        self.destroy()
 
     # pylint: enable=W1701
 
     def _clean_up_subscriptions(self, job_id):
         if self.opts.get("order_masters"):
-            self.event.unsubscribe("syndic/.*/{0}".format(job_id), "regex")
-        self.event.unsubscribe("salt/job/{0}".format(job_id))
+            self.event.unsubscribe("syndic/.*/{}".format(job_id), "regex")
+        self.event.unsubscribe("salt/job/{}".format(job_id))
+
+    def destroy(self):
+        if self.event is not None:
+            self.event.destroy()
+            self.event = None
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.destroy()
 
 
 class FunctionWrapper(dict):
@@ -2026,7 +2072,7 @@ class FunctionWrapper(dict):
     """
 
     def __init__(self, opts, minion):
-        super(FunctionWrapper, self).__init__()
+        super().__init__()
         self.opts = opts
         self.minion = minion
         self.local = LocalClient(self.opts["conf_file"])
@@ -2061,13 +2107,13 @@ class FunctionWrapper(dict):
             """
             args = list(args)
             for _key, _val in kwargs.items():
-                args.append("{0}={1}".format(_key, _val))
+                args.append("{}={}".format(_key, _val))
             return self.local.cmd(self.minion, key, args)
 
         return func
 
 
-class Caller(object):
+class Caller:
     """
     ``Caller`` is the same interface used by the :command:`salt-call`
     command-line tool on the Salt Minion.
@@ -2145,7 +2191,7 @@ class Caller(object):
         return func(*args, **kwargs)
 
 
-class ProxyCaller(object):
+class ProxyCaller:
     """
     ``ProxyCaller`` is the same interface used by the :command:`salt-call`
     with the args ``--proxyid <proxyid>`` command-line tool on the Salt Proxy
@@ -2208,14 +2254,12 @@ class ProxyCaller(object):
         executors = getattr(self.sminion, "module_executors", []) or self.opts.get(
             "module_executors", ["direct_call"]
         )
-        if isinstance(executors, six.string_types):
+        if isinstance(executors, str):
             executors = [executors]
         for name in executors:
-            fname = "{0}.execute".format(name)
+            fname = "{}.execute".format(name)
             if fname not in self.sminion.executors:
-                raise SaltInvocationError(
-                    "Executor '{0}' is not available".format(name)
-                )
+                raise SaltInvocationError("Executor '{}' is not available".format(name))
             return_data = self.sminion.executors[fname](
                 self.opts, data, func, args, kwargs
             )
