@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Copyright 2013 Google Inc. All Rights Reserved.
 
@@ -44,10 +43,7 @@ Example Provider Configuration
 :maintainer: Russell Tolle <russ.tolle@gmail.com>
 :depends: libcloud >= 1.0.0
 """
-# pylint: disable=invalid-name,function-redefined
-
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
+# pylint: disable=function-redefined
 
 import logging
 import os
@@ -63,13 +59,9 @@ import salt.utils.http
 import salt.utils.msgpack
 from salt.cloud.libcloudfuncs import *  # pylint: disable=redefined-builtin,wildcard-import,unused-wildcard-import
 from salt.exceptions import SaltCloudSystemExit
-from salt.ext import six
-
-# Import salt libs
 from salt.utils.functools import namespaced_function
 from salt.utils.versions import LooseVersion as _LooseVersion
 
-# Import 3rd-party libs
 # pylint: disable=import-error
 LIBCLOUD_IMPORT_ERROR = None
 try:
@@ -83,16 +75,6 @@ try:
         ResourceNotFoundError,
     )
 
-    # This work-around for Issue #32743 is no longer needed for libcloud >=
-    # 1.4.0. However, older versions of libcloud must still be supported with
-    # this work-around. This work-around can be removed when the required
-    # minimum version of libcloud is 2.0.0 (See PR #40837 - which is
-    # implemented in Salt 2018.3.0).
-    if _LooseVersion(libcloud.__version__) < _LooseVersion("1.4.0"):
-        # See https://github.com/saltstack/salt/issues/32743
-        import libcloud.security
-
-        libcloud.security.CA_CERTS_PATH.append("/etc/ssl/certs/YaST-CA.pem")
     HAS_LIBCLOUD = True
 except ImportError:
     LIBCLOUD_IMPORT_ERROR = sys.exc_info()
@@ -125,13 +107,19 @@ def __virtual__():
     """
     Set up the libcloud functions and check for GCE configurations.
     """
+    if not HAS_LIBCLOUD:
+        return False, "apache-libcloud is not installed"
+
+    if _LooseVersion(libcloud.__version__) < _LooseVersion("2.5.0"):
+        return False, "The salt-cloud GCE driver requires apache-libcloud>=2.5.0"
+
     if get_configured_provider() is False:
         return False
 
     if get_dependencies() is False:
         return False
 
-    for provider, details in six.iteritems(__opts__["providers"]):
+    for provider, details in __opts__["providers"].items():
         if "gce" not in details:
             continue
 
@@ -147,13 +135,20 @@ def __virtual__():
     return __virtualname__
 
 
+def _get_active_provider_name():
+    try:
+        return __active_provider_name__.value()
+    except AttributeError:
+        return __active_provider_name__
+
+
 def get_configured_provider():
     """
     Return the first configured instance.
     """
     return config.is_provider_configured(
         __opts__,
-        __active_provider_name__ or "gce",
+        _get_active_provider_name() or "gce",
         ("project", "service_account_email_address", "service_account_private_key"),
     )
 
@@ -193,7 +188,7 @@ def get_conn():
         "service_account_private_key", provider, __opts__
     )
     gce = driver(email, private_key, project=project)
-    gce.connection.user_agent_append("{0}/{1}".format(_UA_PRODUCT, _UA_VERSION))
+    gce.connection.user_agent_append("{}/{}".format(_UA_PRODUCT, _UA_VERSION))
     return gce
 
 
@@ -301,7 +296,7 @@ def show_instance(vm_name, call=None):
         )
     conn = get_conn()
     node = _expand_node(conn.ex_get_node(vm_name))
-    __utils__["cloud.cache_node"](node, __active_provider_name__, __opts__)
+    __utils__["cloud.cache_node"](node, _get_active_provider_name(), __opts__)
     return node
 
 
@@ -437,7 +432,7 @@ def __get_metadata(vm_):
     else:
         metadata["salt-cloud-profile"] = vm_["profile"]
         items = []
-        for k, v in six.iteritems(metadata):
+        for k, v in metadata.items():
             items.append({"key": k, "value": v})
         metadata = {"items": items}
     return metadata
@@ -533,7 +528,7 @@ def _parse_allow(allow):
         pairs = p.split(":")
         if pairs[0].lower() not in ["tcp", "udp", "icmp"]:
             raise SaltCloudSystemExit(
-                "Unsupported protocol {0}. Must be tcp, udp, or icmp.".format(pairs[0])
+                "Unsupported protocol {}. Must be tcp, udp, or icmp.".format(pairs[0])
             )
         if len(pairs) == 1 or pairs[0].lower() == "icmp":
             seen_protos[pairs[0]] = []
@@ -569,7 +564,8 @@ def __get_ssh_credentials(vm_):
 
 def create_network(kwargs=None, call=None):
     """
-    ... versionchanged:: 2017.7.0
+    .. versionchanged:: 2017.7.0
+
     Create a GCE network. Must specify name and cidr.
 
     CLI Example:
@@ -699,7 +695,8 @@ def show_network(kwargs=None, call=None):
 
 def create_subnetwork(kwargs=None, call=None):
     """
-    ... versionadded:: 2017.7.0
+    .. versionadded:: 2017.7.0
+
     Create a GCE Subnetwork. Must specify name, cidr, network, and region.
 
     CLI Example:
@@ -773,7 +770,8 @@ def create_subnetwork(kwargs=None, call=None):
 
 def delete_subnetwork(kwargs=None, call=None):
     """
-    ... versionadded:: 2017.7.0
+    .. versionadded:: 2017.7.0
+
     Delete a GCE Subnetwork. Must specify name and region.
 
     CLI Example:
@@ -832,7 +830,8 @@ def delete_subnetwork(kwargs=None, call=None):
 
 def show_subnetwork(kwargs=None, call=None):
     """
-    ... versionadded:: 2017.7.0
+    .. versionadded:: 2017.7.0
+
     Show details of an existing GCE Subnetwork. Must specify name and region.
 
     CLI Example:
@@ -1999,7 +1998,7 @@ def reboot(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "reboot instance",
-        "salt/cloud/{0}/rebooting".format(vm_name),
+        "salt/cloud/{}/rebooting".format(vm_name),
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2010,7 +2009,7 @@ def reboot(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "reboot instance",
-        "salt/cloud/{0}/rebooted".format(vm_name),
+        "salt/cloud/{}/rebooted".format(vm_name),
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2041,7 +2040,7 @@ def start(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "start instance",
-        "salt/cloud/{0}/starting".format(vm_name),
+        "salt/cloud/{}/starting".format(vm_name),
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2052,7 +2051,7 @@ def start(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "start instance",
-        "salt/cloud/{0}/started".format(vm_name),
+        "salt/cloud/{}/started".format(vm_name),
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2081,7 +2080,7 @@ def stop(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "stop instance",
-        "salt/cloud/{0}/stopping".format(vm_name),
+        "salt/cloud/{}/stopping".format(vm_name),
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2092,7 +2091,7 @@ def stop(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "stop instance",
-        "salt/cloud/{0}/stopped".format(vm_name),
+        "salt/cloud/{}/stopped".format(vm_name),
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2130,12 +2129,12 @@ def destroy(vm_name, call=None):
             exc,
             exc_info_on_loglevel=logging.DEBUG,
         )
-        raise SaltCloudSystemExit("Could not find instance {0}.".format(vm_name))
+        raise SaltCloudSystemExit("Could not find instance {}.".format(vm_name))
 
     __utils__["cloud.fire_event"](
         "event",
         "delete instance",
-        "salt/cloud/{0}/deleting".format(vm_name),
+        "salt/cloud/{}/deleting".format(vm_name),
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2171,11 +2170,11 @@ def destroy(vm_name, call=None):
             exc,
             exc_info_on_loglevel=logging.DEBUG,
         )
-        raise SaltCloudSystemExit("Could not destroy instance {0}.".format(vm_name))
+        raise SaltCloudSystemExit("Could not destroy instance {}.".format(vm_name))
     __utils__["cloud.fire_event"](
         "event",
         "delete instance",
-        "salt/cloud/{0}/deleted".format(vm_name),
+        "salt/cloud/{}/deleted".format(vm_name),
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2219,7 +2218,7 @@ def destroy(vm_name, call=None):
 
     if __opts__.get("update_cachedir", False) is True:
         __utils__["cloud.delete_minion_cachedir"](
-            vm_name, __active_provider_name__.split(":")[0], __opts__
+            vm_name, _get_active_provider_name().split(":")[0], __opts__
         )
 
     return inst_deleted
@@ -2264,7 +2263,7 @@ def create_attach_volumes(name, kwargs, call=None):
     letter = ord("a") - 1
 
     for idx, volume in enumerate(volumes):
-        volume_name = "{0}-sd{1}".format(name, chr(letter + 2 + idx))
+        volume_name = "{}-sd{}".format(name, chr(letter + 2 + idx))
 
         volume_dict = {
             "disk_name": volume_name,
@@ -2284,7 +2283,7 @@ def request_instance(vm_):
     """
     Request a single GCE instance from a data dict.
 
-    .. versionchanged: 2017.7.0
+    .. versionchanged:: 2017.7.0
     """
     if not GCE_VM_NAME_REGEX.match(vm_["name"]):
         raise SaltCloudSystemExit(
@@ -2297,7 +2296,7 @@ def request_instance(vm_):
         if (
             vm_["profile"]
             and config.is_profile_configured(
-                __opts__, __active_provider_name__ or "gce", vm_["profile"], vm_=vm_
+                __opts__, _get_active_provider_name() or "gce", vm_["profile"], vm_=vm_
             )
             is False
         ):
@@ -2308,7 +2307,7 @@ def request_instance(vm_):
     __utils__["cloud.fire_event"](
         "event",
         "create instance",
-        "salt/cloud/{0}/creating".format(vm_["name"]),
+        "salt/cloud/{}/creating".format(vm_["name"]),
         args=__utils__["cloud.filter_event"](
             "creating", vm_, ["name", "profile", "provider", "driver"]
         ),
@@ -2398,7 +2397,7 @@ def request_instance(vm_):
     __utils__["cloud.fire_event"](
         "event",
         "requesting instance",
-        "salt/cloud/{0}/requesting".format(vm_["name"]),
+        "salt/cloud/{}/requesting".format(vm_["name"]),
         args=__utils__["cloud.filter_event"](
             "requesting", vm_, ["name", "profile", "provider", "driver"]
         ),
@@ -2427,7 +2426,7 @@ def request_instance(vm_):
         __utils__["cloud.fire_event"](
             "event",
             "attaching volumes",
-            "salt/cloud/{0}/attaching_volumes".format(vm_["name"]),
+            "salt/cloud/{}/attaching_volumes".format(vm_["name"]),
             args={"volumes": volumes},
             sock_dir=__opts__["sock_dir"],
             transport=__opts__["transport"],
@@ -2474,7 +2473,7 @@ def create(vm_=None, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "created instance",
-        "salt/cloud/{0}/created".format(vm_["name"]),
+        "salt/cloud/{}/created".format(vm_["name"]),
         args=__utils__["cloud.filter_event"](
             "created", vm_, ["name", "profile", "provider", "driver"]
         ),
@@ -2533,7 +2532,7 @@ def show_pricing(kwargs=None, call=None):
     comps = profile.get("location", "us").split("-")
     region = comps[0]
 
-    size = "CP-COMPUTEENGINE-VMIMAGE-{0}".format(profile["size"].upper())
+    size = "CP-COMPUTEENGINE-VMIMAGE-{}".format(profile["size"].upper())
     pricefile = os.path.join(__opts__["cachedir"], "gce-pricing.p")
     if not os.path.exists(pricefile):
         update_pricing()
