@@ -1,14 +1,18 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Classification of Salt exit codes.  These are intended to augment
 universal exit codes (found in Python's `os` module with the `EX_`
 prefix or in `sysexits.h`).
-'''
+"""
 
 # Too many situations use "exit 1" - try not to use it when something
 # else is more appropriate.
 EX_GENERIC = 1
 
+EX_STATE_COMPILER_ERROR = 1
+EX_STATE_FAILURE = 2
+EX_PILLAR_FAILURE = 5
+
 # Salt SSH "Thin" deployment failures
 EX_THIN_PYTHON_INVALID = 10
 EX_THIN_DEPLOY = 11
@@ -25,14 +29,14 @@ EX_AGGREGATE = 20
 # These constants are documented here:
 # https://docs.python.org/2/library/os.html#os.EX_OK
 
-EX_OK = 0                 # successful termination
-EX_USAGE = 64             # command line usage error
-EX_NOUSER = 67            # addressee unknown
-EX_UNAVAILABLE = 69       # service unavailable
-EX_SOFTWARE = 70          # internal software error
-EX_CANTCREAT = 73         # can't create (user) output file
-EX_TEMPFAIL = 75          # temp failure; user is invited to retry
-EX_NOPERM = 77            # permission denied
+EX_OK = 0  # successful termination
+EX_USAGE = 64  # command line usage error
+EX_NOUSER = 67  # addressee unknown
+EX_UNAVAILABLE = 69  # service unavailable
+EX_SOFTWARE = 70  # internal software error
+EX_CANTCREAT = 73  # can't create (user) output file
+EX_TEMPFAIL = 75  # temp failure; user is invited to retry
+EX_NOPERM = 77  # permission denied
 
 # The Salt specific exit codes are defined below:
 
