@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Setup Reactor
 
 Example Config in Master or Minion config
@@ -16,21 +15,17 @@ Example Config in Master or Minion config
       - 'salt/cloud/*/destroyed':
         - /srv/reactor/destroy/*.sls
 
-'''
-# Import Python libs
-from __future__ import absolute_import
+"""
 
-
-# Import salt libs
 import salt.utils.reactor
 
 
 def start(refresh_interval=None, worker_threads=None, worker_hwm=None):
     if refresh_interval is not None:
-        __opts__['reactor_refresh_interval'] = refresh_interval
+        __opts__["reactor_refresh_interval"] = refresh_interval
     if worker_threads is not None:
-        __opts__['reactor_worker_threads'] = worker_threads
+        __opts__["reactor_worker_threads"] = worker_threads
     if worker_hwm is not None:
-        __opts__['reactor_worker_hwm'] = worker_hwm
+        __opts__["reactor_worker_hwm"] = worker_hwm
 
     salt.utils.reactor.Reactor(__opts__).run()
