@@ -1,33 +1,18 @@
-# -*- coding: utf-8 -*-
 """
 Module for fetching artifacts from Artifactory
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
+import http.client
 import logging
 import os
+import urllib.request
+import xml.etree.ElementTree as ET
+from urllib.error import HTTPError, URLError
 
-# Import Salt libs
-import salt.ext.six.moves.http_client  # pylint: disable=import-error,redefined-builtin,no-name-in-module
 import salt.utils.files
 import salt.utils.hashutils
 import salt.utils.stringutils
 from salt.exceptions import CommandExecutionError
-from salt.ext.six.moves import urllib  # pylint: disable=no-name-in-module
-from salt.ext.six.moves.urllib.error import (  # pylint: disable=no-name-in-module
-    HTTPError,
-    URLError,
-)
-
-# Import 3rd party libs
-try:
-    from salt._compat import ElementTree as ET
-
-    HAS_ELEMENT_TREE = True
-except ImportError:
-    HAS_ELEMENT_TREE = False
 
 log = logging.getLogger(__name__)
 
@@ -38,15 +23,7 @@ def __virtual__():
     """
     Only load if elementtree xml library is available.
     """
-    if not HAS_ELEMENT_TREE:
-        return (
-            False,
-            "Cannot load {0} module: ElementTree library unavailable".format(
-                __virtualname__
-            ),
-        )
-    else:
-        return True
+    return True
 
 
 def get_latest_snapshot(
@@ -99,9 +76,9 @@ def get_latest_snapshot(
 
     headers = {}
     if username and password:
-        headers["Authorization"] = "Basic {0}".format(
+        headers["Authorization"] = "Basic {}".format(
             salt.utils.hashutils.base64_encodestring(
-                "{0}:{1}".format(username.replace("\n", ""), password.replace("\n", ""))
+                "{}:{}".format(username.replace("\n", ""), password.replace("\n", ""))
             )
         )
     artifact_metadata = _get_artifact_metadata(
@@ -183,9 +160,9 @@ def get_snapshot(
     )
     headers = {}
     if username and password:
-        headers["Authorization"] = "Basic {0}".format(
+        headers["Authorization"] = "Basic {}".format(
             salt.utils.hashutils.base64_encodestring(
-                "{0}:{1}".format(username.replace("\n", ""), password.replace("\n", ""))
+                "{}:{}".format(username.replace("\n", ""), password.replace("\n", ""))
             )
         )
     snapshot_url, file_name = _get_snapshot_url(
@@ -254,9 +231,9 @@ def get_latest_release(
     )
     headers = {}
     if username and password:
-        headers["Authorization"] = "Basic {0}".format(
+        headers["Authorization"] = "Basic {}".format(
             salt.utils.hashutils.base64_encodestring(
-                "{0}:{1}".format(username.replace("\n", ""), password.replace("\n", ""))
+                "{}:{}".format(username.replace("\n", ""), password.replace("\n", ""))
             )
         )
     version = __find_latest_version(
@@ -334,9 +311,9 @@ def get_release(
     )
     headers = {}
     if username and password:
-        headers["Authorization"] = "Basic {0}".format(
+        headers["Authorization"] = "Basic {}".format(
             salt.utils.hashutils.base64_encodestring(
-                "{0}:{1}".format(username.replace("\n", ""), password.replace("\n", ""))
+                "{}:{}".format(username.replace("\n", ""), password.replace("\n", ""))
             )
         )
     release_url, file_name = _get_release_url(
@@ -534,7 +511,7 @@ def _get_artifact_metadata_xml(
         request = urllib.request.Request(artifact_metadata_url, None, headers)
         artifact_metadata_xml = urllib.request.urlopen(request).read()
     except (HTTPError, URLError) as err:
-        message = "Could not fetch data from url: {0}. ERROR: {1}".format(
+        message = "Could not fetch data from url: {}. ERROR: {}".format(
             artifact_metadata_url, err
         )
         raise CommandExecutionError(message)
@@ -612,7 +589,7 @@ def _get_snapshot_version_metadata_xml(
         request = urllib.request.Request(snapshot_version_metadata_url, None, headers)
         snapshot_version_metadata_xml = urllib.request.urlopen(request).read()
     except (HTTPError, URLError) as err:
-        message = "Could not fetch data from url: {0}. ERROR: {1}".format(
+        message = "Could not fetch data from url: {}. ERROR: {}".format(
             snapshot_version_metadata_url, err
         )
         raise CommandExecutionError(message)
@@ -688,7 +665,7 @@ def __find_latest_version(
         request = urllib.request.Request(latest_version_url, None, headers)
         version = urllib.request.urlopen(request).read()
     except (HTTPError, URLError) as err:
-        message = "Could not fetch data from url: {0}. ERROR: {1}".format(
+        message = "Could not fetch data from url: {}. ERROR: {}".format(
             latest_version_url, err
         )
         raise CommandExecutionError(message)
@@ -722,14 +699,14 @@ def __save_artifact(artifact_url, target_file, headers):
                 result["status"] = True
                 result["target_file"] = target_file
                 result["comment"] = (
-                    "File {0} already exists, checksum matches with Artifactory.\n"
-                    "Checksum URL: {1}".format(target_file, checksum_url)
+                    "File {} already exists, checksum matches with Artifactory.\n"
+                    "Checksum URL: {}".format(target_file, checksum_url)
                 )
                 return result
             else:
                 result["comment"] = (
-                    "File {0} already exists, checksum does not match with Artifactory!\n"
-                    "Checksum URL: {1}".format(target_file, checksum_url)
+                    "File {} already exists, checksum does not match with Artifactory!\n"
+                    "Checksum URL: {}".format(target_file, checksum_url)
                 )
 
         else:
@@ -746,7 +723,7 @@ def __save_artifact(artifact_url, target_file, headers):
             local_file.write(salt.utils.stringutils.to_bytes(f.read()))
         result["status"] = True
         result["comment"] = __append_comment(
-            ("Artifact downloaded from URL: {0}".format(artifact_url)),
+            ("Artifact downloaded from URL: {}".format(artifact_url)),
             result["comment"],
         )
         result["changes"]["downloaded_file"] = target_file
@@ -788,11 +765,11 @@ def __download(request_url, headers):
 
 
 def __get_error_comment(http_error, request_url):
-    if http_error.code == salt.ext.six.moves.http_client.NOT_FOUND:
+    if http_error.code == http.client.NOT_FOUND:
         comment = "HTTP Error 404. Request URL: " + request_url
-    elif http_error.code == salt.ext.six.moves.http_client.CONFLICT:
+    elif http_error.code == http.client.CONFLICT:
         comment = (
-            "HTTP Error 409: Conflict. Requested URL: {0}. \n"
+            "HTTP Error 409: Conflict. Requested URL: {}. \n"
             "This error may be caused by reading snapshot artifact from non-snapshot repository.".format(
                 request_url
             )
@@ -811,7 +788,7 @@ def __append_comment(new_comment, current_comment=""):
 
 class ArtifactoryError(Exception):
     def __init__(self, value):
-        super(ArtifactoryError, self).__init__()
+        super().__init__()
         self.value = value
 
     def __str__(self):
