@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Connection module for Amazon Route53
 
@@ -45,23 +44,17 @@ Connection module for Amazon Route53
 # keep lint from choking on _get_conn and _cache_id
 # pylint: disable=E0602
 
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import Python libs
 import logging
-import sys
 import time
 
-# Import salt libs
 import salt.utils.compat
 import salt.utils.odict as odict
 import salt.utils.versions
 from salt.exceptions import SaltInvocationError
-from salt.ext import six
 
 log = logging.getLogger(__name__)
 
-# Import third party libs
 try:
     # pylint: disable=unused-import
     import boto
@@ -85,7 +78,6 @@ def __virtual__():
 
 
 def __init__(opts):
-    salt.utils.compat.pack_dunder(__name__)
     if HAS_BOTO:
         __utils__["boto.assign_funcs"](__name__, "route53", pack=__salt__)
 
@@ -264,7 +256,9 @@ def zone_exists(
 
     .. versionadded:: 2015.8.0
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_route53.zone_exists example.org
 
@@ -312,7 +306,7 @@ def zone_exists(
                 time.sleep(3)
                 error_retries -= 1
                 continue
-            six.reraise(*sys.exc_info())
+            raise
     return False
 
 
@@ -355,7 +349,9 @@ def create_zone(
     profile
         AWS pillar profile
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_route53.create_zone example.org
     """
@@ -451,7 +447,9 @@ def create_healthcheck(
 
         AWS pillar profile
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_route53.create_healthcheck 192.168.0.1
         salt myminion boto_route53.create_healthcheck 192.168.0.1 port=443 hc_type=HTTPS \
@@ -503,7 +501,9 @@ def delete_zone(zone, region=None, key=None, keyid=None, profile=None):
 
     .. versionadded:: 2015.8.0
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_route53.delete_zone example.org
     """
@@ -548,7 +548,9 @@ def get_record(
     """
     Get a record from a zone.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_route53.get_record test.example.org example.org A
 
@@ -588,7 +590,7 @@ def get_record(
             else:
                 _zone = conn.get_zone(zone)
             if not _zone:
-                msg = "Failed to retrieve zone {0}".format(zone)
+                msg = "Failed to retrieve zone {}".format(zone)
                 log.error(msg)
                 return None
             _type = record_type.upper()
@@ -613,7 +615,7 @@ def get_record(
                 time.sleep(3)
                 error_retries -= 1
                 continue
-            six.reraise(*sys.exc_info())
+            raise
 
     if _record:
         ret["name"] = _decode_name(_record.name)
@@ -657,7 +659,9 @@ def add_record(
     """
     Add a record to a zone.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_route53.add_record test.example.org 1.1.1.1 example.org A
 
@@ -695,7 +699,7 @@ def add_record(
             else:
                 _zone = conn.get_zone(zone)
             if not _zone:
-                msg = "Failed to retrieve zone {0}".format(zone)
+                msg = "Failed to retrieve zone {}".format(zone)
                 log.error(msg)
                 return False
             _type = record_type.upper()
@@ -713,7 +717,7 @@ def add_record(
                 time.sleep(3)
                 error_retries -= 1
                 continue
-            six.reraise(*sys.exc_info())
+            raise
 
     _value = _munge_value(value, _type)
     while error_retries > 0:
@@ -736,7 +740,7 @@ def add_record(
                 time.sleep(3)
                 error_retries -= 1
                 continue
-            six.reraise(*sys.exc_info())
+            raise
     return False
 
 
@@ -762,7 +766,9 @@ def update_record(
     """
     Modify a record in a zone.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_route53.modify_record test.example.org 1.1.1.1 example.org A
 
@@ -792,7 +798,7 @@ def update_record(
     else:
         _zone = conn.get_zone(zone)
     if not _zone:
-        msg = "Failed to retrieve zone {0}".format(zone)
+        msg = "Failed to retrieve zone {}".format(zone)
         log.error(msg)
         return False
     _type = record_type.upper()
@@ -824,7 +830,7 @@ def update_record(
                 time.sleep(3)
                 error_retries -= 1
                 continue
-            six.reraise(*sys.exc_info())
+            raise
     return False
 
 
@@ -849,7 +855,9 @@ def delete_record(
     """
     Modify a record in a zone.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_route53.delete_record test.example.org example.org A
 
@@ -879,7 +887,7 @@ def delete_record(
     else:
         _zone = conn.get_zone(zone)
     if not _zone:
-        msg = "Failed to retrieve zone {0}".format(zone)
+        msg = "Failed to retrieve zone {}".format(zone)
         log.error(msg)
         return False
     _type = record_type.upper()
@@ -912,7 +920,7 @@ def delete_record(
                 time.sleep(3)
                 error_retries -= 1
                 continue
-            six.reraise(*sys.exc_info())
+            raise
 
 
 def _try_func(conn, func, **args):
@@ -1027,7 +1035,9 @@ def create_hosted_zone(
     profile
         Dict, or pillar key pointing to a dict, containing AWS region/key/keyid.
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_route53.create_hosted_zone example.org
     """
