@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Support for RFC 2136 dynamic DNS updates.
 
@@ -23,21 +22,18 @@ Support for RFC 2136 dynamic DNS updates.
 
         {"keyname.": "keycontent"}
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import python libs
 import logging
 
 import salt.utils.files
 import salt.utils.json
-from salt.ext import six
 
 log = logging.getLogger(__name__)
 
 try:
     import dns.query
-    import dns.update
-    import dns.tsigkeyring
+    import dns.update  # pylint: disable=no-name-in-module
+    import dns.tsigkeyring  # pylint: disable=no-name-in-module
 
     dns_support = True
 except ImportError as e:
@@ -66,7 +62,7 @@ def _config(name, key=None, **kwargs):
     if name in kwargs:
         value = kwargs[name]
     else:
-        value = __salt__["config.option"]("ddns.{0}".format(key))
+        value = __salt__["config.option"]("ddns.{}".format(key))
         if not value:
             value = None
     return value
@@ -104,7 +100,7 @@ def add_host(
     if res is False:
         return False
 
-    fqdn = "{0}.{1}.".format(name, zone)
+    fqdn = "{}.{}.".format(name, zone)
     parts = ip.split(".")[::-1]
     popped = []
 
@@ -112,7 +108,7 @@ def add_host(
     while len(parts) > 1:
         p = parts.pop(0)
         popped.append(p)
-        zone = "{0}.{1}".format(".".join(parts), "in-addr.arpa.")
+        zone = "{}.{}".format(".".join(parts), "in-addr.arpa.")
         name = ".".join(popped)
         ptr = update(
             zone, name, ttl, "PTR", fqdn, nameserver, timeout, replace, port, **kwargs
@@ -134,7 +130,7 @@ def delete_host(zone, name, nameserver="127.0.0.1", timeout=5, port=53, **kwargs
 
         salt ns1 ddns.delete_host example.com host1
     """
-    fqdn = "{0}.{1}".format(name, zone)
+    fqdn = "{}.{}".format(name, zone)
     request = dns.message.make_query(fqdn, "A")
     answer = dns.query.udp(request, nameserver, timeout, port)
     try:
@@ -155,7 +151,7 @@ def delete_host(zone, name, nameserver="127.0.0.1", timeout=5, port=53, **kwargs
         while len(parts) > 1:
             p = parts.pop(0)
             popped.append(p)
-            zone = "{0}.{1}".format(".".join(parts), "in-addr.arpa.")
+            zone = "{}.{}".format(".".join(parts), "in-addr.arpa.")
             name = ".".join(popped)
             ptr = delete(
                 zone,
@@ -196,12 +192,12 @@ def update(
 
         salt ns1 ddns.update example.com host1 60 A 10.0.0.1
     """
-    name = six.text_type(name)
+    name = str(name)
 
     if name[-1:] == ".":
         fqdn = name
     else:
-        fqdn = "{0}.{1}".format(name, zone)
+        fqdn = "{}.{}".format(name, zone)
 
     request = dns.message.make_query(fqdn, rdtype)
     answer = dns.query.udp(request, nameserver, timeout, port)
@@ -255,12 +251,12 @@ def delete(
 
         salt ns1 ddns.delete example.com host1 A
     """
-    name = six.text_type(name)
+    name = str(name)
 
     if name[-1:] == ".":
         fqdn = name
     else:
-        fqdn = "{0}.{1}".format(name, zone)
+        fqdn = "{}.{}".format(name, zone)
 
     request = dns.message.make_query(fqdn, (rdtype or "ANY"))
     answer = dns.query.udp(request, nameserver, timeout, port)
