@@ -1,57 +1,63 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Module to manage FreeBSD kernel modules
-'''
+"""
+from __future__ import absolute_import, print_function, unicode_literals
 
 # Import python libs
 import os
 import re
 
 # Import salt libs
-import salt.utils
+import salt.utils.files
 
 # Define the module's virtual name
-__virtualname__ = 'kmod'
+__virtualname__ = "kmod"
 
 
 _LOAD_MODULE = '{0}_load="YES"'
-_LOADER_CONF = '/boot/loader.conf'
+_LOADER_CONF = "/boot/loader.conf"
 _MODULE_RE = '^{0}_load="YES"'
 _MODULES_RE = r'^(\w+)_load="YES"'
 
 
 def __virtual__():
-    '''
+    """
     Only runs on FreeBSD systems
-    '''
-    return __virtualname__ if __grains__['kernel'] == 'FreeBSD' else False
+    """
+    if __grains__["kernel"] == "FreeBSD":
+        return __virtualname__
+    return (
+        False,
+        "The freebsdkmod execution module cannot be loaded: only available on FreeBSD systems.",
+    )
 
 
 def _new_mods(pre_mods, post_mods):
-    '''
+    """
     Return a list of the new modules, pass an kldstat dict before running
     modprobe and one after modprobe has run
-    '''
+    """
     pre = set()
     post = set()
     for mod in pre_mods:
-        pre.add(mod['module'])
+        pre.add(mod["module"])
     for mod in post_mods:
-        post.add(mod['module'])
+        post.add(mod["module"])
     return post - pre
 
 
 def _rm_mods(pre_mods, post_mods):
-    '''
+    """
     Return a list of the new modules, pass an kldstat dict before running
     modprobe and one after modprobe has run
-    '''
+    """
     pre = set()
     post = set()
     for mod in pre_mods:
-        pre.add(mod['module'])
+        pre.add(mod["module"])
     for mod in post_mods:
-        post.add(mod['module'])
+        post.add(mod["module"])
     return pre - post
 
 
@@ -63,12 +69,13 @@ def _get_module_name(line):
 
 
 def _get_persistent_modules():
-    '''
+    """
     Returns a list of modules in loader.conf that load on boot.
-    '''
+    """
     mods = set()
-    with salt.utils.fopen(_LOADER_CONF, 'r') as loader_conf:
+    with salt.utils.files.fopen(_LOADER_CONF, "r") as loader_conf:
         for line in loader_conf:
+            line = salt.utils.stringutils.to_unicode(line)
             line = line.strip()
             mod_name = _get_module_name(line)
             if mod_name:
@@ -77,28 +84,33 @@ def _get_persistent_modules():
 
 
 def _set_persistent_module(mod):
-    '''
+    """
     Add a module to loader.conf to make it persistent.
-    '''
-    if not mod or mod in mod_list(True) or mod not in \
-            available():
+    """
+    if not mod or mod in mod_list(True) or mod not in available():
         return set()
-    __salt__['file.append'](_LOADER_CONF, _LOAD_MODULE.format(mod))
+    __salt__["file.append"](_LOADER_CONF, _LOAD_MODULE.format(mod))
     return set([mod])
 
 
-def _remove_persistent_module(mod):
-    '''
-    Remove module from loader.conf.
-    '''
+def _remove_persistent_module(mod, comment):
+    """
+    Remove module from loader.conf. If comment is true only comment line where
+    module is.
+    """
     if not mod or mod not in mod_list(True):
         return set()
-    __salt__['file.sed'](_LOADER_CONF, _MODULE_RE.format(mod), '')
+
+    if comment:
+        __salt__["file.comment"](_LOADER_CONF, _MODULE_RE.format(mod))
+    else:
+        __salt__["file.sed"](_LOADER_CONF, _MODULE_RE.format(mod), "")
+
     return set([mod])
 
 
 def available():
-    '''
+    """
     Return a list of all available kernel modules
 
     CLI Example:
@@ -106,19 +118,19 @@ def available():
     .. code-block:: bash
 
         salt '*' kmod.available
-    '''
+    """
     ret = []
-    for path in __salt__['file.find']('/boot/kernel', name='*.ko$'):
+    for path in __salt__["file.find"]("/boot/kernel", name="*.ko$"):
         bpath = os.path.basename(path)
-        comps = bpath.split('.')
-        if 'ko' in comps:
+        comps = bpath.split(".")
+        if "ko" in comps:
             # This is a kernel module, return it without the .ko extension
-            ret.append('.'.join(comps[:comps.index('ko')]))
+            ret.append(".".join(comps[: comps.index("ko")]))
     return ret
 
 
 def check_available(mod):
-    '''
+    """
     Check to see if the specified kernel module is available
 
     CLI Example:
@@ -126,12 +138,12 @@ def check_available(mod):
     .. code-block:: bash
 
         salt '*' kmod.check_available vmm
-    '''
+    """
     return mod in available()
 
 
 def lsmod():
-    '''
+    """
     Return a dict containing information about currently loaded modules
 
     CLI Example:
@@ -139,26 +151,22 @@ def lsmod():
     .. code-block:: bash
 
         salt '*' kmod.lsmod
-    '''
+    """
     ret = []
-    for line in __salt__['cmd.run']('kldstat').splitlines():
+    for line in __salt__["cmd.run"]("kldstat").splitlines():
         comps = line.split()
         if not len(comps) > 2:
             continue
-        if comps[0] == 'Id':
+        if comps[0] == "Id":
             continue
-        if comps[4] == 'kernel':
+        if comps[4] == "kernel":
             continue
-        ret.append({
-            'module': comps[4][:-3],
-            'size': comps[3],
-            'depcount': comps[1]
-        })
+        ret.append({"module": comps[4][:-3], "size": comps[3], "depcount": comps[1]})
     return ret
 
 
 def mod_list(only_persist=False):
-    '''
+    """
     Return a list of the loaded module names
 
     CLI Example:
@@ -166,7 +174,7 @@ def mod_list(only_persist=False):
     .. code-block:: bash
 
         salt '*' kmod.mod_list
-    '''
+    """
     mods = set()
     if only_persist:
         if not _get_persistent_modules():
@@ -175,12 +183,12 @@ def mod_list(only_persist=False):
             mods.add(mod)
     else:
         for mod in lsmod():
-            mods.add(mod['module'])
+            mods.add(mod["module"])
     return sorted(list(mods))
 
 
 def load(mod, persist=False):
-    '''
+    """
     Load the specified kernel module
 
     mod
@@ -194,18 +202,17 @@ def load(mod, persist=False):
     .. code-block:: bash
 
         salt '*' kmod.load bhyve
-    '''
+    """
     pre_mods = lsmod()
-    response = __salt__['cmd.run_all']('kldload {0}'.format(mod),
-                                       python_shell=False)
-    if response['retcode'] == 0:
+    response = __salt__["cmd.run_all"]("kldload {0}".format(mod), python_shell=False)
+    if response["retcode"] == 0:
         post_mods = lsmod()
         mods = _new_mods(pre_mods, post_mods)
         persist_mods = set()
         if persist:
             persist_mods = _set_persistent_module(mod)
         return sorted(list(mods | persist_mods))
-    elif 'module already loaded or in kernel' in response['stderr']:
+    elif "module already loaded or in kernel" in response["stderr"]:
         if persist and mod not in _get_persistent_modules():
             persist_mods = _set_persistent_module(mod)
             return sorted(list(persist_mods))
@@ -213,11 +220,11 @@ def load(mod, persist=False):
             # It's compiled into the kernel
             return [None]
     else:
-        return 'Module {0} not found'.format(mod)
+        return "Module {0} not found".format(mod)
 
 
 def is_loaded(mod):
-    '''
+    """
     Check to see if the specified kernel module is loaded
 
     CLI Example:
@@ -225,26 +232,38 @@ def is_loaded(mod):
     .. code-block:: bash
 
         salt '*' kmod.is_loaded vmm
-    '''
+    """
     return mod in mod_list()
 
 
-def remove(mod, persist=False):
-    '''
+def remove(mod, persist=False, comment=True):
+    """
     Remove the specified kernel module
 
+    mod
+        Name of module to remove
+
+    persist
+        Also remove module from /boot/loader.conf
+
+    comment
+        If persist is set don't remove line from /boot/loader.conf but only
+        comment it
+
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' kmod.remove vmm
-    '''
+    """
     pre_mods = lsmod()
-    __salt__['cmd.run_all']('kldunload {0}'.format(mod),
-                            python_shell=False)
-    post_mods = lsmod()
-    mods = _rm_mods(pre_mods, post_mods)
-    persist_mods = set()
-    if persist:
-        persist_mods = _remove_persistent_module(mod)
-    return sorted(list(mods | persist_mods))
+    res = __salt__["cmd.run_all"]("kldunload {0}".format(mod), python_shell=False)
+    if res["retcode"] == 0:
+        post_mods = lsmod()
+        mods = _rm_mods(pre_mods, post_mods)
+        persist_mods = set()
+        if persist:
+            persist_mods = _remove_persistent_module(mod, comment)
+        return sorted(list(mods | persist_mods))
+    else:
+        return "Error removing module {0}: {1}".format(mod, res["stderr"])
