@@ -1,81 +1,80 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Return/control aspects of the grains data
-'''
 
-# Import python libs
-from __future__ import absolute_import, print_function
-import os
-import copy
-import math
-import random
-import logging
-import operator
+Grains set or altered with this module are stored in the 'grains'
+file on the minions. By default, this file is located at: ``/etc/salt/grains``
+
+.. Note::
+
+   This does **NOT** override any grains set in the minion config file.
+"""
+
+
 import collections
-import json
-import fnmatch
+import logging
+import math
+import operator
+import os
+import random
+from collections.abc import Mapping
 from functools import reduce  # pylint: disable=redefined-builtin
 
-# Import 3rd-party libs
-import yaml
 import salt.utils.compat
-from salt.utils.odict import OrderedDict
-import salt.ext.six as six
-from salt.ext.six.moves import range  # pylint: disable=import-error,no-name-in-module,redefined-builtin
-
-# Import salt libs
-import salt.utils
-import salt.utils.dictupdate
+import salt.utils.data
+import salt.utils.files
+import salt.utils.json
+import salt.utils.platform
+import salt.utils.yaml
 from salt.defaults import DEFAULT_TARGET_DELIM
 from salt.exceptions import SaltException
 
-__proxyenabled__ = ['*']
+__proxyenabled__ = ["*"]
 
 # Seed the grains dict so cython will build
 __grains__ = {}
 
 # Change the default outputter to make it more readable
 __outputter__ = {
-    'items': 'nested',
-    'item': 'nested',
-    'setval': 'nested',
+    "items": "nested",
+    "item": "nested",
+    "setval": "nested",
 }
 
 # http://stackoverflow.com/a/12414913/127816
 _infinitedict = lambda: collections.defaultdict(_infinitedict)
 
-_non_existent_key = 'NonExistentValueMagicNumberSpK3hnufdHfeBUXCfqVK'
+_non_existent_key = "NonExistentValueMagicNumberSpK3hnufdHfeBUXCfqVK"
 
 log = logging.getLogger(__name__)
 
 
 def _serial_sanitizer(instr):
-    '''Replaces the last 1/4 of a string with X's'''
+    """Replaces the last 1/4 of a string with X's"""
     length = len(instr)
-    index = int(math.floor(length * .75))
-    return '{0}{1}'.format(instr[:index], 'X' * (length - index))
+    index = int(math.floor(length * 0.75))
+    return "{}{}".format(instr[:index], "X" * (length - index))
 
 
-_FQDN_SANITIZER = lambda x: 'MINION.DOMAINNAME'
-_HOSTNAME_SANITIZER = lambda x: 'MINION'
-_DOMAINNAME_SANITIZER = lambda x: 'DOMAINNAME'
+_FQDN_SANITIZER = lambda x: "MINION.DOMAINNAME"
+_HOSTNAME_SANITIZER = lambda x: "MINION"
+_DOMAINNAME_SANITIZER = lambda x: "DOMAINNAME"
 
 
 # A dictionary of grain -> function mappings for sanitizing grain output. This
 # is used when the 'sanitize' flag is given.
 _SANITIZERS = {
-    'serialnumber': _serial_sanitizer,
-    'domain': _DOMAINNAME_SANITIZER,
-    'fqdn': _FQDN_SANITIZER,
-    'id': _FQDN_SANITIZER,
-    'host': _HOSTNAME_SANITIZER,
-    'localhost': _HOSTNAME_SANITIZER,
-    'nodename': _HOSTNAME_SANITIZER,
+    "serialnumber": _serial_sanitizer,
+    "domain": _DOMAINNAME_SANITIZER,
+    "fqdn": _FQDN_SANITIZER,
+    "id": _FQDN_SANITIZER,
+    "host": _HOSTNAME_SANITIZER,
+    "localhost": _HOSTNAME_SANITIZER,
+    "nodename": _HOSTNAME_SANITIZER,
 }
 
 
-def get(key, default='', delimiter=DEFAULT_TARGET_DELIM, ordered=True):
-    '''
+def get(key, default="", delimiter=DEFAULT_TARGET_DELIM, ordered=True):
+    """
     Attempt to retrieve the named value from grains, if the named value is not
     available return the passed default. The default return is an empty string.
 
@@ -108,20 +107,17 @@ def get(key, default='', delimiter=DEFAULT_TARGET_DELIM, ordered=True):
 
         salt '*' grains.get pkg:apache
         salt '*' grains.get abc::def|ghi delimiter='|'
-    '''
+    """
     if ordered is True:
         grains = __grains__
     else:
-        grains = json.loads(json.dumps(__grains__))
-    return salt.utils.traverse_dict_and_list(grains,
-                                             key,
-                                             default,
-                                             delimiter)
+        grains = salt.utils.json.loads(salt.utils.json.dumps(__grains__))
+    return salt.utils.data.traverse_dict_and_list(grains, key, default, delimiter)
 
 
 def has_value(key):
-    '''
-    Determine whether a named value exists in the grains dictionary.
+    """
+    Determine whether a key exists in the grains dictionary.
 
     Given a grains dictionary that contains the following structure::
 
@@ -136,12 +132,15 @@ def has_value(key):
     .. code-block:: bash
 
         salt '*' grains.has_value pkg:apache
-    '''
-    return True if salt.utils.traverse_dict_and_list(__grains__, key, False) else False
+    """
+    return (
+        salt.utils.data.traverse_dict_and_list(__grains__, key, KeyError)
+        is not KeyError
+    )
 
 
 def items(sanitize=False):
-    '''
+    """
     Return all of the minion's grains
 
     CLI Example:
@@ -155,19 +154,19 @@ def items(sanitize=False):
     .. code-block:: bash
 
         salt '*' grains.items sanitize=True
-    '''
-    if salt.utils.is_true(sanitize):
+    """
+    if salt.utils.data.is_true(sanitize):
         out = dict(__grains__)
-        for key, func in six.iteritems(_SANITIZERS):
+        for key, func in _SANITIZERS.items():
             if key in out:
                 out[key] = func(out[key])
         return out
     else:
-        return __grains__
+        return dict(__grains__)
 
 
 def item(*args, **kwargs):
-    '''
+    """
     Return one or more grains
 
     CLI Example:
@@ -182,70 +181,85 @@ def item(*args, **kwargs):
     .. code-block:: bash
 
         salt '*' grains.item host sanitize=True
-    '''
+    """
     ret = {}
-    default = kwargs.get('default', '')
-    delimiter = kwargs.get('delimiter', DEFAULT_TARGET_DELIM)
+    default = kwargs.get("default", "")
+    delimiter = kwargs.get("delimiter", DEFAULT_TARGET_DELIM)
 
     try:
         for arg in args:
-            ret[arg] = salt.utils.traverse_dict_and_list(__grains__,
-                                                        arg,
-                                                        default,
-                                                        delimiter)
+            ret[arg] = salt.utils.data.traverse_dict_and_list(
+                __grains__, arg, default, delimiter
+            )
     except KeyError:
         pass
 
-    if salt.utils.is_true(kwargs.get('sanitize')):
-        for arg, func in six.iteritems(_SANITIZERS):
+    if salt.utils.data.is_true(kwargs.get("sanitize")):
+        for arg, func in _SANITIZERS.items():
             if arg in ret:
                 ret[arg] = func(ret[arg])
     return ret
 
 
-def setvals(grains, destructive=False):
-    '''
+def setvals(grains, destructive=False, refresh_pillar=True):
+    """
     Set new grains values in the grains config file
 
     destructive
         If an operation results in a key being removed, delete the key, too.
         Defaults to False.
 
+    refresh_pillar
+        Whether pillar will be refreshed.
+        Defaults to True.
+
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' grains.setvals "{'key1': 'val1', 'key2': 'val2'}"
-    '''
+    """
     new_grains = grains
-    if not isinstance(new_grains, collections.Mapping):
-        raise SaltException('setvals grains must be a dictionary.')
+    if not isinstance(new_grains, Mapping):
+        raise SaltException("setvals grains must be a dictionary.")
     grains = {}
-    if os.path.isfile(__opts__['conf_file']):
-        gfn = os.path.join(
-            os.path.dirname(__opts__['conf_file']),
-            'grains'
-        )
-    elif os.path.isdir(__opts__['conf_file']):
-        gfn = os.path.join(
-            __opts__['conf_file'],
-            'grains'
-        )
+    if os.path.isfile(__opts__["conf_file"]):
+        if salt.utils.platform.is_proxy():
+            gfn = os.path.join(
+                os.path.dirname(__opts__["conf_file"]),
+                "proxy.d",
+                __opts__["id"],
+                "grains",
+            )
+        else:
+            gfn = os.path.join(os.path.dirname(__opts__["conf_file"]), "grains")
+    elif os.path.isdir(__opts__["conf_file"]):
+        if salt.utils.platform.is_proxy():
+            gfn = os.path.join(
+                __opts__["conf_file"], "proxy.d", __opts__["id"], "grains"
+            )
+        else:
+            gfn = os.path.join(__opts__["conf_file"], "grains")
     else:
-        gfn = os.path.join(
-            os.path.dirname(__opts__['conf_file']),
-            'grains'
-        )
+        if salt.utils.platform.is_proxy():
+            gfn = os.path.join(
+                os.path.dirname(__opts__["conf_file"]),
+                "proxy.d",
+                __opts__["id"],
+                "grains",
+            )
+        else:
+            gfn = os.path.join(os.path.dirname(__opts__["conf_file"]), "grains")
 
     if os.path.isfile(gfn):
-        with salt.utils.fopen(gfn, 'rb') as fp_:
+        with salt.utils.files.fopen(gfn, "rb") as fp_:
             try:
-                grains = yaml.safe_load(fp_.read())
-            except yaml.YAMLError as exc:
-                return 'Unable to read existing grains file: {0}'.format(exc)
+                grains = salt.utils.yaml.safe_load(fp_)
+            except salt.utils.yaml.YAMLError as exc:
+                return "Unable to read existing grains file: {}".format(exc)
         if not isinstance(grains, dict):
             grains = {}
-    for key, val in six.iteritems(new_grains):
+    for key, val in new_grains.items():
         if val is None and destructive is True:
             if key in grains:
                 del grains[key]
@@ -254,45 +268,26 @@ def setvals(grains, destructive=False):
         else:
             grains[key] = val
             __grains__[key] = val
-    # Cast defaultdict to dict; is there a more central place to put this?
     try:
-        yaml_reps = copy.deepcopy(yaml.representer.SafeRepresenter.yaml_representers)
-        yaml_multi_reps = copy.deepcopy(yaml.representer.SafeRepresenter.yaml_multi_representers)
-    except (TypeError, NameError):
-        # This likely means we are running under Python 2.6 which cannot deepcopy
-        # bound methods. Fallback to a modification of deepcopy which can support
-        # this behavior.
-        yaml_reps = salt.utils.compat.deepcopy_bound(yaml.representer.SafeRepresenter.yaml_representers)
-        yaml_multi_reps = salt.utils.compat.deepcopy_bound(yaml.representer.SafeRepresenter.yaml_multi_representers)
-    yaml.representer.SafeRepresenter.add_representer(collections.defaultdict,
-            yaml.representer.SafeRepresenter.represent_dict)
-    yaml.representer.SafeRepresenter.add_representer(OrderedDict,
-            yaml.representer.SafeRepresenter.represent_dict)
-    cstr = yaml.safe_dump(grains, default_flow_style=False)
-    yaml.representer.SafeRepresenter.yaml_representers = yaml_reps
-    yaml.representer.SafeRepresenter.yaml_multi_representers = yaml_multi_reps
+        with salt.utils.files.fopen(gfn, "w+", encoding="utf-8") as fp_:
+            salt.utils.yaml.safe_dump(grains, fp_, default_flow_style=False)
+    except OSError:
+        log.error("Unable to write to grains file at %s. Check permissions.", gfn)
+    fn_ = os.path.join(__opts__["cachedir"], "module_refresh")
     try:
-        with salt.utils.fopen(gfn, 'w+') as fp_:
-            fp_.write(cstr)
-    except (IOError, OSError):
-        msg = 'Unable to write to grains file at {0}. Check permissions.'
-        log.error(msg.format(gfn))
-    fn_ = os.path.join(__opts__['cachedir'], 'module_refresh')
-    try:
-        with salt.utils.flopen(fn_, 'w+') as fp_:
-            fp_.write('')
-    except (IOError, OSError):
-        msg = 'Unable to write to cache file {0}. Check permissions.'
-        log.error(msg.format(fn_))
-    if not __opts__.get('local', False):
-        # Sync the grains
-        __salt__['saltutil.sync_grains']()
+        with salt.utils.files.flopen(fn_, "w+"):
+            pass
+    except OSError:
+        log.error("Unable to write to cache file %s. Check permissions.", fn_)
+    if not __opts__.get("local", False):
+        # Refresh the grains
+        __salt__["saltutil.refresh_grains"](refresh_pillar=refresh_pillar)
     # Return the grains we just set to confirm everything was OK
     return new_grains
 
 
-def setval(key, val, destructive=False):
-    '''
+def setval(key, val, destructive=False, refresh_pillar=True):
+    """
     Set a grains value in the grains config file
 
     key
@@ -305,18 +300,22 @@ def setval(key, val, destructive=False):
         If an operation results in a key being removed, delete the key, too.
         Defaults to False.
 
+    refresh_pillar
+        Whether pillar will be refreshed.
+        Defaults to True.
+
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' grains.setval key val
         salt '*' grains.setval key "{'sub-key': 'val', 'sub-key2': 'val2'}"
-    '''
-    return setvals({key: val}, destructive)
+    """
+    return setvals({key: val}, destructive, refresh_pillar=refresh_pillar)
 
 
 def append(key, val, convert=False, delimiter=DEFAULT_TARGET_DELIM):
-    '''
+    """
     .. versionadded:: 0.17.0
 
     Append a value to a list in the grains config file. If the grain doesn't
@@ -347,15 +346,15 @@ def append(key, val, convert=False, delimiter=DEFAULT_TARGET_DELIM):
     .. code-block:: bash
 
         salt '*' grains.append key val
-    '''
+    """
     grains = get(key, [], delimiter)
     if convert:
         if not isinstance(grains, list):
             grains = [] if grains is None else [grains]
     if not isinstance(grains, list):
-        return 'The key {0} is not a valid list'.format(key)
+        return "The key {} is not a valid list".format(key)
     if val in grains:
-        return 'The val {0} was already in the list {1}'.format(val, key)
+        return "The val {} was already in the list {}".format(val, key)
     if isinstance(val, list):
         for item in val:
             grains.append(item)
@@ -373,7 +372,7 @@ def append(key, val, convert=False, delimiter=DEFAULT_TARGET_DELIM):
 
 
 def remove(key, val, delimiter=DEFAULT_TARGET_DELIM):
-    '''
+    """
     .. versionadded:: 0.17.0
 
     Remove a value from a list in the grains config file
@@ -397,12 +396,12 @@ def remove(key, val, delimiter=DEFAULT_TARGET_DELIM):
     .. code-block:: bash
 
         salt '*' grains.remove key val
-    '''
+    """
     grains = get(key, [], delimiter)
     if not isinstance(grains, list):
-        return 'The key {0} is not a valid list'.format(key)
+        return "The key {} is not a valid list".format(key)
     if val not in grains:
-        return 'The val {0} was not in the list {1}'.format(val, key)
+        return "The val {} was not in the list {}".format(val, key)
     grains.remove(val)
 
     while delimiter in key:
@@ -415,11 +414,36 @@ def remove(key, val, delimiter=DEFAULT_TARGET_DELIM):
     return setval(key, grains)
 
 
-def delval(key, destructive=False):
-    '''
+def delkey(key, force=False):
+    """
+    .. versionadded:: 2017.7.0
+
+    Remove a grain completely from the grain system, this will remove the
+    grain key and value
+
+    key
+        The grain key from which to delete the value.
+
+    force
+        Force remove the grain even when it is a mapped value.
+        Defaults to False
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' grains.delkey key
+    """
+    return delval(key, destructive=True, force=force)
+
+
+def delval(key, destructive=False, force=False):
+    """
     .. versionadded:: 0.17.0
 
-    Delete a grain from the grains config file
+    Delete a grain value from the grains config file. This will just set the
+    grain value to ``None``. To completely remove the grain, run ``grains.delkey``
+    or pass ``destructive=True`` to ``grains.delval``.
 
     key
         The grain key from which to delete the value.
@@ -427,18 +451,21 @@ def delval(key, destructive=False):
     destructive
         Delete the key, too. Defaults to False.
 
+    force
+        Force remove the grain even when it is a mapped value.
+        Defaults to False
+
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' grains.delval key
-    '''
-
-    setval(key, None, destructive=destructive)
+    """
+    return set(key, None, destructive=destructive, force=force)
 
 
 def ls():  # pylint: disable=C0103
-    '''
+    """
     Return a list of all available grains
 
     CLI Example:
@@ -446,12 +473,12 @@ def ls():  # pylint: disable=C0103
     .. code-block:: bash
 
         salt '*' grains.ls
-    '''
+    """
     return sorted(__grains__)
 
 
-def filter_by(lookup_dict, grain='os_family', merge=None, default='default', base=None):
-    '''
+def filter_by(lookup_dict, grain="os_family", merge=None, default="default", base=None):
+    """
     .. versionadded:: 0.17.0
 
     Look up the given grain in a given dictionary for the current OS and return
@@ -552,57 +579,25 @@ def filter_by(lookup_dict, grain='os_family', merge=None, default='default', bas
         # next one renders {A: {B: G}, D: J}
         salt '*' grains.filter_by '{default: {A: {B: C}, D: E}, F: {A: {B: G}}, H: {D: I}}' 'xxx' '{D: J}' 'F' 'default'
         # next same as above when default='H' instead of 'F' renders {A: {B: C}, D: J}
-    '''
-
-    ret = None
-    # Default value would be an empty list if grain not found
-    val = salt.utils.traverse_dict_and_list(__grains__, grain, [])
-
-    # Iterate over the list of grain values to match against patterns in the lookup_dict keys
-    for each in val if isinstance(val, list) else [val]:
-        for key in sorted(lookup_dict):
-            test_key = key if isinstance(key, six.string_types) else str(key)
-            test_each = each if isinstance(each, six.string_types) else str(each)
-            if fnmatch.fnmatchcase(test_each, test_key):
-                ret = lookup_dict[key]
-                break
-        if ret is not None:
-            break
-
-    if ret is None:
-        ret = lookup_dict.get(default, None)
-
-    if base and base in lookup_dict:
-        base_values = lookup_dict[base]
-        if ret is None:
-            ret = base_values
-
-        elif isinstance(base_values, collections.Mapping):
-            if not isinstance(ret, collections.Mapping):
-                raise SaltException(
-                    'filter_by default and look-up values must both be dictionaries.')
-            ret = salt.utils.dictupdate.update(copy.deepcopy(base_values), ret)
-
-    if merge:
-        if not isinstance(merge, collections.Mapping):
-            raise SaltException('filter_by merge argument must be a dictionary.')
-
-        if ret is None:
-            ret = merge
-        else:
-            salt.utils.dictupdate.update(ret, copy.deepcopy(merge))
-
-    return ret
+    """
+    return salt.utils.data.filter_by(
+        lookup_dict=lookup_dict,
+        lookup=grain,
+        traverse=__grains__,
+        merge=merge,
+        default=default,
+        base=base,
+    )
 
 
 def _dict_from_path(path, val, delimiter=DEFAULT_TARGET_DELIM):
-    '''
+    """
     Given a lookup string in the form of 'foo:bar:baz" return a nested
     dictionary of the appropriate depth with the final segment as a value.
 
     >>> _dict_from_path('foo:bar:baz', 'somevalue')
     {"foo": {"bar": {"baz": "somevalue"}}
-    '''
+    """
     nested_dict = _infinitedict()
     keys = path.rsplit(delimiter)
     lastplace = reduce(operator.getitem, keys[:-1], nested_dict)
@@ -611,10 +606,10 @@ def _dict_from_path(path, val, delimiter=DEFAULT_TARGET_DELIM):
     return nested_dict
 
 
-def get_or_set_hash(name,
-        length=8,
-        chars='abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)'):
-    '''
+def get_or_set_hash(
+    name, length=8, chars="abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)"
+):
+    """
     Perform a one-time generation of a hash and write it to the local grains.
     If that grain has already been set return the value instead.
 
@@ -643,11 +638,18 @@ def get_or_set_hash(name,
         as directives by the YAML parser, such as strings beginning with ``%``. To avoid
         issues when using the output of this function in an SLS file containing YAML+Jinja,
         surround the call with single quotes.
-    '''
+    """
+    salt.utils.versions.warn_until(
+        "Phosphorus",
+        "The 'grains.get_or_set_hash' function has been deprecated and it's "
+        "functionality will be completely removed. Reference pillar and SDB "
+        "documentation for secure ways to manage sensitive information. Grains "
+        "are an insecure way to store secrets.",
+    )
     ret = get(name, None)
 
     if ret is None:
-        val = ''.join([random.SystemRandom().choice(chars) for _ in range(length)])
+        val = "".join([random.SystemRandom().choice(chars) for _ in range(length)])
 
         if DEFAULT_TARGET_DELIM in name:
             root, rest = name.split(DEFAULT_TARGET_DELIM, 1)
@@ -661,12 +663,8 @@ def get_or_set_hash(name,
     return get(name)
 
 
-def set(key,
-        val='',
-        force=False,
-        destructive=False,
-        delimiter=DEFAULT_TARGET_DELIM):
-    '''
+def set(key, val="", force=False, destructive=False, delimiter=DEFAULT_TARGET_DELIM):
+    """
     Set a key to an arbitrary value. It is used like setval but works
     with nested keys.
 
@@ -690,46 +688,51 @@ def set(key,
 
         salt '*' grains.set 'apps:myApp:port' 2209
         salt '*' grains.set 'apps:myApp' '{port: 2209}'
-    '''
+    """
 
-    ret = {'comment': '',
-           'changes': {},
-           'result': True}
+    ret = {"comment": "", "changes": {}, "result": True}
 
     # Get val type
-    _new_value_type = 'simple'
+    _new_value_type = "simple"
     if isinstance(val, dict):
-        _new_value_type = 'complex'
+        _new_value_type = "complex"
     elif isinstance(val, list):
-        _new_value_type = 'complex'
+        _new_value_type = "complex"
 
     _non_existent = object()
     _existing_value = get(key, _non_existent, delimiter)
     _value = _existing_value
 
-    _existing_value_type = 'simple'
+    _existing_value_type = "simple"
     if _existing_value is _non_existent:
         _existing_value_type = None
     elif isinstance(_existing_value, dict):
-        _existing_value_type = 'complex'
+        _existing_value_type = "complex"
     elif isinstance(_existing_value, list):
-        _existing_value_type = 'complex'
+        _existing_value_type = "complex"
 
-    if _existing_value_type is not None and _existing_value == val \
-                   and (val is not None or destructive is not True):
-        ret['comment'] = 'Grain is already set'
+    if (
+        _existing_value_type is not None
+        and _existing_value == val
+        and (val is not None or destructive is not True)
+    ):
+        ret["comment"] = "Grain is already set"
         return ret
 
     if _existing_value is not None and not force:
-        if _existing_value_type == 'complex':
-            ret['comment'] = 'The key \'{0}\' exists but is a dict or a list. '.format(key) \
-                 + 'Use \'force=True\' to overwrite.'
-            ret['result'] = False
+        if _existing_value_type == "complex":
+            ret["comment"] = (
+                "The key '{}' exists but is a dict or a list. "
+                "Use 'force=True' to overwrite.".format(key)
+            )
+            ret["result"] = False
             return ret
-        elif _new_value_type == 'complex' and _existing_value_type is not None:
-            ret['comment'] = 'The key \'{0}\' exists and the given value is a '.format(key) \
-                 + 'dict or a list. Use \'force=True\' to overwrite.'
-            ret['result'] = False
+        elif _new_value_type == "complex" and _existing_value_type is not None:
+            ret["comment"] = (
+                "The key '{}' exists and the given value is a dict or a "
+                "list. Use 'force=True' to overwrite.".format(key)
+            )
+            ret["result"] = False
             return ret
         else:
             _value = val
@@ -760,21 +763,42 @@ def set(key,
         elif _existing_value == rest or force:
             _existing_value = {rest: _value}
         else:
-            ret['comment'] = 'The key \'{0}\' value is \'{1}\', '.format(key, _existing_value) \
-                 + 'which is different from the provided key \'{0}\'. '.format(rest) \
-                 + 'Use \'force=True\' to overwrite.'
-            ret['result'] = False
+            ret["comment"] = (
+                "The key '{}' value is '{}', which is different from "
+                "the provided key '{}'. Use 'force=True' to overwrite.".format(
+                    key, _existing_value, rest
+                )
+            )
+            ret["result"] = False
             return ret
         _value = _existing_value
 
     _setval_ret = setval(key, _value, destructive=destructive)
     if isinstance(_setval_ret, dict):
-        ret['changes'] = _setval_ret
+        ret["changes"] = _setval_ret
     else:
-        ret['comment'] = _setval_ret
-        ret['result'] = False
+        ret["comment"] = _setval_ret
+        ret["result"] = False
     return ret
 
 
+def equals(key, value):
+    """
+    Used to make sure the minion's grain key/value matches.
+
+    Returns ``True`` if matches otherwise ``False``.
+
+    .. versionadded:: 2017.7.0
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' grains.equals fqdn <expected_fqdn>
+        salt '*' grains.equals systemd:version 219
+    """
+    return str(value) == str(get(key))
+
+
 # Provide a jinja function call compatible get aliased as fetch
 fetch = get
