@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 NAPALM NTP
 ==========
 
 Manages NTP on network devices.
 
-:codeauthor: Mircea Ulinic <mircea@cloudflare.com> & Jerome Fleury <jf@cloudflare.com>
+:codeauthor: Mircea Ulinic <ping@mirceaulinic.net> & Jerome Fleury <jf@cloudflare.com>
 :maturity:   new
 :depends:    napalm
 :platform:   unix
@@ -19,23 +19,26 @@ Dependencies
     :mod:`NTP peers management state <salt.states.netntp>`
 
 .. versionadded:: 2016.11.0
-'''
+"""
 
-from __future__ import absolute_import, unicode_literals, print_function
+from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
-log = logging.getLogger(__file__)
 
 # import NAPALM utils
 import salt.utils.napalm
 from salt.utils.napalm import proxy_napalm_wrap
 
+log = logging.getLogger(__file__)
+
+
 # ----------------------------------------------------------------------------------------------------------------------
 # module properties
 # ----------------------------------------------------------------------------------------------------------------------
 
-__virtualname__ = 'ntp'
-__proxyenabled__ = ['napalm']
+__virtualname__ = "ntp"
+__proxyenabled__ = ["napalm"]
+__virtual_aliases__ = ("napalm_ntp",)
 # uses NAPALM-based proxy to interact with network devices
 
 # ----------------------------------------------------------------------------------------------------------------------
@@ -44,11 +47,12 @@ __proxyenabled__ = ['napalm']
 
 
 def __virtual__():
-    '''
+    """
     NAPALM library must be installed for this module to work and run in a (proxy) minion.
-    '''
+    """
     return salt.utils.napalm.virtual(__opts__, __virtualname__, __file__)
 
+
 # ----------------------------------------------------------------------------------------------------------------------
 # helper functions -- will not be exported
 # ----------------------------------------------------------------------------------------------------------------------
@@ -61,7 +65,7 @@ def __virtual__():
 @proxy_napalm_wrap
 def peers(**kwargs):  # pylint: disable=unused-argument
 
-    '''
+    """
     Returns a list the NTP peers configured on the network device.
 
     :return: configured NTP peers as list.
@@ -83,21 +87,18 @@ def peers(**kwargs):  # pylint: disable=unused-argument
             '2400:cb00:6:1024::c71b:840a'
         ]
 
-    '''
+    """
 
     ntp_peers = salt.utils.napalm.call(
-        napalm_device,  # pylint: disable=undefined-variable
-        'get_ntp_peers',
-        **{
-        }
+        napalm_device, "get_ntp_peers", **{}  # pylint: disable=undefined-variable
     )
 
-    if not ntp_peers.get('result'):
+    if not ntp_peers.get("result"):
         return ntp_peers
 
-    ntp_peers_list = list(ntp_peers.get('out', {}).keys())
+    ntp_peers_list = list(ntp_peers.get("out", {}).keys())
 
-    ntp_peers['out'] = ntp_peers_list
+    ntp_peers["out"] = ntp_peers_list
 
     return ntp_peers
 
@@ -105,7 +106,7 @@ def peers(**kwargs):  # pylint: disable=unused-argument
 @proxy_napalm_wrap
 def servers(**kwargs):  # pylint: disable=unused-argument
 
-    '''
+    """
     Returns a list of the configured NTP servers on the device.
 
     CLI Example:
@@ -124,21 +125,18 @@ def servers(**kwargs):  # pylint: disable=unused-argument
             '172.17.17.2',
             '2400:cb00:6:1024::c71b:840a'
         ]
-    '''
+    """
 
     ntp_servers = salt.utils.napalm.call(
-        napalm_device,  # pylint: disable=undefined-variable
-        'get_ntp_servers',
-        **{
-        }
+        napalm_device, "get_ntp_servers", **{}  # pylint: disable=undefined-variable
     )
 
-    if not ntp_servers.get('result'):
+    if not ntp_servers.get("result"):
         return ntp_servers
 
-    ntp_servers_list = list(ntp_servers.get('out', {}).keys())
+    ntp_servers_list = list(ntp_servers.get("out", {}).keys())
 
-    ntp_servers['out'] = ntp_servers_list
+    ntp_servers["out"] = ntp_servers_list
 
     return ntp_servers
 
@@ -146,7 +144,7 @@ def servers(**kwargs):  # pylint: disable=unused-argument
 @proxy_napalm_wrap
 def stats(peer=None, **kwargs):  # pylint: disable=unused-argument
 
-    '''
+    """
     Returns a dictionary containing synchronization details of the NTP peers.
 
     :param peer: Returns only the details of a specific NTP peer.
@@ -189,26 +187,23 @@ def stats(peer=None, **kwargs):  # pylint: disable=unused-argument
                 'jitter'        : 2.695
             }
         ]
-    '''
+    """
 
     proxy_output = salt.utils.napalm.call(
-        napalm_device,  # pylint: disable=undefined-variable
-        'get_ntp_stats',
-        **{
-        }
+        napalm_device, "get_ntp_stats", **{}  # pylint: disable=undefined-variable
     )
 
-    if not proxy_output.get('result'):
+    if not proxy_output.get("result"):
         return proxy_output
 
-    ntp_peers = proxy_output.get('out')
+    ntp_peers = proxy_output.get("out")
 
     if peer:
-        ntp_peers = [ntp_peer for ntp_peer in ntp_peers if ntp_peer.get('remote', '') == peer]
+        ntp_peers = [
+            ntp_peer for ntp_peer in ntp_peers if ntp_peer.get("remote", "") == peer
+        ]
 
-    proxy_output.update({
-        'out': ntp_peers
-    })
+    proxy_output.update({"out": ntp_peers})
 
     return proxy_output
 
@@ -216,13 +211,13 @@ def stats(peer=None, **kwargs):  # pylint: disable=unused-argument
 @proxy_napalm_wrap
 def set_peers(*peers, **options):
 
-    '''
+    """
     Configures a list of NTP peers on the device.
 
     :param peers: list of IP Addresses/Domain Names
-    :param test (bool): discard loaded config. By default `test` is False (will
-        not dicard the changes)
-    :commit commit (bool): commit loaded config. By default `commit` is True
+    :param test (bool): discard loaded config. By default ``test`` is False
+        (will not dicard the changes)
+    :commit commit (bool): commit loaded config. By default ``commit`` is True
         (will commit the changes). Useful when the user does not want to commit
         after each change, but after a couple.
 
@@ -236,26 +231,31 @@ def set_peers(*peers, **options):
         salt '*' ntp.set_peers 192.168.0.1 172.17.17.1 time.apple.com
         salt '*' ntp.set_peers 172.17.17.1 test=True  # only displays the diff
         salt '*' ntp.set_peers 192.168.0.1 commit=False  # preserves the changes, but does not commit
-    '''
+    """
 
-    test = options.pop('test', False)
-    commit = options.pop('commit', True)
+    test = options.pop("test", False)
+    commit = options.pop("commit", True)
 
-    return __salt__['net.load_template']('set_ntp_peers',
-                                         peers=peers,
-                                         test=test,
-                                         commit=commit,
-                                         inherit_napalm_device=napalm_device)  # pylint: disable=undefined-variable
+    # pylint: disable=undefined-variable
+    return __salt__["net.load_template"](
+        "set_ntp_peers",
+        peers=peers,
+        test=test,
+        commit=commit,
+        inherit_napalm_device=napalm_device,
+    )
+    # pylint: enable=undefined-variable
 
 
 @proxy_napalm_wrap
 def set_servers(*servers, **options):
-    '''
+    """
     Configures a list of NTP servers on the device.
 
     :param servers: list of IP Addresses/Domain Names
-    :param test (bool): discard loaded config. By default `test` is False (will not dicard the changes)
-    :commit commit (bool): commit loaded config. By default `commit` is True
+    :param test (bool): discard loaded config. By default ``test`` is False
+        (will not dicard the changes)
+    :commit commit (bool): commit loaded config. By default ``commit`` is True
         (will commit the changes). Useful when the user does not want to commit
         after each change, but after a couple.
 
@@ -269,28 +269,32 @@ def set_servers(*servers, **options):
         salt '*' ntp.set_servers 192.168.0.1 172.17.17.1 time.apple.com
         salt '*' ntp.set_servers 172.17.17.1 test=True  # only displays the diff
         salt '*' ntp.set_servers 192.168.0.1 commit=False  # preserves the changes, but does not commit
-    '''
+    """
 
-    test = options.pop('test', False)
-    commit = options.pop('commit', True)
+    test = options.pop("test", False)
+    commit = options.pop("commit", True)
 
-    return __salt__['net.load_template']('set_ntp_servers',
-                                         servers=servers,
-                                         test=test,
-                                         commit=commit,
-                                         inherit_napalm_device=napalm_device)  # pylint: disable=undefined-variable
+    # pylint: disable=undefined-variable
+    return __salt__["net.load_template"](
+        "set_ntp_servers",
+        servers=servers,
+        test=test,
+        commit=commit,
+        inherit_napalm_device=napalm_device,
+    )
+    # pylint: enable=undefined-variable
 
 
 @proxy_napalm_wrap
 def delete_peers(*peers, **options):
 
-    '''
+    """
     Removes NTP peers configured on the device.
 
     :param peers: list of IP Addresses/Domain Names to be removed as NTP peers
-    :param test (bool): discard loaded config. By default `test` is False (will
-        not dicard the changes)
-    :param commit (bool): commit loaded config. By default `commit` is True
+    :param test (bool): discard loaded config. By default ``test`` is False
+        (will not dicard the changes)
+    :param commit (bool): commit loaded config. By default ``commit`` is True
         (will commit the changes). Useful when the user does not want to commit
         after each change, but after a couple.
 
@@ -305,29 +309,33 @@ def delete_peers(*peers, **options):
         salt '*' ntp.delete_peers 8.8.8.8 time.apple.com
         salt '*' ntp.delete_peers 172.17.17.1 test=True  # only displays the diff
         salt '*' ntp.delete_peers 192.168.0.1 commit=False  # preserves the changes, but does not commit
-    '''
+    """
 
-    test = options.pop('test', False)
-    commit = options.pop('commit', True)
+    test = options.pop("test", False)
+    commit = options.pop("commit", True)
 
-    return __salt__['net.load_template']('delete_ntp_peers',
-                                         peers=peers,
-                                         test=test,
-                                         commit=commit,
-                                         inherit_napalm_device=napalm_device)  # pylint: disable=undefined-variable
+    # pylint: disable=undefined-variable
+    return __salt__["net.load_template"](
+        "delete_ntp_peers",
+        peers=peers,
+        test=test,
+        commit=commit,
+        inherit_napalm_device=napalm_device,
+    )
+    # pylint: enable=undefined-variable
 
 
 @proxy_napalm_wrap
 def delete_servers(*servers, **options):
 
-    '''
+    """
     Removes NTP servers configured on the device.
 
     :param servers: list of IP Addresses/Domain Names to be removed as NTP
         servers
-    :param test (bool): discard loaded config. By default `test` is False (will
-        not dicard the changes)
-    :param commit (bool): commit loaded config. By default `commit` is True
+    :param test (bool): discard loaded config. By default ``test`` is False
+        (will not dicard the changes)
+    :param commit (bool): commit loaded config. By default ``commit`` is True
         (will commit the changes). Useful when the user does not want to commit
         after each change, but after a couple.
 
@@ -342,13 +350,17 @@ def delete_servers(*servers, **options):
         salt '*' ntp.delete_servers 8.8.8.8 time.apple.com
         salt '*' ntp.delete_servers 172.17.17.1 test=True  # only displays the diff
         salt '*' ntp.delete_servers 192.168.0.1 commit=False  # preserves the changes, but does not commit
-    '''
+    """
 
-    test = options.pop('test', False)
-    commit = options.pop('commit', True)
+    test = options.pop("test", False)
+    commit = options.pop("commit", True)
 
-    return __salt__['net.load_template']('delete_ntp_servers',
-                                         servers=servers,
-                                         test=test,
-                                         commit=commit,
-                                         inherit_napalm_device=napalm_device)  # pylint: disable=undefined-variable
+    # pylint: disable=undefined-variable
+    return __salt__["net.load_template"](
+        "delete_ntp_servers",
+        servers=servers,
+        test=test,
+        commit=commit,
+        inherit_napalm_device=napalm_device,
+    )
+    # pylint: enable=undefined-variable
