@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Simple and flexible YAML ext_pillar which can read pillar from within pillar.
 
 .. versionadded:: 2016.3.0
@@ -103,7 +102,7 @@ would actually end up in pillar after all merging was complete:
           - baz
 
 MakoStack configuration files
--------------------------------
+-----------------------------
 
 The config files that are referenced in the above ``ext_pillar`` configuration
 are mako templates which must render as a simple ordered list of ``yaml``
@@ -371,38 +370,34 @@ You can also select a custom merging strategy using a ``__`` object in a list:
 |       - tom    |       - __: overwrite   |       - mat             |
 |       - root   |       - mat             |                         |
 +----------------+-------------------------+-------------------------+
-'''
+"""
+
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 import functools
-import os
 import logging
+import os
 
-# Import Salt libs
 import salt.utils.yaml
 
-# Import 3rd-party libs
-from salt.ext import six
-
 try:
-    from mako.lookup import TemplateLookup
-    from mako import exceptions
+    from mako.lookup import TemplateLookup  # pylint: disable=no-name-in-module
+    from mako import exceptions  # pylint: disable=no-name-in-module
+
     HAS_MAKO = True
 except ImportError:
     HAS_MAKO = False
 
 log = logging.getLogger(__name__)
-strategies = ('overwrite', 'merge-first', 'merge-last', 'remove')
+strategies = ("overwrite", "merge-first", "merge-last", "remove")
 
-__virtualname__ = 'makostack'
+__virtualname__ = "makostack"
 
 
 # Only load in this module if the EC2 configurations are in place
 def __virtual__():
-    '''
+    """
     Set up the libcloud functions and check for EC2 configurations
-    '''
+    """
     if HAS_MAKO is True:
         return __virtualname__
     return False
@@ -410,25 +405,28 @@ def __virtual__():
 
 def ext_pillar(minion_id, pillar, *args, **kwargs):
     import salt.utils.data
+
     stack = {}
     stack_config_files = list(args)
     traverse = {
-        'pillar': functools.partial(salt.utils.data.traverse_dict_and_list, pillar),
-        'grains': functools.partial(salt.utils.data.traverse_dict_and_list, __grains__),
-        'opts': functools.partial(salt.utils.data.traverse_dict_and_list, __opts__),
-        }
-    for matcher, matchs in six.iteritems(kwargs):
-        t, matcher = matcher.split(':', 1)
+        "pillar": functools.partial(salt.utils.data.traverse_dict_and_list, pillar),
+        "grains": functools.partial(salt.utils.data.traverse_dict_and_list, __grains__),
+        "opts": functools.partial(salt.utils.data.traverse_dict_and_list, __opts__),
+    }
+    for matcher, matchs in kwargs.items():
+        t, matcher = matcher.split(":", 1)
         if t not in traverse:
-            raise Exception('Unknown traverse option "{0}", '
-                            'should be one of {1}'.format(t, traverse.keys()))
+            raise Exception(
+                'Unknown traverse option "{}", '
+                "should be one of {}".format(t, traverse.keys())
+            )
         cfgs = matchs.get(traverse[t](matcher, None), [])
         if not isinstance(cfgs, list):
             cfgs = [cfgs]
         stack_config_files += cfgs
     for cfg in stack_config_files:
-        if ':' in cfg:
-            cfg, namespace = cfg.split(':', 1)
+        if ":" in cfg:
+            cfg, namespace = cfg.split(":", 1)
         else:
             namespace = None
         if not os.path.isfile(cfg):
@@ -441,40 +439,47 @@ def ext_pillar(minion_id, pillar, *args, **kwargs):
 def _process_stack_cfg(cfg, stack, minion_id, pillar, namespace):
     basedir, filename = os.path.split(cfg)
     lookup = TemplateLookup(directories=[basedir])
-    tops = lookup.get_template(filename).render(__opts__=__opts__,
-                                                __salt__=__salt__,
-                                                __grains__=__grains__,
-                                                minion_id=minion_id,
-                                                pillar=pillar, stack=stack)
+    tops = lookup.get_template(filename).render(
+        __opts__=__opts__,
+        __salt__=__salt__,
+        __grains__=__grains__,
+        minion_id=minion_id,
+        pillar=pillar,
+        stack=stack,
+    )
     for path in _parse_top_cfg(tops):
         dirs = [basedir]
-        if path.startswith('/'):
-            dirs += ['/']
+        if path.startswith("/"):
+            dirs += ["/"]
         lookup = TemplateLookup(directories=dirs)
         try:
-            p = lookup.get_template(path).render(__opts__=__opts__,
-                                                 __salt__=__salt__,
-                                                 __grains__=__grains__,
-                                                 minion_id=minion_id,
-                                                 pillar=pillar, stack=stack)
+            p = lookup.get_template(path).render(
+                __opts__=__opts__,
+                __salt__=__salt__,
+                __grains__=__grains__,
+                minion_id=minion_id,
+                pillar=pillar,
+                stack=stack,
+            )
             obj = salt.utils.yaml.safe_load(p)
             if not isinstance(obj, dict):
                 log.info(
                     'Ignoring Stack template "%s": Can\'t parse as a valid '
-                    'yaml dictionary', path
+                    "yaml dictionary",
+                    path,
                 )
                 continue
             if namespace:
-                for sub in namespace.split(':')[::-1]:
+                for sub in namespace.split(":")[::-1]:
                     obj = {sub: obj}
             stack = _merge_dict(stack, obj)
             log.info('Stack template "%s" parsed', path)
         except exceptions.TopLevelLookupException as e:
             log.info('Stack template "%s" not found.', path)
             continue
-        except Exception as e:
+        except Exception as e:  # pylint: disable=broad-except
             log.info('Ignoring Stack template "%s":', path)
-            log.info('%s', exceptions.text_error_template().render())
+            log.info("%s", exceptions.text_error_template().render())
             continue
     return stack
 
@@ -482,29 +487,29 @@ def _process_stack_cfg(cfg, stack, minion_id, pillar, namespace):
 def _cleanup(obj):
     if obj:
         if isinstance(obj, dict):
-            obj.pop('__', None)
-            for k, v in six.iteritems(obj):
+            obj.pop("__", None)
+            for k, v in obj.items():
                 obj[k] = _cleanup(v)
-        elif isinstance(obj, list) and isinstance(obj[0], dict) \
-                and '__' in obj[0]:
+        elif isinstance(obj, list) and isinstance(obj[0], dict) and "__" in obj[0]:
             del obj[0]
     return obj
 
 
 def _merge_dict(stack, obj):
-    strategy = obj.pop('__', 'merge-last')
+    strategy = obj.pop("__", "merge-last")
     if strategy not in strategies:
-        raise Exception('Unknown strategy "{0}", should be one of {1}'.format(
-            strategy, strategies))
-    if strategy == 'overwrite':
+        raise Exception(
+            'Unknown strategy "{}", should be one of {}'.format(strategy, strategies)
+        )
+    if strategy == "overwrite":
         return _cleanup(obj)
     else:
-        for k, v in six.iteritems(obj):
-            if strategy == 'remove':
+        for k, v in obj.items():
+            if strategy == "remove":
                 stack.pop(k, None)
                 continue
             if k in stack:
-                if strategy == 'merge-first':
+                if strategy == "merge-first":
                     # merge-first is same as merge-last but the other way round
                     # so let's switch stack[k] and v
                     stack_k = stack[k]
@@ -512,8 +517,7 @@ def _merge_dict(stack, obj):
                     v = stack_k
                 if type(stack[k]) != type(v):
                     log.debug(
-                        'Force overwrite, types differ: \'%s\' != \'%s\'',
-                        stack[k], v
+                        "Force overwrite, types differ: '%s' != '%s'", stack[k], v
                     )
                     stack[k] = _cleanup(v)
                 elif isinstance(v, dict):
@@ -528,31 +532,32 @@ def _merge_dict(stack, obj):
 
 
 def _merge_list(stack, obj):
-    strategy = 'merge-last'
-    if obj and isinstance(obj[0], dict) and '__' in obj[0]:
-        strategy = obj[0]['__']
+    strategy = "merge-last"
+    if obj and isinstance(obj[0], dict) and "__" in obj[0]:
+        strategy = obj[0]["__"]
         del obj[0]
     if strategy not in strategies:
-        raise Exception('Unknown strategy "{0}", should be one of {1}'.format(
-            strategy, strategies))
-    if strategy == 'overwrite':
+        raise Exception(
+            'Unknown strategy "{}", should be one of {}'.format(strategy, strategies)
+        )
+    if strategy == "overwrite":
         return obj
-    elif strategy == 'remove':
+    elif strategy == "remove":
         return [item for item in stack if item not in obj]
-    elif strategy == 'merge-first':
+    elif strategy == "merge-first":
         return obj + stack
     else:
         return stack + obj
 
 
 def _parse_top_cfg(content):
-    '''
+    """
     Allow top_cfg to be YAML
-    '''
+    """
     try:
         obj = salt.utils.yaml.safe_load(content)
         if isinstance(obj, list):
             return obj
-    except Exception as e:
+    except Exception as e:  # pylint: disable=broad-except
         pass
     return content.splitlines()
