@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Return salt data via pushover (http://www.pushover.net)
 
@@ -15,6 +14,10 @@ The following fields can be set in the minion conf file::
     pushover.retry (optional)
     pushover.profile (optional)
 
+.. note::
+    The ``user`` here is your **user key**, *not* the email address you use to
+    login to pushover.net.
+
 Alternative configuration values can be used by prefacing the configuration.
 Any values not found in the alternative configuration will be pulled from
 the default location::
@@ -75,19 +78,14 @@ To override individual configuration items, append --return_kwargs '{"key:": "va
     salt '*' test.ping --return pushover --return_kwargs '{"title": "Salt is awesome!"}'
 
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
-
-# Import Python libs
 import pprint
 
-# Import Salt Libs
 import salt.returners
 import salt.utils.pushover
 from salt.exceptions import SaltInvocationError
 
-# Import 3rd-party libs
 # pylint: disable=import-error,no-name-in-module,redefined-builtin
 from salt.ext.six.moves.urllib.parse import urlencode as _urlencode
 
@@ -238,11 +236,11 @@ def returner(ret):
             )
 
     message = (
-        "id: {0}\r\n"
-        "function: {1}\r\n"
-        "function args: {2}\r\n"
-        "jid: {3}\r\n"
-        "return: {4}\r\n"
+        "id: {}\r\n"
+        "function: {}\r\n"
+        "function args: {}\r\n"
+        "jid: {}\r\n"
+        "return: {}\r\n"
     ).format(
         ret.get("id"),
         ret.get("fun"),
