@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Management of APT/DNF/YUM/Zypper package repos
 ==============================================
@@ -65,28 +64,26 @@ package managers are APT, DNF, YUM and Zypper. Here is some example SLS:
         - name: logstash
         - refresh: True
 
-
-.. _bug: https://bugs.launchpad.net/ubuntu/+source/software-properties/+bug/1249080
-
 .. note::
 
     On Ubuntu systems, the ``python-software-properties`` package should be
     installed for better support of PPA repositories. To check if this package
     is installed, run ``dpkg -l python-software-properties``.
 
-    Also, some Ubuntu releases have a bug_ in their
-    ``python-software-properties`` package, a missing dependency on pycurl, so
-    ``python-pycurl`` will need to be manually installed if it is not present
-    once ``python-software-properties`` is installed.
-
     On Ubuntu & Debian systems, the ``python-apt`` package is required to be
     installed. To check if this package is installed, run ``dpkg -l python-apt``.
     ``python-apt`` will need to be manually installed if it is not present.
 
+.. code-block:: yaml
+
+    hello-copr:
+        pkgrepo.managed:
+            - copr: mymindstorm/hello
+        pkg.installed:
+            - name: hello
+
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import sys
 
@@ -95,12 +92,7 @@ import salt.utils.files
 import salt.utils.pkg.deb
 import salt.utils.pkg.rpm
 import salt.utils.versions
-
-# Import salt libs
 from salt.exceptions import CommandExecutionError, SaltInvocationError
-
-# Import 3rd-party libs
-from salt.ext import six
 from salt.state import STATE_INTERNAL_KEYWORDS as _STATE_INTERNAL_KEYWORDS
 
 
@@ -111,7 +103,7 @@ def __virtual__():
     return "pkg.mod_repo" in __salt__
 
 
-def managed(name, ppa=None, **kwargs):
+def managed(name, ppa=None, copr=None, **kwargs):
     """
     This state manages software package repositories. Currently, :mod:`yum
     <salt.modules.yumpkg>`, :mod:`apt <salt.modules.aptpkg>`, and :mod:`zypper
@@ -132,8 +124,8 @@ def managed(name, ppa=None, **kwargs):
         /etc/yum.repos.d (e.g. ``/etc/yum.repos.d/foo.conf``).
 
     enabled : True
-        Whether or not the repo is enabled. Can be specified as True/False or
-        1/0.
+        Whether the repo is enabled or not. Can be specified as ``True``/``False`` or
+        ``1``/``0``.
 
     disabled : False
         Included to reduce confusion due to APT's use of the ``disabled``
@@ -141,8 +133,14 @@ def managed(name, ppa=None, **kwargs):
         reverse will be passed as ``enabled``. For example passing
         ``disabled=True`` will assume ``enabled=False``.
 
+    copr
+        Fedora and RedHat based distributions only. Use community packages
+        outside of the main package repository.
+
+        .. versionadded:: 3002
+
     humanname
-        This is used as the "name" value in the repo file in
+        This is used as the ``name`` value in the repo file in
         ``/etc/yum.repos.d/`` (or ``/etc/zypp/repos.d`` for SUSE distros).
 
     baseurl
@@ -157,8 +155,8 @@ def managed(name, ppa=None, **kwargs):
         in the repo configuration with a comment marker (#) in front.
 
     gpgautoimport
-        Only valid for Zypper package manager. If set to True, automatically
-        trust and import public GPG key for the repository. The key should be
+        Only valid for Zypper package manager. If set to ``True``, automatically
+        trust and import the new repository signing key. The key should be
         specified with ``gpgkey`` parameter. See details below.
 
     Additional configuration values seen in YUM/DNF/Zypper repo files, such as
@@ -204,8 +202,8 @@ def managed(name, ppa=None, **kwargs):
 
     name
         On apt-based systems this must be the complete entry as it would be
-        seen in the sources.list file.  This can have a limited subset of
-        components (i.e. 'main') which can be added/modified with the
+        seen in the ``sources.list`` file. This can have a limited subset of
+        components (e.g. ``main``) which can be added/modified with the
         ``comps`` option.
 
         .. code-block:: yaml
@@ -235,30 +233,30 @@ def managed(name, ppa=None, **kwargs):
         ``enabled=False`` will assume ``disabled=False``.
 
     architectures
-        On apt-based systems, architectures can restrict the available
-        architectures that the repository provides (e.g. only amd64).
-        architectures should be a comma-separated list.
+        On apt-based systems, ``architectures`` can restrict the available
+        architectures that the repository provides (e.g. only ``amd64``).
+        ``architectures`` should be a comma-separated list.
 
     comps
         On apt-based systems, comps dictate the types of packages to be
-        installed from the repository (e.g. main, nonfree, ...).  For
-        purposes of this, comps should be a comma-separated list.
+        installed from the repository (e.g. ``main``, ``nonfree``, ...).  For
+        purposes of this, ``comps`` should be a comma-separated list.
 
     file
-       The filename for the .list that the repository is configured in.
+       The filename for the ``*.list`` that the repository is configured in.
        It is important to include the full-path AND make sure it is in
        a directory that APT will look in when handling packages
 
     dist
        This dictates the release of the distro the packages should be built
-       for.  (e.g. unstable). This option is rarely needed.
+       for.  (e.g. ``unstable``). This option is rarely needed.
 
     keyid
        The KeyID or a list of KeyIDs of the GPG key to install.
        This option also requires the ``keyserver`` option to be set.
 
     keyserver
-       This is the name of the keyserver to retrieve gpg keys from.  The
+       This is the name of the keyserver to retrieve GPG keys from. The
        ``keyid`` option must also be set for this option to work.
 
     key_url
@@ -270,9 +268,9 @@ def managed(name, ppa=None, **kwargs):
            Use either ``keyid``/``keyserver`` or ``key_url``, but not both.
 
     key_text
-        The string representation of the GPG key to install.
+       The string representation of the GPG key to install.
 
-        .. versionadded:: 2018.3.0
+       .. versionadded:: 2018.3.0
 
        .. note::
 
@@ -281,14 +279,14 @@ def managed(name, ppa=None, **kwargs):
 
     consolidate : False
        If set to ``True``, this will consolidate all sources definitions to the
-       sources.list file, cleanup the now unused files, consolidate components
-       (e.g. main) for the same URI, type, and architecture to a single line,
-       and finally remove comments from the sources.list file.  The consolidate
+       ``sources.list`` file, cleanup the now unused files, consolidate components
+       (e.g. ``main``) for the same URI, type, and architecture to a single line,
+       and finally remove comments from the ``sources.list`` file.  The consolidation
        will run every time the state is processed. The option only needs to be
-       set on one repo managed by salt to take effect.
+       set on one repo managed by Salt to take effect.
 
     clean_file : False
-       If set to ``True``, empty the file before config repo
+       If set to ``True``, empty the file before configuring the defined repository
 
        .. note::
            Use with care. This can be dangerous if multiple sources are
@@ -298,15 +296,16 @@ def managed(name, ppa=None, **kwargs):
 
     refresh : True
        If set to ``False`` this will skip refreshing the apt package database
-       on debian based systems.
+       on Debian based systems.
 
     refresh_db : True
        .. deprecated:: 2018.3.0
            Use ``refresh`` instead.
 
     require_in
-       Set this to a list of pkg.installed or pkg.latest to trigger the
-       running of apt-get update prior to attempting to install these
+       Set this to a list of :mod:`pkg.installed <salt.states.pkg.installed>` or
+       :mod:`pkg.latest <salt.states.pkg.latest>` to trigger the
+       running of ``apt-get update`` prior to attempting to install these
        packages. Setting a require in the pkg state will not work for this.
     """
 
@@ -360,7 +359,7 @@ def managed(name, ppa=None, **kwargs):
             try:
                 repo = ":".join(("ppa", ppa))
             except TypeError:
-                repo = ":".join(("ppa", six.text_type(ppa)))
+                repo = ":".join(("ppa", str(ppa)))
 
         kwargs["disabled"] = (
             not salt.utils.data.is_true(enabled)
@@ -369,6 +368,11 @@ def managed(name, ppa=None, **kwargs):
         )
 
     elif __grains__["os_family"] in ("RedHat", "Suse"):
+        if __grains__["os_family"] in "RedHat":
+            if copr is not None:
+                repo = ":".join(("copr", copr))
+                kwargs["name"] = name
+
         if "humanname" in kwargs:
             kwargs["name"] = kwargs.pop("humanname")
         if "name" not in kwargs:
@@ -396,7 +400,7 @@ def managed(name, ppa=None, **kwargs):
         pre = __salt__["pkg.get_repo"](repo=repo, **kwargs)
     except CommandExecutionError as exc:
         ret["result"] = False
-        ret["comment"] = "Failed to examine repo '{0}': {1}".format(name, exc)
+        ret["comment"] = "Failed to examine repo '{}': {}".format(name, exc)
         return ret
 
     # This is because of how apt-sources works. This pushes distro logic
@@ -469,18 +473,16 @@ def managed(name, ppa=None, **kwargs):
                     ) != salt.utils.data.is_true(pre[kwarg]):
                         break
                 else:
-                    if six.text_type(sanitizedkwargs[kwarg]) != six.text_type(
-                        pre[kwarg]
-                    ):
+                    if str(sanitizedkwargs[kwarg]) != str(pre[kwarg]):
                         break
         else:
             ret["result"] = True
-            ret["comment"] = "Package repo '{0}' already configured".format(name)
+            ret["comment"] = "Package repo '{}' already configured".format(name)
             return ret
 
     if __opts__["test"]:
         ret["comment"] = (
-            "Package repo '{0}' would be configured. This may cause pkg "
+            "Package repo '{}' would be configured. This may cause pkg "
             "states to behave differently than stated if this action is "
             "repeated without test=True, due to the differences in the "
             "configured repositories.".format(name)
@@ -510,7 +512,7 @@ def managed(name, ppa=None, **kwargs):
         # This is another way to pass information back from the mod_repo
         # function.
         ret["result"] = False
-        ret["comment"] = "Failed to configure repo '{0}': {1}".format(name, exc)
+        ret["comment"] = "Failed to configure repo '{}': {}".format(name, exc)
         return ret
 
     try:
@@ -526,10 +528,10 @@ def managed(name, ppa=None, **kwargs):
             ret["changes"] = {"repo": repo}
 
         ret["result"] = True
-        ret["comment"] = "Configured package repo '{0}'".format(name)
+        ret["comment"] = "Configured package repo '{}'".format(name)
     except Exception as exc:  # pylint: disable=broad-except
         ret["result"] = False
-        ret["comment"] = "Failed to confirm config of repo '{0}': {1}".format(name, exc)
+        ret["comment"] = "Failed to confirm config of repo '{}': {}".format(name, exc)
 
     # Clear cache of available packages, if present, since changes to the
     # repositories may change the packages that are available.
@@ -544,12 +546,25 @@ def managed(name, ppa=None, **kwargs):
 def absent(name, **kwargs):
     """
     This function deletes the specified repo on the system, if it exists. It
-    is essentially a wrapper around pkg.del_repo.
+    is essentially a wrapper around :mod:`pkg.del_repo <salt.modules.pkg.del_repo>`.
 
     name
         The name of the package repo, as it would be referred to when running
         the regular package manager commands.
 
+    **FEDORA/REDHAT-SPECIFIC OPTIONS**
+
+    copr
+        Use community packages outside of the main package repository.
+
+        .. versionadded:: 3002
+
+        .. code-block:: yaml
+
+            hello-copr:
+                pkgrepo.absent:
+                  - copr: mymindstorm/hello
+
     **UBUNTU-SPECIFIC OPTIONS**
 
     ppa
@@ -596,6 +611,11 @@ def absent(name, **kwargs):
         if not name.startswith("ppa:"):
             name = "ppa:" + name
 
+    if "copr" in kwargs and __grains__["os_family"] in "RedHat":
+        name = kwargs.pop("copr")
+        if not name.startswith("copr:"):
+            name = "copr:" + name
+
     remove_key = any(kwargs.get(x) is not None for x in ("keyid", "keyid_ppa"))
     if remove_key and "pkg.del_repo_key" not in __salt__:
         ret["result"] = False
@@ -606,17 +626,17 @@ def absent(name, **kwargs):
         repo = __salt__["pkg.get_repo"](name, **kwargs)
     except CommandExecutionError as exc:
         ret["result"] = False
-        ret["comment"] = "Failed to configure repo '{0}': {1}".format(name, exc)
+        ret["comment"] = "Failed to configure repo '{}': {}".format(name, exc)
         return ret
 
     if not repo:
-        ret["comment"] = "Package repo {0} is absent".format(name)
+        ret["comment"] = "Package repo {} is absent".format(name)
         ret["result"] = True
         return ret
 
     if __opts__["test"]:
         ret["comment"] = (
-            "Package repo '{0}' will be removed. This may "
+            "Package repo '{}' will be removed. This may "
             "cause pkg states to behave differently than stated "
             "if this action is repeated without test=True, due "
             "to the differences in the configured repositories.".format(name)
@@ -633,7 +653,7 @@ def absent(name, **kwargs):
     repos = __salt__["pkg.list_repos"]()
     if name not in repos:
         ret["changes"]["repo"] = name
-        ret["comment"] = "Removed repo {0}".format(name)
+        ret["comment"] = "Removed repo {}".format(name)
 
         if not remove_key:
             ret["result"] = True
@@ -642,13 +662,13 @@ def absent(name, **kwargs):
                 removed_keyid = __salt__["pkg.del_repo_key"](name, **kwargs)
             except (CommandExecutionError, SaltInvocationError) as exc:
                 ret["result"] = False
-                ret["comment"] += ", but failed to remove key: {0}".format(exc)
+                ret["comment"] += ", but failed to remove key: {}".format(exc)
             else:
                 ret["result"] = True
                 ret["changes"]["keyid"] = removed_keyid
-                ret["comment"] += ", and keyid {0}".format(removed_keyid)
+                ret["comment"] += ", and keyid {}".format(removed_keyid)
     else:
         ret["result"] = False
-        ret["comment"] = "Failed to remove repo {0}".format(name)
+        ret["comment"] = "Failed to remove repo {}".format(name)
 
     return ret
