@@ -1,21 +1,19 @@
-# -*- coding: utf-8 -*-
 """
 Encapsulate the different transports available to Salt.
 """
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
+
 
 import logging
-
-# Import Salt libs
-import salt.utils.versions
-
-# Import third party libs
-from salt.ext import six
-from salt.ext.six.moves import range
+import warnings
 
 log = logging.getLogger(__name__)
 
+# Supress warnings when running with a very old pyzmq. This can be removed
+# after we drop support for Ubuntu 16.04 and Debian 9
+warnings.filterwarnings(
+    "ignore", message="IOLoop.current expected instance.*", category=RuntimeWarning
+)
+
 
 def iter_transport_opts(opts):
     """
@@ -23,7 +21,7 @@ def iter_transport_opts(opts):
     """
     transports = set()
 
-    for transport, opts_overrides in six.iteritems(opts.get("transport_opts", {})):
+    for transport, opts_overrides in opts.get("transport_opts", {}).items():
         t_opts = dict(opts)
         t_opts.update(opts_overrides)
         t_opts["transport"] = transport
@@ -34,7 +32,7 @@ def iter_transport_opts(opts):
         yield opts["transport"], opts
 
 
-class MessageClientPool(object):
+class MessageClientPool:
     def __init__(self, tgt, opts, args=None, kwargs=None):
         sock_pool_size = opts["sock_pool_size"] if "sock_pool_size" in opts else 1
         if sock_pool_size < 1:
