@@ -1,30 +1,25 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 IPC transport classes
-'''
+"""
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
+
+import errno
 import logging
 import socket
-import weakref
 import time
 
-# Import 3rd-party libs
-import msgpack
-
-# Import Tornado libs
-import tornado
-import tornado.gen
-import tornado.netutil
-import tornado.concurrent
-from tornado.locks import Semaphore
-from tornado.ioloop import IOLoop, TimeoutError as TornadoTimeoutError
-from tornado.iostream import IOStream
-# Import Salt libs
+import salt.ext.tornado
+import salt.ext.tornado.concurrent
+import salt.ext.tornado.gen
+import salt.ext.tornado.ioloop
+import salt.ext.tornado.netutil
 import salt.transport.client
 import salt.transport.frame
-from salt.ext import six
+import salt.utils.msgpack
+from salt.ext.tornado.ioloop import IOLoop
+from salt.ext.tornado.ioloop import TimeoutError as TornadoTimeoutError
+from salt.ext.tornado.iostream import IOStream, StreamClosedError
+from salt.ext.tornado.locks import Lock
 
 log = logging.getLogger(__name__)
 
@@ -38,20 +33,21 @@ def future_with_timeout_callback(future):
         future._future_with_timeout._done_callback(future)
 
 
-class FutureWithTimeout(tornado.concurrent.Future):
+class FutureWithTimeout(salt.ext.tornado.concurrent.Future):
     def __init__(self, io_loop, future, timeout):
-        super(FutureWithTimeout, self).__init__()
+        super().__init__()
         self.io_loop = io_loop
         self._future = future
         if timeout is not None:
             if timeout < 0.1:
                 timeout = 0.1
             self._timeout_handle = self.io_loop.add_timeout(
-                self.io_loop.time() + timeout, self._timeout_callback)
+                self.io_loop.time() + timeout, self._timeout_callback
+            )
         else:
             self._timeout_handle = None
 
-        if hasattr(self._future, '_future_with_timeout'):
+        if hasattr(self._future, "_future_with_timeout"):
             # Reusing a future that has previously been used.
             # Due to this, no need to call add_done_callback()
             # because we did that before.
@@ -78,17 +74,25 @@ class FutureWithTimeout(tornado.concurrent.Future):
                 self._timeout_handle = None
 
             self.set_result(future.result())
-        except Exception as exc:
+        except Exception as exc:  # pylint: disable=broad-except
             self.set_exception(exc)
 
 
-class IPCServer(object):
-    '''
+class IPCServer:
+    """
     A Tornado IPC server very similar to Tornado's TCPServer class
     but using either UNIX domain sockets or TCP sockets
-    '''
+    """
+
+    async_methods = [
+        "handle_stream",
+    ]
+    close_methods = [
+        "close",
+    ]
+
     def __init__(self, socket_path, io_loop=None, payload_handler=None):
-        '''
+        """
         Create a new Tornado IPC server
 
         :param str/int socket_path: Path on the filesystem for the
@@ -102,126 +106,145 @@ class IPCServer(object):
         :param IOLoop io_loop: A Tornado ioloop to handle scheduling
         :param func payload_handler: A function to customize handling of
                                      incoming data.
-        '''
+        """
         self.socket_path = socket_path
         self._started = False
         self.payload_handler = payload_handler
 
         # Placeholders for attributes to be populated by method calls
         self.sock = None
-        self.io_loop = io_loop or IOLoop.current()
+        self.io_loop = io_loop or salt.ext.tornado.ioloop.IOLoop.current()
         self._closing = False
 
     def start(self):
-        '''
+        """
         Perform the work necessary to start up a Tornado IPC server
 
         Blocks until socket is established
-        '''
+        """
         # Start up the ioloop
-        log.trace('IPCServer: binding to socket: %s', self.socket_path)
+        log.trace("IPCServer: binding to socket: %s", self.socket_path)
         if isinstance(self.socket_path, int):
             self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             self.sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
             self.sock.setblocking(0)
-            self.sock.bind(('127.0.0.1', self.socket_path))
+            self.sock.bind(("127.0.0.1", self.socket_path))
             # Based on default used in tornado.netutil.bind_sockets()
             self.sock.listen(128)
         else:
-            self.sock = tornado.netutil.bind_unix_socket(self.socket_path)
+            self.sock = salt.ext.tornado.netutil.bind_unix_socket(self.socket_path)
 
         with salt.utils.asynchronous.current_ioloop(self.io_loop):
-            tornado.netutil.add_accept_handler(
-                self.sock,
-                self.handle_connection,
+            salt.ext.tornado.netutil.add_accept_handler(
+                self.sock, self.handle_connection,
             )
         self._started = True
 
-    @tornado.gen.coroutine
+    @salt.ext.tornado.gen.coroutine
     def handle_stream(self, stream):
-        '''
+        """
         Override this to handle the streams as they arrive
 
         :param IOStream stream: An IOStream for processing
 
         See https://tornado.readthedocs.io/en/latest/iostream.html#tornado.iostream.IOStream
         for additional details.
-        '''
-        @tornado.gen.coroutine
+        """
+
+        @salt.ext.tornado.gen.coroutine
         def _null(msg):
-            raise tornado.gen.Return(None)
+            raise salt.ext.tornado.gen.Return(None)
 
         def write_callback(stream, header):
-            if header.get('mid'):
-                @tornado.gen.coroutine
+            if header.get("mid"):
+
+                @salt.ext.tornado.gen.coroutine
                 def return_message(msg):
                     pack = salt.transport.frame.frame_msg_ipc(
-                        msg,
-                        header={'mid': header['mid']},
-                        raw_body=True,
+                        msg, header={"mid": header["mid"]}, raw_body=True,
                     )
                     yield stream.write(pack)
+
                 return return_message
             else:
                 return _null
-        if six.PY2:
-            encoding = None
+
+        # msgpack deprecated `encoding` starting with version 0.5.2
+        if salt.utils.msgpack.version >= (0, 5, 2):
+            # Under Py2 we still want raw to be set to True
+            msgpack_kwargs = {"raw": False}
         else:
-            encoding = 'utf-8'
-        unpacker = msgpack.Unpacker(encoding=encoding)
+            msgpack_kwargs = {"encoding": "utf-8"}
+        unpacker = salt.utils.msgpack.Unpacker(**msgpack_kwargs)
         while not stream.closed():
             try:
                 wire_bytes = yield stream.read_bytes(4096, partial=True)
                 unpacker.feed(wire_bytes)
                 for framed_msg in unpacker:
-                    body = framed_msg['body']
-                    self.io_loop.spawn_callback(self.payload_handler, body, write_callback(stream, framed_msg['head']))
-            except tornado.iostream.StreamClosedError:
-                log.trace('Client disconnected from IPC %s', self.socket_path)
+                    body = framed_msg["body"]
+                    self.io_loop.spawn_callback(
+                        self.payload_handler,
+                        body,
+                        write_callback(stream, framed_msg["head"]),
+                    )
+            except StreamClosedError:
+                log.trace("Client disconnected from IPC %s", self.socket_path)
                 break
-            except socket.error as exc:
+            except OSError as exc:
                 # On occasion an exception will occur with
                 # an error code of 0, it's a spurious exception.
                 if exc.errno == 0:
-                    log.trace('Exception occured with error number 0, '
-                              'spurious exception: %s', exc)
+                    log.trace(
+                        "Exception occurred with error number 0, "
+                        "spurious exception: %s",
+                        exc,
+                    )
                 else:
-                    log.error('Exception occurred while '
-                              'handling stream: %s', exc)
-            except Exception as exc:
-                log.error('Exception occurred while '
-                          'handling stream: %s', exc)
+                    log.error("Exception occurred while " "handling stream: %s", exc)
+            except Exception as exc:  # pylint: disable=broad-except
+                log.error("Exception occurred while " "handling stream: %s", exc)
 
     def handle_connection(self, connection, address):
-        log.trace('IPCServer: Handling connection '
-                  'to address: %s', address)
+        log.trace("IPCServer: Handling connection " "to address: %s", address)
         try:
             with salt.utils.asynchronous.current_ioloop(self.io_loop):
-                stream = IOStream(
-                    connection,
-                )
+                stream = IOStream(connection,)
             self.io_loop.spawn_callback(self.handle_stream, stream)
-        except Exception as exc:
-            log.error('IPC streaming error: %s', exc)
+        except Exception as exc:  # pylint: disable=broad-except
+            log.error("IPC streaming error: %s", exc)
 
     def close(self):
-        '''
+        """
         Routines to handle any cleanup before the instance shuts down.
         Sockets and filehandles should be closed explicitly, to prevent
         leaks.
-        '''
+        """
         if self._closing:
             return
         self._closing = True
-        if hasattr(self.sock, 'close'):
+        if hasattr(self.sock, "close"):
             self.sock.close()
 
+    # pylint: disable=W1701
     def __del__(self):
+        try:
+            self.close()
+        except TypeError:
+            # This is raised when Python's GC has collected objects which
+            # would be needed when calling self.close()
+            pass
+
+    # pylint: enable=W1701
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
         self.close()
 
 
-class IPCClient(object):
-    '''
+class IPCClient:
+    """
     A Tornado IPC client very similar to Tornado's TCPClient class
     but using either UNIX domain sockets or TCP sockets
 
@@ -235,87 +258,65 @@ class IPCClient(object):
                                 It may also be of type 'int', in which
                                 case it is used as the port for a tcp
                                 localhost connection.
-    '''
+    """
 
-    # Create singleton map between two sockets
-    instance_map = weakref.WeakKeyDictionary()
-
-    def __new__(cls, socket_path, io_loop=None):
-        io_loop = io_loop or tornado.ioloop.IOLoop.current()
-        if io_loop not in IPCClient.instance_map:
-            IPCClient.instance_map[io_loop] = weakref.WeakValueDictionary()
-        loop_instance_map = IPCClient.instance_map[io_loop]
-
-        # FIXME
-        key = six.text_type(socket_path)
-
-        client = loop_instance_map.get(key)
-        if client is None:
-            log.debug('Initializing new IPCClient for path: %s', key)
-            client = object.__new__(cls)
-            # FIXME
-            client.__singleton_init__(io_loop=io_loop, socket_path=socket_path)
-            loop_instance_map[key] = client
-        else:
-            log.debug('Re-using IPCClient for %s', key)
-        return client
-
-    def __singleton_init__(self, socket_path, io_loop=None):
-        '''
+    def __init__(self, socket_path, io_loop=None):
+        """
         Create a new IPC client
 
         IPC clients cannot bind to ports, but must connect to
         existing IPC servers. Clients can then send messages
         to the server.
 
-        '''
-        self.io_loop = io_loop or tornado.ioloop.IOLoop.current()
+        """
+        self.io_loop = io_loop or salt.ext.tornado.ioloop.IOLoop.current()
         self.socket_path = socket_path
         self._closing = False
         self.stream = None
-        if six.PY2:
-            encoding = None
+        # msgpack deprecated `encoding` starting with version 0.5.2
+        if salt.utils.msgpack.version >= (0, 5, 2):
+            # Under Py2 we still want raw to be set to True
+            msgpack_kwargs = {"raw": False}
         else:
-            encoding = 'utf-8'
-        self.unpacker = msgpack.Unpacker(encoding=encoding)
-
-    def __init__(self, socket_path, io_loop=None):
-        # Handled by singleton __new__
-        pass
+            msgpack_kwargs = {"encoding": "utf-8"}
+        self.unpacker = salt.utils.msgpack.Unpacker(**msgpack_kwargs)
+        self._connecting_future = None
 
     def connected(self):
         return self.stream is not None and not self.stream.closed()
 
     def connect(self, callback=None, timeout=None):
-        '''
+        """
         Connect to the IPC socket
-        '''
-        if hasattr(self, '_connecting_future') and not self._connecting_future.done():  # pylint: disable=E0203
-            future = self._connecting_future  # pylint: disable=E0203
+        """
+        if self._connecting_future is not None and not self._connecting_future.done():
+            future = self._connecting_future
         else:
-            if hasattr(self, '_connecting_future'):
+            if self._connecting_future is not None:
                 # read previous future result to prevent the "unhandled future exception" error
                 self._connecting_future.exception()  # pylint: disable=E0203
-            future = tornado.concurrent.Future()
+            future = salt.ext.tornado.concurrent.Future()
             self._connecting_future = future
-            self._connect(timeout=timeout)
+            self._connect(timeout)
 
         if callback is not None:
+
             def handle_future(future):
                 response = future.result()
                 self.io_loop.add_callback(callback, response)
+
             future.add_done_callback(handle_future)
 
         return future
 
-    @tornado.gen.coroutine
+    @salt.ext.tornado.gen.coroutine
     def _connect(self, timeout=None):
-        '''
+        """
         Connect to a running IPCServer
-        '''
+        """
         if isinstance(self.socket_path, int):
             sock_type = socket.AF_INET
-            sock_addr = ('127.0.0.1', self.socket_path)
+            sock_addr = ("127.0.0.1", self.socket_path)
         else:
             sock_type = socket.AF_UNIX
             sock_addr = self.socket_path
@@ -330,16 +331,13 @@ class IPCClient(object):
 
             if self.stream is None:
                 with salt.utils.asynchronous.current_ioloop(self.io_loop):
-                    self.stream = IOStream(
-                        socket.socket(sock_type, socket.SOCK_STREAM),
-                    )
-
+                    self.stream = IOStream(socket.socket(sock_type, socket.SOCK_STREAM))
             try:
-                log.trace('IPCClient: Connecting to socket: %s', self.socket_path)
+                log.trace("IPCClient: Connecting to socket: %s", self.socket_path)
                 yield self.stream.connect(sock_addr)
                 self._connecting_future.set_result(True)
                 break
-            except Exception as e:
+            except Exception as e:  # pylint: disable=broad-except
                 if self.stream.closed():
                     self.stream = None
 
@@ -350,36 +348,50 @@ class IPCClient(object):
                     self._connecting_future.set_exception(e)
                     break
 
-                yield tornado.gen.sleep(1)
-
-    def __del__(self):
-        self.close()
+                yield salt.ext.tornado.gen.sleep(1)
 
     def close(self):
-        '''
+        """
         Routines to handle any cleanup before the instance shuts down.
         Sockets and filehandles should be closed explicitly, to prevent
         leaks.
-        '''
+        """
         if self._closing:
             return
-        self._closing = True
-        if self.stream is not None and not self.stream.closed():
-            self.stream.close()
 
-        # Remove the entry from the instance map so
-        # that a closed entry may not be reused.
-        # This forces this operation even if the reference
-        # count of the entry has not yet gone to zero.
-        if self.io_loop in IPCClient.instance_map:
-            loop_instance_map = IPCClient.instance_map[self.io_loop]
-            key = six.text_type(self.socket_path)
-            if key in loop_instance_map:
-                del loop_instance_map[key]
+        self._closing = True
+        self._connecting_future = None
+
+        log.debug("Closing %s instance", self.__class__.__name__)
+
+        if self.stream is not None and not self.stream.closed():
+            try:
+                self.stream.close()
+            except OSError as exc:
+                if exc.errno != errno.EBADF:
+                    # If its not a bad file descriptor error, raise
+                    raise
+
+    # pylint: disable=W1701
+    def __del__(self):
+        try:
+            self.close()
+        except TypeError:
+            # This is raised when Python's GC has collected objects which
+            # would be needed when calling self.close()
+            pass
+
+    # pylint: enable=W1701
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.close()
 
 
 class IPCMessageClient(IPCClient):
-    '''
+    """
     Salt IPC message client
 
     Create an IPC client to send messages to an IPC server
@@ -390,13 +402,13 @@ class IPCMessageClient(IPCClient):
     IMPORTANT: The below example also assumes a running IOLoop process.
 
     # Import Tornado libs
-    import tornado.ioloop
+    import salt.ext.tornado.ioloop
 
     # Import Salt libs
     import salt.config
     import salt.transport.ipc
 
-    io_loop = tornado.ioloop.IOLoop.current()
+    io_loop = salt.ext.tornado.ioloop.IOLoop.current()
 
     ipc_server_socket_path = '/var/run/ipc_server.ipc'
 
@@ -407,19 +419,29 @@ class IPCMessageClient(IPCClient):
 
     # Send some data
     ipc_client.send('Hello world')
-    '''
+    """
+
+    async_methods = [
+        "send",
+        "connect",
+        "_connect",
+    ]
+    close_methods = [
+        "close",
+    ]
+
     # FIXME timeout unimplemented
     # FIXME tries unimplemented
-    @tornado.gen.coroutine
+    @salt.ext.tornado.gen.coroutine
     def send(self, msg, timeout=None, tries=None):
-        '''
+        """
         Send a message to an IPC socket
 
         If the socket is not currently connected, a connection will be established.
 
         :param dict msg: The message to be sent
         :param int timeout: Timeout when sending message (Currently unimplemented)
-        '''
+        """
         if not self.connected():
             yield self.connect()
         pack = salt.transport.frame.frame_msg_ipc(msg, raw_body=True)
@@ -427,7 +449,7 @@ class IPCMessageClient(IPCClient):
 
 
 class IPCMessageServer(IPCServer):
-    '''
+    """
     Salt IPC message server
 
     Creates a message server which can create and bind to a socket on a given
@@ -437,20 +459,17 @@ class IPCMessageServer(IPCServer):
     a console:
 
         # Import Tornado libs
-        import tornado.ioloop
+        import salt.ext.tornado.ioloop
 
         # Import Salt libs
         import salt.transport.ipc
-        import salt.config
 
-        opts = salt.config.master_opts()
-
-        io_loop = tornado.ioloop.IOLoop.current()
+        io_loop = salt.ext.tornado.ioloop.IOLoop.current()
         ipc_server_socket_path = '/var/run/ipc_server.ipc'
-        ipc_server = salt.transport.ipc.IPCMessageServer(opts, io_loop=io_loop
-                                                         stream_handler=print_to_console)
+        ipc_server = salt.transport.ipc.IPCMessageServer(ipc_server_socket_path, io_loop=io_loop,
+                                                         payload_handler=print_to_console)
         # Bind to the socket and prepare to run
-        ipc_server.start(ipc_server_socket_path)
+        ipc_server.start()
 
         # Start the server
         io_loop.start()
@@ -460,16 +479,17 @@ class IPCMessageServer(IPCServer):
             print(payload)
 
     See IPCMessageClient() for an example of sending messages to an IPCMessageServer instance
-    '''
+    """
 
 
-class IPCMessagePublisher(object):
-    '''
+class IPCMessagePublisher:
+    """
     A Tornado IPC Publisher similar to Tornado's TCPServer class
     but using either UNIX domain sockets or TCP sockets
-    '''
+    """
+
     def __init__(self, opts, socket_path, io_loop=None):
-        '''
+        """
         Create a new Tornado IPC server
         :param dict opts: Salt options
         :param str/int socket_path: Path on the filesystem for the
@@ -481,7 +501,7 @@ class IPCMessagePublisher(object):
                                     which case it is used as the port
                                     for a tcp localhost connection.
         :param IOLoop io_loop: A Tornado ioloop to handle scheduling
-        '''
+        """
         self.opts = opts
         self.socket_path = socket_path
         self._started = False
@@ -493,97 +513,98 @@ class IPCMessagePublisher(object):
         self.streams = set()
 
     def start(self):
-        '''
+        """
         Perform the work necessary to start up a Tornado IPC server
 
         Blocks until socket is established
-        '''
+        """
         # Start up the ioloop
-        log.trace('IPCMessagePublisher: binding to socket: %s', self.socket_path)
+        log.trace("IPCMessagePublisher: binding to socket: %s", self.socket_path)
         if isinstance(self.socket_path, int):
             self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             self.sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
             self.sock.setblocking(0)
-            self.sock.bind(('127.0.0.1', self.socket_path))
-            # Based on default used in tornado.netutil.bind_sockets()
+            self.sock.bind(("127.0.0.1", self.socket_path))
+            # Based on default used in salt.ext.tornado.netutil.bind_sockets()
             self.sock.listen(128)
         else:
-            self.sock = tornado.netutil.bind_unix_socket(self.socket_path)
+            self.sock = salt.ext.tornado.netutil.bind_unix_socket(self.socket_path)
 
         with salt.utils.asynchronous.current_ioloop(self.io_loop):
-            tornado.netutil.add_accept_handler(
-                self.sock,
-                self.handle_connection,
+            salt.ext.tornado.netutil.add_accept_handler(
+                self.sock, self.handle_connection,
             )
         self._started = True
 
-    @tornado.gen.coroutine
+    @salt.ext.tornado.gen.coroutine
     def _write(self, stream, pack):
         try:
             yield stream.write(pack)
-        except tornado.iostream.StreamClosedError:
-            log.trace('Client disconnected from IPC %s', self.socket_path)
+        except StreamClosedError:
+            log.trace("Client disconnected from IPC %s", self.socket_path)
             self.streams.discard(stream)
-        except Exception as exc:
-            log.error('Exception occurred while handling stream: %s', exc)
+        except Exception as exc:  # pylint: disable=broad-except
+            log.error("Exception occurred while handling stream: %s", exc)
             if not stream.closed():
                 stream.close()
             self.streams.discard(stream)
 
     def publish(self, msg):
-        '''
+        """
         Send message to all connected sockets
-        '''
-        if not len(self.streams):
+        """
+        if not self.streams:
             return
 
         pack = salt.transport.frame.frame_msg_ipc(msg, raw_body=True)
-
         for stream in self.streams:
             self.io_loop.spawn_callback(self._write, stream, pack)
 
     def handle_connection(self, connection, address):
-        log.trace('IPCServer: Handling connection to address: %s', address)
+        log.trace("IPCServer: Handling connection to address: %s", address)
         try:
             kwargs = {}
-            if self.opts['ipc_write_buffer'] > 0:
-                kwargs['max_write_buffer_size'] = self.opts['ipc_write_buffer']
-                log.trace('Setting IPC connection write buffer: %s', (self.opts['ipc_write_buffer']))
-            with salt.utils.asynchronous.current_ioloop(self.io_loop):
-                stream = IOStream(
-                    connection,
-                    **kwargs
+            if self.opts["ipc_write_buffer"] > 0:
+                kwargs["max_write_buffer_size"] = self.opts["ipc_write_buffer"]
+                log.trace(
+                    "Setting IPC connection write buffer: %s",
+                    (self.opts["ipc_write_buffer"]),
                 )
+            with salt.utils.asynchronous.current_ioloop(self.io_loop):
+                stream = IOStream(connection, **kwargs)
             self.streams.add(stream)
 
             def discard_after_closed():
                 self.streams.discard(stream)
 
             stream.set_close_callback(discard_after_closed)
-        except Exception as exc:
-            log.error('IPC streaming error: %s', exc)
+        except Exception as exc:  # pylint: disable=broad-except
+            log.error("IPC streaming error: %s", exc)
 
     def close(self):
-        '''
+        """
         Routines to handle any cleanup before the instance shuts down.
         Sockets and filehandles should be closed explicitly, to prevent
         leaks.
-        '''
+        """
         if self._closing:
             return
         self._closing = True
         for stream in self.streams:
             stream.close()
         self.streams.clear()
-        if hasattr(self.sock, 'close'):
+        if hasattr(self.sock, "close"):
             self.sock.close()
 
-    def __del__(self):
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
         self.close()
 
 
 class IPCMessageSubscriber(IPCClient):
-    '''
+    """
     Salt IPC message subscriber
 
     Create an IPC client to receive messages from IPC publisher
@@ -594,7 +615,7 @@ class IPCMessageSubscriber(IPCClient):
     IMPORTANT: The below example also assumes the IOLoop is NOT running.
 
     # Import Tornado libs
-    import tornado.ioloop
+    import salt.ext.tornado.ioloop
 
     # Import Salt libs
     import salt.config
@@ -602,7 +623,7 @@ class IPCMessageSubscriber(IPCClient):
 
     # Create a new IO Loop.
     # We know that this new IO Loop is not currently running.
-    io_loop = tornado.ioloop.IOLoop()
+    io_loop = salt.ext.tornado.ioloop.IOLoop()
 
     ipc_publisher_socket_path = '/var/run/ipc_publisher.ipc'
 
@@ -614,34 +635,44 @@ class IPCMessageSubscriber(IPCClient):
 
     # Wait for some data
     package = ipc_subscriber.read_sync()
-    '''
-    def __singleton_init__(self, socket_path, io_loop=None):
-        super(IPCMessageSubscriber, self).__singleton_init__(
-            socket_path, io_loop=io_loop)
-        self._read_sync_future = None
+    """
+
+    async_methods = [
+        "read",
+        "connect",
+    ]
+    close_methods = [
+        "close",
+    ]
+
+    def __init__(self, socket_path, io_loop=None):
+        super().__init__(socket_path, io_loop=io_loop)
         self._read_stream_future = None
-        self._sync_ioloop_running = False
-        self.saved_data = []
-        self._sync_read_in_progress = Semaphore()
+        self._saved_data = []
+        self._read_in_progress = Lock()
+
+    @salt.ext.tornado.gen.coroutine
+    def _read(self, timeout, callback=None):
+        try:
+            yield self._read_in_progress.acquire(timeout=0.00000001)
+        except salt.ext.tornado.gen.TimeoutError:
+            raise salt.ext.tornado.gen.Return(None)
 
-    @tornado.gen.coroutine
-    def _read_sync(self, timeout):
-        yield self._sync_read_in_progress.acquire()
         exc_to_raise = None
         ret = None
-
         try:
             while True:
                 if self._read_stream_future is None:
-                    self._read_stream_future = self.stream.read_bytes(4096, partial=True)
+                    self._read_stream_future = self.stream.read_bytes(
+                        4096, partial=True
+                    )
 
                 if timeout is None:
                     wire_bytes = yield self._read_stream_future
                 else:
-                    future_with_timeout = FutureWithTimeout(
-                        self.io_loop, self._read_stream_future, timeout)
-                    wire_bytes = yield future_with_timeout
-
+                    wire_bytes = yield FutureWithTimeout(
+                        self.io_loop, self._read_stream_future, timeout
+                    )
                 self._read_stream_future = None
 
                 # Remove the timeout once we get some data or an exception
@@ -650,41 +681,62 @@ class IPCMessageSubscriber(IPCClient):
                 timeout = None
 
                 self.unpacker.feed(wire_bytes)
-                first = True
+                first_sync_msg = True
                 for framed_msg in self.unpacker:
-                    if first:
-                        ret = framed_msg['body']
-                        first = False
+                    if callback:
+                        self.io_loop.spawn_callback(callback, framed_msg["body"])
+                    elif first_sync_msg:
+                        ret = framed_msg["body"]
+                        first_sync_msg = False
                     else:
-                        self.saved_data.append(framed_msg['body'])
-                if not first:
-                    # We read at least one piece of data
+                        self._saved_data.append(framed_msg["body"])
+                if not first_sync_msg:
+                    # We read at least one piece of data and we're on sync run
                     break
         except TornadoTimeoutError:
             # In the timeout case, just return None.
             # Keep 'self._read_stream_future' alive.
             ret = None
-        except tornado.iostream.StreamClosedError as exc:
-            log.trace('Subscriber disconnected from IPC %s', self.socket_path)
+        except StreamClosedError as exc:
+            log.trace("Subscriber disconnected from IPC %s", self.socket_path)
             self._read_stream_future = None
-            exc_to_raise = exc
-        except Exception as exc:
-            log.error('Exception occurred in Subscriber while handling stream: %s', exc)
+        except Exception as exc:  # pylint: disable=broad-except
+            log.error("Exception occurred in Subscriber while handling stream: %s", exc)
             self._read_stream_future = None
             exc_to_raise = exc
 
-        if self._sync_ioloop_running:
-            # Stop the IO Loop so that self.io_loop.start() will return in
-            # read_sync().
-            self.io_loop.spawn_callback(self.io_loop.stop)
+        self._read_in_progress.release()
 
         if exc_to_raise is not None:
             raise exc_to_raise  # pylint: disable=E0702
-        self._sync_read_in_progress.release()
-        raise tornado.gen.Return(ret)
+        raise salt.ext.tornado.gen.Return(ret)
+
+    @salt.ext.tornado.gen.coroutine
+    def read(self, timeout):
+        """
+        Asynchronously read messages and invoke a callback when they are ready.
+        :param callback: A callback with the received data
+        """
+        if self._saved_data:
+            res = self._saved_data.pop(0)
+            raise salt.ext.tornado.gen.Return(res)
+        while not self.connected():
+            try:
+                yield self.connect(timeout=5)
+            except StreamClosedError:
+                log.trace(
+                    "Subscriber closed stream on IPC %s before connect",
+                    self.socket_path,
+                )
+                yield salt.ext.tornado.gen.sleep(1)
+            except Exception as exc:  # pylint: disable=broad-except
+                log.error("Exception occurred while Subscriber connecting: %s", exc)
+                yield salt.ext.tornado.gen.sleep(1)
+        res = yield self._read(timeout)
+        raise salt.ext.tornado.gen.Return(res)
 
     def read_sync(self, timeout=None):
-        '''
+        """
         Read a message from an IPC socket
 
         The socket must already be connected.
@@ -692,70 +744,45 @@ class IPCMessageSubscriber(IPCClient):
         :param int timeout: Timeout when receiving message
         :return: message data if successful. None if timed out. Will raise an
                  exception for all other error conditions.
-        '''
-        if self.saved_data:
-            return self.saved_data.pop(0)
+        """
+        if self._saved_data:
+            return self._saved_data.pop(0)
+        return self.io_loop.run_sync(lambda: self._read(timeout))
 
-        self._sync_ioloop_running = True
-        self._read_sync_future = self._read_sync(timeout)
-        self.io_loop.start()
-        self._sync_ioloop_running = False
-
-        ret_future = self._read_sync_future
-        self._read_sync_future = None
-        return ret_future.result()
-
-    @tornado.gen.coroutine
-    def _read_async(self, callback):
-        while not self.stream.closed():
-            try:
-                self._read_stream_future = self.stream.read_bytes(4096, partial=True)
-                wire_bytes = yield self._read_stream_future
-                self._read_stream_future = None
-                self.unpacker.feed(wire_bytes)
-                for framed_msg in self.unpacker:
-                    body = framed_msg['body']
-                    self.io_loop.spawn_callback(callback, body)
-            except tornado.iostream.StreamClosedError:
-                log.trace('Subscriber disconnected from IPC %s', self.socket_path)
-                break
-            except Exception as exc:
-                log.error('Exception occurred while Subscriber handling stream: %s', exc)
-
-    @tornado.gen.coroutine
+    @salt.ext.tornado.gen.coroutine
     def read_async(self, callback):
-        '''
+        """
         Asynchronously read messages and invoke a callback when they are ready.
 
         :param callback: A callback with the received data
-        '''
+        """
         while not self.connected():
             try:
                 yield self.connect(timeout=5)
-            except tornado.iostream.StreamClosedError:
-                log.trace('Subscriber closed stream on IPC %s before connect', self.socket_path)
-                yield tornado.gen.sleep(1)
-            except Exception as exc:
-                log.error('Exception occurred while Subscriber connecting: %s', exc)
-                yield tornado.gen.sleep(1)
-        yield self._read_async(callback)
+            except StreamClosedError:
+                log.trace(
+                    "Subscriber closed stream on IPC %s before connect",
+                    self.socket_path,
+                )
+                yield salt.ext.tornado.gen.sleep(1)
+            except Exception as exc:  # pylint: disable=broad-except
+                log.error("Exception occurred while Subscriber connecting: %s", exc)
+                yield salt.ext.tornado.gen.sleep(1)
+        yield self._read(None, callback)
 
     def close(self):
-        '''
+        """
         Routines to handle any cleanup before the instance shuts down.
         Sockets and filehandles should be closed explicitly, to prevent
         leaks.
-        '''
-        if not self._closing:
-            IPCClient.close(self)
-            # This will prevent this message from showing up:
-            # '[ERROR   ] Future exception was never retrieved:
-            # StreamClosedError'
-            if self._read_sync_future is not None and self._read_sync_future.done():
-                self._read_sync_future.exception()
-            if self._read_stream_future is not None and self._read_stream_future.done():
-                self._read_stream_future.exception()
-
-    def __del__(self):
-        if IPCMessageSubscriber in globals():
-            self.close()
+        """
+        if self._closing:
+            return
+        super().close()
+        # This will prevent this message from showing up:
+        # '[ERROR   ] Future exception was never retrieved:
+        # StreamClosedError'
+        if self._read_stream_future is not None and self._read_stream_future.done():
+            exc = self._read_stream_future.exception()
+            if exc and not isinstance(exc, StreamClosedError):
+                log.error("Read future returned exception %r", exc)
