@@ -6,15 +6,30 @@ import sys
 import salt.payload
 
 
+def _trim_dict_in_dict(data, max_val_size, replace_with):
+    """
+    Takes a dictionary, max_val_size and replace_with
+    and recursively loops through and replaces any values
+    that are greater than max_val_size.
+    """
+    for key in data:
+        if isinstance(data[key], dict):
+            _trim_dict_in_dict(data[key], max_val_size, replace_with)
+        else:
+            if sys.getsizeof(data[key]) > max_val_size:
+                data[key] = replace_with
+
+
 def trim_dict(
-        data,
-        max_dict_bytes,
-        percent=50.0,
-        stepper_size=10,
-        replace_with='VALUE_TRIMMED',
-        is_msgpacked=False,
-        use_bin_type=False):
-    '''
+    data,
+    max_dict_bytes,
+    percent=50.0,
+    stepper_size=10,
+    replace_with="VALUE_TRIMMED",
+    is_msgpacked=False,
+    use_bin_type=False,
+):
+    """
     Takes a dictionary and iterates over its keys, looking for
     large values and replacing them with a trimmed string.
 
@@ -30,7 +45,7 @@ def trim_dict(
     to accurately return the items referenced in the structure.
 
     Ex:
-    >>> salt.utils.trim_dict({'a': 'b', 'c': 'x' * 10000}, 100)
+    >>> salt.utils.dicttrim.trim_dict({'a': 'b', 'c': 'x' * 10000}, 100)
     {'a': 'b', 'c': 'VALUE_TRIMMED'}
 
     To improve performance, it is adviseable to pass in msgpacked
@@ -46,8 +61,8 @@ def trim_dict(
                          with "use_bin_type=True". This also means
                          that the msgpack data should be decoded with
                          "encoding='utf-8'".
-    '''
-    serializer = salt.payload.Serial({'serial': 'msgpack'})
+    """
+    serializer = salt.payload.Serial({"serial": "msgpack"})
     if is_msgpacked:
         dict_size = sys.getsizeof(data)
     else:
@@ -55,7 +70,7 @@ def trim_dict(
     if dict_size > max_dict_bytes:
         if is_msgpacked:
             if use_bin_type:
-                data = serializer.loads(data, encoding='utf-8')
+                data = serializer.loads(data, encoding="utf-8")
             else:
                 data = serializer.loads(data)
         while True:
@@ -63,8 +78,11 @@ def trim_dict(
             max_val_size = float(max_dict_bytes * (percent / 100))
             try:
                 for key in data:
-                    if sys.getsizeof(data[key]) > max_val_size:
-                        data[key] = replace_with
+                    if isinstance(data[key], dict):
+                        _trim_dict_in_dict(data[key], max_val_size, replace_with)
+                    else:
+                        if sys.getsizeof(data[key]) > max_val_size:
+                            data[key] = replace_with
                 percent = percent - stepper_size
                 max_val_size = float(max_dict_bytes * (percent / 100))
                 if use_bin_type:
